@@ -20,9 +20,10 @@
   NIL)
 
 
-(defconst *initial-gcs%* (acl2::make gcs% :cts 0 :wts 0 :runs 0 :vacs 0 :dups 0))
+(def-const *initial-gcs%*
+  (acl2::make gcs% :cts 0 :wts 0 :runs 0 :vacs 0 :dups 0))
 
-(defconst *gcs-fields* '(cts wts runs dups vacs))
+(def-const *gcs-fields* '(cts wts runs dups vacs))
 (defun gcs%-p (v)
   (declare (xargs :guard T))
   (case-match v
@@ -41,10 +42,17 @@
              (acl2::|1+F| (access gcs% ,fld-nm))))
                                    
 
-(defconst *cgen-state-givens*  '(start-time user-supplied-term displayed-goal top-ctx params))
-(defconst *cgen-state-derived* '(top-vt-alist))
-(defconst *cgen-state-transient* '(gcs processor-hist s-hist stopping-condition-p proof-aborted-p end-time))
-(defconst *cgen-state-fields* (append *cgen-state-transient* *cgen-state-givens* *cgen-state-derived*))
+(def-const *cgen-state-givens*
+  '(start-time user-supplied-term displayed-goal top-ctx params))
+
+(def-const *cgen-state-derived*
+  '(top-vt-alist))
+
+(def-const *cgen-state-transient*
+  '(gcs processor-hist s-hist stopping-condition-p proof-aborted-p end-time))
+
+(def-const *cgen-state-fields*
+  (append *cgen-state-transient* *cgen-state-givens* *cgen-state-derived*))
 
 (defun cgen-state-p (v)
   (declare (xargs :guard T))
@@ -125,6 +133,11 @@ cgen-state"
 (defun allowed-cgen-event-ctx-p-no-defun (ctx)
   (declare (xargs :guard t))
   (cond ((equal ctx "( THM ...)") t)
+        ;; Pete: added this test because callback.lisp has this call
+        ;; (init-cgen-state/event (acl2s::acl2s-defaults-alist) start :undefined)
+        ;; and the third arg to init-cgen-state/event is supposed to
+        ;; satisfy allowed-cgen-event-ctx-p
+        ((equal ctx :undefined) t)
         ((member-equal ctx '(ACL2::THM ACL2::DEFTHM ACL2::VERIFY-GUARDS)))
         ((and (consp ctx)
               (member-equal (car ctx) '(ACL2::DEFTHM ACL2::VERIFY-GUARDS))) t)
@@ -157,6 +170,7 @@ cgen-state"
           (search-strategy :search-strategy)
           (testing-enabled :testing-enabled)
           (cgen-local-timeout :cgen-local-timeout)
+          (cgen-single-test-timeout :cgen-single-test-timeout)
           (print-cgen-summary :print-cgen-summary)
           (use-fixers :use-fixers)
           (recursively-fix :recursively-fix)
@@ -173,6 +187,7 @@ cgen-state"
          (member-eq search-strategy acl2s::*search-strategy-values*)
          (member-eq testing-enabled acl2s::*testing-enabled-values*)
          (rationalp cgen-local-timeout)
+         (rationalp cgen-single-test-timeout)
          (booleanp print-cgen-summary)
          (booleanp use-fixers)
          (booleanp recursively-fix)
@@ -222,7 +237,7 @@ cgen-state"
   "increments the number-valued fields of test-outcomes%"
   (declare (xargs :guard (member-eq fld '(cts wts vacs dups))))
   (let* ((fld-dc (string-downcase (symbol-name fld)))
-         (fld-nm (intern-in-package-of-symbol 
+         (fld-nm (acl2s::fix-intern-in-pkg-of-sym 
                   (concatenate-names (list "#" fld-dc)) 'test-outcomes%)))
     `(change test-outcomes% ,fld-nm
              (acl2::|1+F| (access test-outcomes% ,fld-nm)))))
