@@ -40,6 +40,7 @@
 (include-book "tools/rulesets" :dir :system)
 
 (include-book "var-book" :ttags :all)
+(include-book "ordinals/lexicographic-book" :dir :system)
 
 ;; (make-event ;TODO make sure to get this working
 ;;  (er-progn
@@ -70,8 +71,13 @@
 ; store all aliases of allp in a table. This will be used by subtype-p and
 ; disjoint-p functions. Recall that we have given up homebrew datatype
 ; relationship graphs in favor of its implicit coding in TAU-DATABASE.
-(table allp-aliases nil)
-(table allp-aliases 'allp 'all :put) ;all will be registered as a defdata type below.
+(table defdata::allp-aliases-table nil)
+(table defdata::allp-aliases-table 'allp 'all :put) ;all will be registered as a defdata type below.
+
+(defun allp-aliases-table (wrld)
+  "api to get the alist representing alias table allp-aliases"
+  (declare (xargs :guard (plist-worldp wrld)))
+  (table-alist 'defdata::allp-aliases-table wrld))
 
 ; Matt K. addition: Avoid ACL2(p) failure due to override-hints.
 (set-override-hints nil) ; a local event enabling waterfall-parallelism off
@@ -90,7 +96,33 @@
                            ((allp car) (allp cdr))
                            :rule-classes nil
                            :verbose t)
-                
+
+#|
+
+Adding app as a constructor is problematic because we have to be able
+to deconstruct lists and we don't know how to do that, i.e., we don't
+know where to split them up. 
+
+If this turns out to be important, one can define constructor
+on a per data definition basis or 
+
+;; App is a non-proper constructor that allows us to define
+;; datatypes such as
+;; (defdata infix (or 'x 'y (app (list infix) (cons '+ infix))))
+(defun append-dest1 (l)
+  (declare (xargs :guard (consp l)))
+  (list (car l)))
+
+(defun append-dest2 (l )
+  (declare (xargs :guard (consp l)))
+  (cdr l))
+
+(register-data-constructor
+ (consp append)
+ ((consp append-dest1) (allp append-dest2))
+ :rule-classes nil
+ :proper nil)
+|#
 
 ;;jared's oset implementation
 ;; (defun set::non-empty-setp (x)
@@ -104,26 +136,23 @@
 
 
 ;;symbols
-(register-data-constructor (symbolp intern$)
-                           ((stringp symbol-name) (stringp symbol-package-name))
-                           :rule-classes nil
-                           :proper nil) ;package name destructor fails
+(register-data-constructor
+ (symbolp intern$)
+ ((stringp symbol-name) (stringp symbol-package-name))
+ :rule-classes nil
+ :proper nil) ;package name destructor fails
 
-
-
-(register-data-constructor (rationalp /)
-                           ((integerp numerator) (posp denominator))
-                           :rule-classes nil
-                           :proper nil)
-
-
- 
+(register-data-constructor
+ (rationalp /)
+ ((integerp numerator) (posp denominator))
+ :rule-classes nil
+ :proper nil)
 
 ;;complex number type
-(register-data-constructor (acl2-numberp complex)
-                           ((rationalp realpart) (rationalp imagpart))
-                           :rule-classes nil
-                           )
+(register-data-constructor
+ (acl2-numberp complex)
+ ((rationalp realpart) (rationalp imagpart))
+ :rule-classes nil)
 
 
 #||
@@ -153,11 +182,11 @@
 
 ;;characters
 
-(defconst *character-values* *standard-chars*)
+(def-const *character-values* *standard-chars*)
 
-(defconst *len-character-values* (len *character-values*))
+(def-const *len-character-values* (len *character-values*))
 
-(defconst *alpha-chars*
+(def-const *alpha-chars*
   '(#\A #\B #\C #\D #\E #\F #\G
     #\H #\I #\J #\K #\L #\M #\N #\O #\P #\Q
     #\R #\S #\T #\U #\V #\W #\X #\Y #\Z
@@ -166,26 +195,26 @@
     #\n #\o #\p #\q #\r #\s #\t #\u #\v #\w
     #\x #\y #\z     ))
 
-(defconst *len-alpha-chars* (len *alpha-chars*))
+(def-const *len-alpha-chars* (len *alpha-chars*))
 
-(defconst *alpha-low-chars*
+(def-const *alpha-low-chars*
   '(#\a #\b #\c
     #\d #\e #\f #\g #\h #\i #\j #\k #\l #\m
     #\n #\o #\p #\q #\r #\s #\t #\u #\v #\w
     #\x #\y #\z 
     ))
 
-(defconst *len-alpha-low-chars* (len *alpha-low-chars*))
+(def-const *len-alpha-low-chars* (len *alpha-low-chars*))
 
-(defconst *alpha-up-chars*
+(def-const *alpha-up-chars*
   '(#\A #\B #\C #\D #\E #\F #\G
     #\H #\I #\J #\K #\L #\M #\N #\O #\P #\Q
     #\R #\S #\T #\U #\V #\W #\X #\Y #\Z
     ))
 
-(defconst *len-alpha-up-chars* (len *alpha-up-chars*))
+(def-const *len-alpha-up-chars* (len *alpha-up-chars*))
 
-(defconst *alpha-num-chars*
+(def-const *alpha-num-chars*
   '(#\A #\B #\C #\D #\E #\F #\G
     #\H #\I #\J #\K #\L #\M #\N #\O #\P #\Q
     #\R #\S #\T #\U #\V #\W #\X #\Y #\Z
@@ -196,7 +225,7 @@
     #\x #\y #\z
     ))
 
-(defconst *len-alpha-num-chars* (len *alpha-num-chars*))
+(def-const *len-alpha-num-chars* (len *alpha-num-chars*))
 
 
 (defthm integerp-mod
@@ -245,14 +274,12 @@
 (local (in-theory (disable mod)))
 ;;booleans
 
-(defconst *boolean-values* '(t nil))
+(def-const *boolean-values* '(t nil))
 (defun nth-boolean-builtin (n)
   (declare (xargs :guard (natp n)))
   (nth (mod n 2) *boolean-values*))
 ;(define-enumeration-type boolean '(t nil))
 
-
-
 ;-------- define some enumerators --------;
 
 (defun nth-nat-builtin (n)
@@ -340,7 +367,18 @@
 
 (defun nth-non-pos-integer-builtin (n)
   (declare (xargs :guard (natp n)))
-  (+ 1 n))
+  (- n))
+
+(defun non-0-integerp (x)
+  (declare (xargs :guard t))
+  (and (integerp x) 
+       (/= x 0)))
+
+(defun nth-non-0-integer-builtin (n)
+  (declare (xargs :guard (natp n)))
+  (if (evenp n)
+      (1+ (/ n 2))
+    (- (/ (1+ n) 2))))
 
 ;;integers
 (defun nth-integer-builtin (n)
@@ -352,20 +390,94 @@
       mag
       (- -1 mag))))
 
+(def-const *init-hash-num* 
+  (floor (* 61803095516164791237/100000000000000000000 (expt 2 64)) 1))
+
+(defun simple-hash (n range)
+  (declare (xargs :guard (and (natp n) (natp range))))
+  (let ((x (* n *init-hash-num*)))
+    (mod x (1+ range))))
+
 (defun nth-integer-between (n lo hi)
   (declare (xargs :guard (and (natp n)
                               (integerp lo)
-                              (integerp hi))))
-  (let ((range (nfix (- hi lo))))
-    (+ lo (mod n (1+ range)))))
+                              (integerp hi)
+                              (<= lo hi))))
+  (let ((range (- hi lo)))
+    (+ lo (simple-hash n range))))
+
+(local (include-book "arithmetic-5/top" :dir :system))
+       
+(defun bitsize-aux (n acc)
+  (declare (xargs :guard (and (natp n) (posp acc))))
+  (if (and (integerp n) (> n 1))
+      (bitsize-aux (floor (nfix n) 2) (1+ acc))
+    acc))
+
+(defthm bitsize-aux-posp
+  (implies (and (natp n) (posp acc))
+           (posp (bitsize-aux n acc))))
+
+(defun bitsize (n)
+  (declare (xargs :guard (natp n)))
+  (bitsize-aux n 1))
+
+; (bitsize 0)
+; (bitsize 1)
+; (bitsize 63)
+; (bitsize 64)
+
+(defun rounds (lo hi stop-bits)
+  (declare (xargs :guard (and (integerp lo)
+                              (integerp hi)
+                              (<= lo hi)
+                              (posp stop-bits))))
+  (let* ((range (nfix (- hi lo)))
+         (size (bitsize range)))
+    (if (<= size stop-bits)
+        1
+      (- size (1- stop-bits)))))
+    
+; (rounds 0 1023 10)
+; (rounds 0 1024 10)
+
+(defun nth-integer-between-bits-mid (n lo hi bits)
+  (declare (xargs :guard (and (natp n)
+                              (integerp lo)
+                              (integerp hi)
+                              (<= lo hi)
+                              (posp bits))))
+  (let* ((fullrange (- hi lo))
+         (brange (min fullrange (1- (expt 2 bits))))
+         (fullmid (+ lo (floor fullrange 2)))
+         (blo (- fullmid (floor brange 2))))
+    (+ blo (simple-hash n brange))))
+
+(defun nth-integer-between-bits-lo (n lo hi bits)
+  (declare (xargs :guard (and (natp n)
+                              (integerp lo)
+                              (integerp hi)
+                              (<= lo hi)
+                              (posp bits))))
+  (let* ((fullrange (- hi lo))
+         (brange (min fullrange (1- (expt 2 bits)))))
+    (+ lo (simple-hash n brange))))
+
+;(nth-integer-between-bits-mid 1021312 0 10000 100)
+;(nth-integer-between-bits-lo  1021312 0 10000 100)
+;(nth-integer-between          1021312 0 10000)
+
+;(nth-integer-between-bits-mid 1021312 0 10000 8)
+;(nth-integer-between-bits-lo  1021312 0 10000 8)
+;(nth-integer-between          1021312 0 10000)
 
 (defun integer-index (i)
   (declare (xargs :guard (integerp i)))
   (if (< i 0)
-    (1+ (* (- (1+ i)) 2))
+      (1+ (* (- (1+ i)) 2))
     (* i 2)))
 
-#||
+#|
 (encapsulate nil
   (local 
    (include-book "arithmetic-5/top" :dir :system))
@@ -404,17 +516,184 @@
        (not (integerp x))
        (< x 0)))
 
-(defun nth-neg-ratio-builtin (n)
-  (declare (xargs :guard (natp n)))
-  (if (or (zp n)
-          (<= n 2))
-      -1/2
-    (let* ((two-n-list (defdata::split-nat 2 n))
-           (alpha  (car two-n-list))
-           (beta (cadr two-n-list))
-           (den (+ 2 alpha))
-           (num (+ (floor beta den) beta)))
-      (- (/ num den)))))
+(defun base-defdata-insert (e l)
+  (declare (xargs :guard (and (natp e) (nat-listp l))))
+  (cond ((endp l) (list e))
+        ((<= e (car l)) (cons e l))
+        (t (cons (car l) (base-defdata-insert e (cdr l))))))
+
+(defun base-defdata-isort (l)
+  (declare (xargs :guard (nat-listp l)))
+  (if (endp l)
+      l
+    (base-defdata-insert (car l) (base-defdata-isort (cdr l)))))
+
+#|
+ (defthm base-defdata-isort-listp
+   (implies (nat-listp l)
+            (nat-listp (base-defdata-isort l)))
+   :rule-classes ((:forward-chaining) (:rewrite)))
+
+  (defthm len-base-defdata-isort
+   (equal (len (base-defdata-isort l)) (len l))
+   :rule-classes ((:forward-chaining :trigger-terms ((base-defdata-isort l))) (:rewrite)))
+
+ (defthm len-base-defdata-isort1
+   (implies (and (nat-listp l) l) (base-defdata-isort l))
+   :rule-classes ((:forward-chaining) (:rewrite)))
+
+ (defthm len-base-defdata-isort2
+   (implies (and (nat-listp l) (cdr l)) (cdr (base-defdata-isort l)))
+   :rule-classes ((:forward-chaining) (:rewrite)))
+
+ (defthm len-base-defdata-isort3
+   (implies (and (nat-listp l) (cddr l)) (cddr (base-defdata-isort l)))
+   :rule-classes ((:forward-chaining) (:rewrite)))
+  
+ (defthm weighted-split-nat--nat-listp-fc
+   (nat-listp (defdata::weighted-split-nat weights x))
+   :rule-classes ((:forward-chaining
+                   :trigger-terms
+                   ((defdata::weighted-split-nat weights x)))))
+
+(skip-proofs
+ (defthm len-wsn1
+   (implies (and (nat-listp l) l (natp n))
+            (defdata::weighted-split-nat l n))
+   :rule-classes ((:forward-chaining) (:rewrite))))
+
+(skip-proofs
+ (defthm len-wsn2
+   (implies (and (nat-listp l) (cdr l) (natp n))
+            (cdr (defdata::weighted-split-nat l n)))
+   :rule-classes ((:forward-chaining) (:rewrite))))
+
+(skip-proofs
+ (defthm len-wsn3
+   (implies (and (nat-listp l) (cddr l) (natp n))
+            (cddr (defdata::weighted-split-nat l n)))
+   :rule-classes ((:forward-chaining) (:rewrite))))
+
+(defthm base-defdata-isort-elements1
+  (implies (and (nat-listp l)
+                l)
+           (natp (car l)))
+  :rule-classes ((:rewrite)
+                 (:forward-chaining :trigger-terms ((car l)))))
+                                                     
+(defthm base-defdata-isort-elements2
+  (implies (and (nat-listp l)
+                (cdr l))
+           (natp (cadr l)))
+  :rule-classes ((:rewrite)
+                 (:forward-chaining :trigger-terms ((cadr l)))))
+
+(defthm base-defdata-isort-elements3
+  (implies (and (nat-listp l)
+                (cddr l))
+           (natp (caddr l)))
+  :rule-classes ((:rewrite)
+                 (:forward-chaining :trigger-terms ((caddr l)))))
+
+(defthm wsn-elements1
+  (implies (and (nat-listp l)
+                l
+                (natp n))
+           (natp (car )))
+  :rule-classes ((:rewrite)
+                 (:forward-chaining :trigger-terms ((car l)))))
+                                                     
+(defthm wsn-elements2
+  (implies (and (nat-listp l)
+                (cdr l))
+           (natp (cadr l)))
+  :rule-classes ((:rewrite)
+                 (:forward-chaining :trigger-terms ((cadr l)))))
+
+(defthm wsn-elements3
+  (implies (and (nat-listp l)
+                (cddr l))
+           (natp (caddr l)))
+  :rule-classes ((:rewrite)
+                 (:forward-chaining :trigger-terms ((caddr l)))))
+
+#|
+(i-am-here) ; proving stuff about weighted-split-nat is going to be a pain.
+(thm
+  (implies (and (posp k)
+                (natp n))
+           (nat-listp (defdata::split-nat k n))))
+
+(thm (implies (natp k)
+              (equal (len (acl2::repeat k n))
+                     k)))
+
+(skip-proofs
+(defthm weighted-split-nat--len
+  (equal (len (defdata::weighted-split-nat weights x))
+         (max 1 (len weights)))))
+
+(thm 
+  (EQUAL (LEN (DEFDATA::WEIGHTED-SPLIT-NAT l n))
+         (max 1 (len l)))
+  :hints (("goal" :in-theory (enable defdata::weighted-split-nat)))))
+
+
+(thm
+  (implies (posp k)
+           (equal (len (defdata::split-nat k n)) k)))
+|#
+
+(local
+ (defthm natp-implies-acl2-numberp
+  (implies (natp x)
+           (acl2-numberp x))
+  :rule-classes ((:rewrite) (:forward-chaining)))
+
+(defthm posp-implies-acl2-numberp
+  (implies (posp x)
+           (acl2-numberp x))
+  :rule-classes ((:rewrite) (:forward-chaining)))
+ 
+(defthm integerp-implies-acl2-numberp
+  (implies (integerp x)
+           (acl2-numberp x))
+  :rule-classes ((:rewrite) (:forward-chaining)))
+
+(defthm rationalp-implies-acl2-numberp2
+  (implies (rationalp x)
+           (acl2-numberp x))
+  :rule-classes ((:rewrite) (:forward-chaining)))
+
+(defthm natp-implies-rationalp
+  (implies (natp x)
+           (rationalp x))
+  :rule-classes ((:rewrite) (:forward-chaining)))
+
+(defthm posp-implies-rationalp
+  (implies (posp x)
+           (rationalp x))
+  :rule-classes ((:rewrite) (:forward-chaining)))
+
+(defthm integerp-implies-rationalp
+  (implies (integerp x)
+           (rationalp x))
+  :rule-classes ((:rewrite) (:forward-chaining)))
+)
+
+(defthm split-nat-len
+  (implies (and (posp k)
+                (natp n))
+           (equal (len (defdata::split-nat k n)) k))
+  :rule-classes ((:forward-chaining
+                  :trigger-terms ((defdata::split-nat k n)))))
+
+(in-theory (enable defdata::nthcdr-weighted-split-nat defdata::split-nat))
+(in-theory (disable
+            DEFDATA::WEIGHTED-SPLIT-NAT--TO--NTHCDR-WEIGHTED-SPLIT-NAT
+;            defdata::split-nat
+            ))
+|#
 
 (defun pos-ratiop (x)
   (declare (xargs :guard t))
@@ -423,16 +702,23 @@
        (> x 0)))
 
 (defun nth-pos-ratio-builtin (n)
-  (declare (xargs :guard (natp n)))
-  (if (or (zp n)
-          (<= n 2))
-      1/2
-    (let* ((two-n-list (defdata::split-nat 2 n))
-           (alpha  (car two-n-list))
-           (beta (cadr two-n-list))
-           (den (+ 2 alpha))
-           (num (+ (floor beta den) beta)))
-      (/ num den))))
+  (declare (xargs :guard (natp n) :verify-guards nil))
+  (let* ((two-n-list (base-defdata-isort (defdata::split-nat 3 n)))
+         (a (first two-n-list))
+         (b (1+ (second two-n-list)))
+         (c (1+ (third two-n-list)))
+         (c (if (< b c) c (1+ c))))
+    (+ a (/ b c))))
+
+(defun nth-neg-ratio-builtin (n)
+  (declare (xargs :guard (natp n) :verify-guards nil))
+  (- (nth-pos-ratio-builtin n)))
+
+#|
+
+Notice that this is the same as pos-ratio, since
+a ratio can't be an integer! So, I'm removing
+this as a type.
 
 (defun non-neg-ratiop (x)
   (declare (xargs :guard t))
@@ -440,17 +726,13 @@
        (not (integerp x))
        (>= x 0)))
 
-(defun nth-non-neg-ratio-builtin (n)
-  (declare (xargs :guard (natp n)))
-  (cond
-   ((zp n) 0)
-   ((<= n 2) 1/2)
-   (t (let* ((two-n-list (defdata::split-nat 2 n))
-             (alpha  (car two-n-list))
-             (beta (cadr two-n-list))
-             (den (+ 2 alpha))
-             (num (+ (floor beta den) beta)))
-        (/ num den)))))
+|#
+
+#|
+
+Notice that this is the same as neg-ratio, since a 
+ratio can't be an integer! So, I'm removing this 
+as a type.
 
 (defun non-pos-ratiop (x)
   (declare (xargs :guard t))
@@ -459,16 +741,11 @@
        (<= x 0)))
 
 (defun nth-non-pos-ratio-builtin (n)
-  (declare (xargs :guard (natp n)))
-  (cond
-   ((zp n) 0)
-   ((<= n 2) -1/2)
-   (t (let* ((two-n-list (defdata::split-nat 2 n))
-             (alpha  (car two-n-list))
-             (beta (cadr two-n-list))
-             (den (+ 2 alpha))
-             (num (+ (floor beta den) beta)))
-        (- (/ num den))))))
+  (declare (xargs :guard (natp n) :verify-guards nil))
+  (if (zp n)
+      0
+    (nth-neg-ratio-builtin n)))
+|#
 
 ;(defdata rat (oneof 0 pos-ratio neg-ratio))
 ;DOESNT WORK so pos/neg ratio are not consistent types ;TODO
@@ -526,7 +803,19 @@
 (defun nth-non-pos-rational-builtin (n)
   (declare (xargs :guard (natp n)))
   (let* ((two-n-list (defdata::split-nat 2 n))
-         (num (* -1 (nth-nat-builtin (car two-n-list))))
+         (num (nth-neg-builtin (car two-n-list)))
+         (den (nth-pos-builtin (cadr two-n-list))))
+    (/ num den)))
+
+(defun non-0-rationalp (x)
+  (declare (xargs :guard t))
+  (and (rationalp x) 
+       (/= x 0)))
+
+(defun nth-non-0-rational-builtin (n)
+  (declare (xargs :guard (natp n)))
+  (let* ((two-n-list (defdata::split-nat 2 n))
+         (num (nth-non-0-integer-builtin (car two-n-list)))
          (den (nth-pos-builtin (cadr two-n-list))))
     (/ num den)))
 
@@ -548,13 +837,13 @@
 (defun nth-rational-between (n lo hi);inclusive
   (declare (xargs :guard (and (natp n)
                               (rationalp lo)
-                              (rationalp hi))))
-
+                              (rationalp hi)
+                              (<= lo hi))))
   (let* ((two-n-list (defdata::split-nat 2 n))
          (den (nth-pos-builtin (car two-n-list)))
-         (num (nth-integer-between (cadr two-n-list) 0 (1+ den)))
+         (num (nth-integer-between (cadr two-n-list) 0 den))
          (range (- hi lo)))
-    (+ lo (* (/ num den) range))))       
+    (+ lo (* (/ num den) range))))
 
 (defun nth-complex-rational-builtin (n)
   (declare (xargs :guard (natp n)))
@@ -564,7 +853,11 @@
     (complex rpart ipart)))
 
 (defun nth-complex-rational-between (n lo hi)
-  (declare (xargs :guard (and (natp n) (complex/complex-rationalp lo) (complex/complex-rationalp hi))))
+  (declare (xargs :guard (and (natp n)
+                              (complex/complex-rationalp lo)
+                              (complex/complex-rationalp hi)
+                              (<= (realpart lo) (realpart hi))
+                              (<= (imagpart lo) (imagpart hi)))))
   (b* ((rlo (realpart lo))
        (rhi (realpart hi))
        (ilo (imagpart lo))
@@ -606,7 +899,6 @@
     (complex-rational (nth-complex-rational-between n lo hi))
     (t (nth-acl2-number-between n lo hi))))
   
-
 (defmacro nth-number-between (n lo hi &key type)
   `(nth-number-between-fn ,n ,lo ,hi (or ,type 'acl2s::acl2-number)))
 
@@ -687,7 +979,7 @@
     charlist))
 
 #||
-(defconst *base-types* '((BOOLEAN 2 *BOOLEAN-VALUES* . BOOLEANP)
+(def-const *base-types* '((BOOLEAN 2 *BOOLEAN-VALUES* . BOOLEANP)
                          (CHARACTER-LIST T NTH-CHARACTER-LIST . CHARACTER-LISTP)
                          (SYMBOL T NTH-SYMBOL . SYMBOLP)
                          (STRING T NTH-STRING . STRINGP)
@@ -727,17 +1019,24 @@
 (register-custom-type pos t nth-pos-builtin posp)
 (register-custom-type nat t nth-nat-builtin natp)
 
+#|
 (defdata non-neg-integer nat)
 
 (defthm non-neg-integer-is-nat
   (equal (non-neg-integerp x)
          (natp x)))
+|#
 
 (register-custom-type non-pos-integer
                       t
                       nth-non-pos-integer-builtin
                       non-pos-integerp)
 
+(register-custom-type non-0-integer
+                      t
+                      nth-non-0-integer-builtin
+                      non-0-integerp)
+
 (register-custom-type integer t nth-integer-builtin integerp)
 
 (register-custom-type neg-ratio
@@ -750,15 +1049,25 @@
                       nth-pos-ratio-builtin
                       pos-ratiop)
 
+#|
+
+Same as pos-ratio
+
 (register-custom-type non-neg-ratio
                       t
                       nth-non-neg-ratio-builtin
                       non-neg-ratiop)
+|#
+
+#|
+
+Same as neg-ratio
 
 (register-custom-type non-pos-ratio
                       t
                       nth-non-pos-ratio-builtin
                       non-pos-ratiop)
+|#
 
 (defdata ratio (oneof pos-ratio neg-ratio)) 
 
@@ -782,11 +1091,27 @@
                       nth-non-pos-rational-builtin
                       non-pos-rationalp)
 
-(register-custom-type rational t nth-rational-builtin  rationalp )
-(register-custom-type complex-rational t nth-complex-rational-builtin  complex-rationalp )
-(register-custom-type acl2-number t nth-acl2-number-builtin  acl2-numberp )
+(register-custom-type non-0-rational
+                      t
+                      nth-non-0-rational-builtin
+                      non-0-rationalp)
 
-(defconst *number-testing-limit* 1000)
+(register-custom-type rational
+                      t
+                      nth-rational-builtin
+                      rationalp)
+
+(register-custom-type complex-rational
+                      t
+                      nth-complex-rational-builtin
+                      complex-rationalp)
+
+(register-custom-type acl2-number
+                      t
+                      nth-acl2-number-builtin
+                      acl2-numberp)
+
+(def-const *number-testing-limit* 1000)
 
 ;ADDED restricted testing enumerators for all number types
 (defun nth-neg-testing (n)
@@ -809,33 +1134,42 @@
   (let ((n-small (mod n *number-testing-limit*)))
     (nth-non-pos-integer-builtin n-small)))
 
+(defun nth-non-0-integer-testing (n)
+  (declare (xargs :guard (natp n)))
+  (let ((n-small (mod n *number-testing-limit*)))
+    (nth-non-0-integer-builtin n-small)))
+
 (defun nth-integer-testing (n)
   (declare (xargs :guard (natp n)))
   (let ((n-small (mod n *number-testing-limit*)))
     (nth-integer-builtin n-small)))
 
 (defun nth-neg-ratio-testing (n)
-  (declare (xargs :guard (natp n)))
+  (declare (xargs :guard (natp n) :verify-guards nil))
   (let ((n-small (mod n *number-testing-limit*)))
     (nth-neg-ratio-builtin n-small)))
 
 (defun nth-pos-ratio-testing (n)
-  (declare (xargs :guard (natp n)))
+  (declare (xargs :guard (natp n) :verify-guards nil))
   (let ((n-small (mod n *number-testing-limit*)))
     (nth-pos-ratio-builtin n-small)))
 
+#|
+
+No longer needed.
 (defun nth-non-neg-ratio-testing (n)
-  (declare (xargs :guard (natp n)))
+  (declare (xargs :guard (natp n) :verify-guards nil))
   (let ((n-small (mod n *number-testing-limit*)))
     (nth-non-neg-ratio-builtin n-small)))
 
 (defun nth-non-pos-ratio-testing (n)
-  (declare (xargs :guard (natp n)))
+  (declare (xargs :guard (natp n) :verify-guards nil))
   (let ((n-small (mod n *number-testing-limit*)))
     (nth-non-pos-ratio-builtin n-small)))
+|#
 
 (defun nth-ratio-testing (n)
-  (declare (xargs :guard (natp n) :mode :program))
+  (declare (xargs :guard (natp n) :verify-guards nil :mode :program))
   (let ((n-small (mod n *number-testing-limit*)))
     (nth-ratio-builtin n-small)))
 
@@ -859,6 +1193,11 @@
   (let ((n-small (mod n *number-testing-limit*)))
     (nth-non-pos-rational-builtin n-small)))
 
+(defun nth-non-0-rational-testing (n)
+  (declare (xargs :guard (natp n)))
+  (let ((n-small (mod n *number-testing-limit*)))
+    (nth-non-0-rational-builtin n-small)))
+
 (defun nth-rational-testing (n)
   (declare (xargs :guard (natp n)))
   (let ((n-small (mod n *number-testing-limit*)))
@@ -890,7 +1229,7 @@
 
 (local (in-theory (disable acl2::legal-constantp)))
 
-(defconst *nice-symbol-names*
+(def-const *nice-symbol-names*
   '(x y z a b c i j k p q r s u v w l d e f g h m n))
 
 (defun nth-proper-symbol-builtin (n)
@@ -969,7 +1308,7 @@
 ;added the above atom primitive types in the data-type graph using register-custom-type
 
 ;custom type
-(defconst *z-values* '(0 -1 "a" 1/3 :a)) ;for zp
+(def-const *z-values* '(0 -1 "a" 1/3 :a)) ;for zp
 (defun nth-z-builtin (n)
   (declare (xargs :guard (natp n)))
   (nth (mod n 5) *z-values*))
@@ -985,35 +1324,39 @@
 (defdata::register-type z :domain-size t :enumerator nth-z-builtin :predicate zp :enum/acc nth-z-uniform-builtin)
 
 ;Subtype relations betweem the above
-
+; neg <= non-pos-integer <= integer
+; neg <= non-0-integer <= integer
+; neg <= neg-rational <= non-pos-rational <= rational
+;
+ 
 (defdata-subtype-strict neg non-pos-integer)
+(defdata-subtype-strict neg non-0-integer)
 (defdata-subtype-strict neg neg-rational)
 
 (defdata-subtype-strict pos nat)
+(defdata-subtype-strict pos non-0-integer)
 (defdata-subtype-strict pos pos-rational)
 
-(defdata-subtype-strict nat integer)
-
 (defdata-subtype-strict non-pos-integer integer)
+(defdata-subtype-strict non-0-integer integer)
+(defdata-subtype-strict nat integer)
 
 (defdata-subtype-strict integer rational)
 
-(defdata-subtype-strict neg-ratio non-pos-ratio)
 (defdata-subtype-strict neg-ratio non-pos-rational)
-
-(defdata-subtype-strict pos-ratio non-neg-ratio)
 (defdata-subtype-strict pos-ratio non-neg-rational)
 
-(defdata-subtype-strict non-neg-ratio ratio)
-(defdata-subtype-strict non-pos-ratio ratio)
-
 (defdata-subtype-strict ratio rational)
   
 (defdata-subtype-strict neg-rational non-pos-rational) 
+(defdata-subtype-strict neg-rational non-0-rational) 
+
 (defdata-subtype-strict pos-rational non-neg-rational) 
+(defdata-subtype-strict pos-rational non-0-rational) 
 
 (defdata-subtype-strict non-neg-rational rational)
 (defdata-subtype-strict non-pos-rational rational)
+(defdata-subtype-strict non-0-rational rational)
 
 (defdata-subtype-strict rational acl2-number)
 
@@ -1076,7 +1419,7 @@
                 (< (acl2-count (cdr x1)) (acl2-count x2)))))
 (defthm terminination-tree-enum-nth
   (<= (acl2-count (nth i x))
-              (acl2-count x))
+      (acl2-count x))
   :rule-classes (:rewrite :linear))
 
 (defthm termination-tree-enum-dec2
@@ -1084,7 +1427,31 @@
            (< (acl2-count (nth i x1)) (acl2-count x2)))
   :hints (("Goal" :in-theory (disable nth))))
 
+#|
 
+The corresponding rules do not seem to help, at all.
+
+(include-book "acl2s/acl2s-size" :dir :system)
+(defthm termination-tree-enum-cdr-acl2s-size
+  (implies (consp (double-rewrite x))
+           (and (< (acl2s-size (cdr x))
+                   (acl2s-size x))
+                (< (acl2s-size (car x))
+                   (acl2s-size x))))
+  :rule-classes :linear)
+
+(defthm termination-tree-enum-dec-acl2s-size
+  (implies (< (acl2s-size (double-rewrite x1)) (acl2s-size x2))
+           (and (< (acl2s-size (car x1)) (acl2s-size x2))
+                (< (acl2s-size (cdr x1)) (acl2s-size x2))))
+  :rule-classes ((:linear :match-free :all)))
+
+(defthm termination-tree-enum-dec2-acl2s-size
+  (implies (< (acl2s-size x1) (acl2s-size x2))
+           (< (acl2s-size (nth i x1)) (acl2s-size x2)))
+  :hints (("Goal" :in-theory (disable nth)))
+  :rule-classes ((:linear :match-free :all)))
+|#
 
 ; IMPORTANT: PROPER-CONS is put ahead of all lists, so that in the
 ; event of intersecting it with lists, the lists are given preference,
@@ -1201,8 +1568,18 @@
 
 
 
-
 (defdata nat-list (listof nat))
+(defdata non-empty-nat-list (cons nat nat-list))
+
+(local 
+ (defthm non-empty-nat-list-thm
+   (equal (non-empty-nat-listp x)
+          (and (consp x)
+               (nat-listp x)))
+   :rule-classes ((:forward-chaining
+                   :trigger-terms ((non-empty-nat-listp x))))))
+
+(defdata lex (oneof nat non-empty-nat-list))
 
 ;; (verify-termination pos-listp) ; pos-listp is in program mode, so we need this.
 ;; (verify-guards pos-listp)
@@ -1215,7 +1592,8 @@
 
 (defdata acl2-number-list (listof acl2-number) )
 (defdata boolean-list (listof boolean) )
-(defdata symbol-list    (listof symbol) )
+(defdata symbol-list  (listof symbol) )
+(defdata proper-symbol-list (listof proper-symbol) )
 (defdata::register-type character-list 
                :domain-size t 
                :predicate character-listp
@@ -1397,11 +1775,28 @@
   :domain-size t
   :enumerator nth-all-builtin
   :enum/acc nth-all-uniform-builtin)
-  
 
+(defun nth-quote-builtin (n)
+  (declare (xargs :mode :program))
+  (declare (xargs :guard (natp n)))
+  `(quote ,(nth-all-builtin n)))
+
+(defun nth-quote-uniform-builtin (m seed)
+  (declare (xargs :mode :program))
+  (declare (type (unsigned-byte 31) seed))
+  (declare (xargs :guard (and (natp m) (unsigned-byte-p 31 seed))))
+  (b* (((mv val seed)
+        (nth-all-uniform-builtin m seed)))
+    (mv `(quote ,val) seed)))
+
+(defdata::register-type quote
+  :predicate rquotep
+  :domain-size t
+  :enumerator nth-quote-builtin
+  :enum/acc nth-quote-uniform-builtin)
 
 ;We will also name a special type, the empty type, which has no elements in its typeset.
-(defconst *empty-values* '())
+(def-const *empty-values* '())
 (defun nth-empty (x)
   (declare (ignore x) (xargs :guard (natp x)))
   (er hard? 'nth-empty "~| Empty enumerator~%"))
@@ -1891,3 +2286,9 @@
 
 (in-theory (disable varp))
 
+; Some later proofs are easier if I use listof instead of alistof
+(defdata sym-aalist (listof (cons symbol symbol-alist)))
+
+(defthm sym-aalist-sym-aalist1
+  (equal (defdata::sym-aalist1p x)
+         (sym-aalistp x)))
