@@ -1,7 +1,8 @@
 #|$ACL2s-Preamble$;
 ;; Author - Harsh Raju Chamarthi (harshrc)
-(ld ;; Newline to fool ACL2/cert.pl dependency scanner
+(ld ; Matt K.: added linebreak to avoid build-system warning from LD
  "package.lsp")
 (begin-book t);$ACL2s-Preamble$|#
 
-(in-package "ACL2S")
\ No newline at end of file
+
+(in-package "ACL2S")
