@@ -408,16 +408,16 @@
                         (expt c n)
                       (- (expt c n))))))
 
-(theory-invariant (if (active-runep '(:definition boil-that-dustspeck))
-		      (and ;(active-runep '(:rewrite |(expt x (- n))|))
-			   ;(active-runep '(:rewrite |(expt x (- c))|))
-			   (active-runep '(:rewrite |(expt (/ x) n)|))
-		           (active-runep '(:rewrite |(/ (expt x n))|))
-			   (active-runep '(:rewrite |(expt 1/c n)|))
-			   (active-runep '(:rewrite |(expt (- x) n)|))
-			   (active-runep '(:rewrite |(expt (- c) n)|)))
-		    t)
-		  :error nil)
+(theory-invariant (if (active-runep '(:definition arith-5-active-flag))
+                      (and ;(active-runep '(:rewrite |(expt x (- n))|))
+                           ;(active-runep '(:rewrite |(expt x (- c))|))
+                           (active-runep '(:rewrite |(expt (/ x) n)|))
+                           (active-runep '(:rewrite |(/ (expt x n))|))
+                           (active-runep '(:rewrite |(expt 1/c n)|))
+                           (active-runep '(:rewrite |(expt (- x) n)|))
+                           (active-runep '(:rewrite |(expt (- c) n)|)))
+                    t)
+                  :error nil)
 
 (defthm |(expt (* x y) n)|
   (equal (expt (* x y) n)
