@@ -229,10 +229,9 @@
     :hints(("Goal" :in-theory (enable undup))))
 
   (defrefinement undup-equiv set-equiv
-    :hints (("goal" :use ((:instance undup-under-set-equiv
-                           (x acl2::x))
+    :hints (("goal" :use ((:instance undup-under-set-equiv)
                           (:instance undup-under-set-equiv
-                           (x acl2::y)))
+                           (x y)))
              :in-theory (disable undup-under-set-equiv))))
 
   (defcong undup-equiv undup-equiv (append a b) 1
@@ -1526,13 +1525,6 @@
 
 (fty::defoption maybe-backref backref)
 
-(define backref-extract-substr ((x backref-p) (str stringp))
-  :guard (backref-in-bounds x str)
-  :guard-hints (("goal" :in-theory (enable backref-in-bounds)))
-  :returns (substr stringp :rule-classes :type-prescription)
-  (b* (((backref x)))
-    (subseq (lstrfix str) x.loc (+ x.loc x.len))))
-
 (define maybe-backref-in-bounds ((x maybe-backref-p) (str stringp))
   (or (not x) (backref-in-bounds x str))
   ///
