@@ -154,8 +154,9 @@
        (acc  (revappend-chars "<p>This is a product type introduced by @(see fty::defprod).</p>" acc))
        (acc  (cons #\Newline acc))
        ((mv acc state) (defprod-main-description prod base-pkg acc state))
-       (acc  (revappend-chars (or long "") acc))
-       (long (rchars-to-string acc)))
+       ;; long may be a form that evaluates to a string:
+       (acc  `(revappend-chars ,(or long "") ',acc))
+       (long `(rchars-to-string ,acc)))
     (mv `((defxdoc ,x.name
             :parents ,parents
             :short ,short
@@ -313,7 +314,9 @@
                            ;; accessors.  XDOC will put them at the end in
                            ;; alphabetical order.
                            `((xdoc::order-subtopics ,foo
-                             (,foo-p ,foo-fix ,make-foo ,change-foo))))))
+                             (,foo-p ,foo-fix
+                                     ,@(and (not prod.no-ctor-macros)
+                                            `(,make-foo ,change-foo))))))))
     (mv doc-events state)))
 
 (defun deftagsum-prod-doc (sum  ; the containing sum type
@@ -331,8 +334,9 @@
        (acc  (revappend-chars ").</p>" acc))
        (acc  (cons #\Newline acc))
        ((mv acc state) (defprod-main-description prod base-pkg acc state))
-       (acc  (revappend-chars (or prod.long "") acc))
-       (long (rchars-to-string acc))
+       ;; prod.long may be a form that evaluates to a string:
+       (acc  `(revappend-chars ,(or prod.long "") ',acc))
+       (long `(rchars-to-string ,acc))
        (top-doc `((defxdoc ,prod.type-name
                     :parents ,parents
                     :short ,prod.short
@@ -347,7 +351,8 @@
        )
     (mv (append top-doc
                 make/change
-                `((xdoc::order-subtopics ,prod.type-name (,make-foo ,change-foo)))
+                (and (not prod.no-ctor-macros)
+                     `((xdoc::order-subtopics ,prod.type-name (,make-foo ,change-foo))))
                 )
         state)))
 
@@ -486,8 +491,9 @@ binder.</p>")
        ((mv acc state) (deftagsum-summarize-prods x x.prods base-pkg acc state))
        (acc   (revappend-chars "</dl>" acc))
        (acc   (cons #\Newline acc))
-       (acc   (revappend-chars (or long "") acc))
-       (long  (rchars-to-string acc))
+       ;; long may be a form that evaluates to a string:
+       (acc `(revappend-chars ,(or long "") ',acc))
+       (long `(rchars-to-string ,acc))
        (main-doc `((defxdoc ,x.name
                      :parents ,parents
                      :short ,short
@@ -520,8 +526,9 @@ binder.</p>")
        ((mv acc state) (deftagsum-summarize-prods x x.prods base-pkg acc state))
        (acc   (revappend-chars "</dl>" acc))
        (acc   (cons #\Newline acc))
-       (acc   (revappend-chars (or long "") acc))
-       (long  (rchars-to-string acc))
+       ;; long may be a form that evaluates to a string:
+       (acc `(revappend-chars ,(or long "") ',acc))
+       (long `(rchars-to-string ,acc))
        (main-doc `((defxdoc ,x.name
                      :parents ,parents
                      :short ,short
@@ -562,8 +569,9 @@ binder.</p>")
        (acc (revappend-chars "</dl>" acc))
 
        (acc   (cons #\Newline acc))
-       (acc   (revappend-chars (or long "") acc))
-       (long  (rchars-to-string acc))
+       ;; long may be a form that evaluates to a string:
+       (acc `(revappend-chars ,(or long "") ',acc))
+       (long `(rchars-to-string ,acc))
        ((mv prods-doc state)
         (deftagsum-prods-doc x x.prods (list x.name) base-pkg state))
        (case-doc (flexsum-case-macro-defxdoc x))
@@ -605,8 +613,9 @@ binder.</p>")
        (acc   (flextranssum-members->xdoc x.members acc state))
        (acc   (revappend-chars "</ul>" acc))
        (acc   (cons #\Newline acc))
-       (acc   (revappend-chars (or long "") acc))
-       (long  (rchars-to-string acc))
+       ;; long may be a form that evaluates to a string:
+       (acc `(revappend-chars ,(or long "") ',acc))
+       (long `(rchars-to-string ,acc))
        (main-doc `((defxdoc ,x.name
                      :parents ,parents
                      :short ,short
