@@ -31,7 +31,7 @@
 (in-package "FTY")
 (include-book "../deftypes")
 (include-book "../basetypes")
-(include-book "misc/assert" :dir :system)
+(include-book "std/testing/assert" :dir :system)
 
 (defprod student
   :tag :student
