@@ -33,7 +33,7 @@
 (include-book "../basetypes")
 (include-book "std/lists/acl2-count" :dir :system)
 (include-book "std/basic/two-nats-measure" :dir :system)
-(include-book "misc/assert" :dir :system)
+(include-book "std/testing/assert" :dir :system)
 (include-book "std/util/tests/utils" :dir :system)
 
 (in-theory (disable acl2-count))
@@ -147,6 +147,7 @@
 
     (deffixtype fnsym :pred fnsym-p :fix fnsym-fix :equiv fnsym-equiv :define t)))
 
+
 (deftypes pterm
   :prepwork ((local (defthm len-equal-val
                       (implies (syntaxp (quotep val))
