@@ -979,6 +979,10 @@ Warning: Clock ran out in ~x0~%" ',(gl-fnsym top-fn))
                  _newgeval_-ev-rules
                  _newgeval_-ev-of-fncall-args
                  _oldgeval_-ev-of-fncall-args
+                 _newgeval_-ev-of-nonsymbol-atom
+                 _oldgeval_-ev-of-nonsymbol-atom
+                 _newgeval_-ev-of-bad-fncall
+                 _oldgeval_-ev-of-bad-fncall
                  car-cons cdr-cons nth-0-cons (nfix)))
     :expand (; (_oldgeval_ x env)
              (:with _newgeval_ (_newgeval_ x env))
