@@ -229,8 +229,7 @@
   :guard (not (eq (ipasir-get-status$a solver) :undef))
   :returns (new-solver ipasir$a-p)
   :short "Logic form of @(see ipasir-input).  See @(see ipasir) for usage."
-  (b* (((ipasir$a solver)))
-    (change-ipasir$a solver :status :input))
+  (change-ipasir$a solver :status :input)
   ///
   (std::defret ipasir-input$a-status
     (equal (ipasir$a->status new-solver) :input))
@@ -369,8 +368,7 @@
   :short "Logic form of @(see ipasir-set-limit).  See @(see ipasir) for usage."
   (b* (((ipasir$a solver)))
     (change-ipasir$a solver
-                     :history (cons `(:limit ,(acl2::maybe-natp-fix limit)) solver.history)
-                     :callback-count 0))
+                     :history (cons `(:limit ,(acl2::maybe-natp-fix limit)) solver.history)))
   ///
   (std::defret status-of-ipasir-set-limit$a
     (equal (ipasir$a->status new-solver)
@@ -453,8 +451,7 @@
                             (equal (eval-cube new-solver.solution env$) 0))))))
 
  (defthm ipasir-solve$a-sat
-   (b* (((ipasir$a solver))
-        ((mv status (ipasir$a new-solver)) (ipasir-solve$a solver)))
+   (b* (((mv status (ipasir$a new-solver)) (ipasir-solve$a solver)))
      (implies (equal status :sat)
               (equal new-solver.status :sat))))
  ;; Won't assume the solution is a correct assignment because we can just
@@ -463,8 +460,7 @@
  ;; formula/assumption (for any starting env).
 
  (defthm ipasir-solve$a-failed
-   (b* (((ipasir$a solver))
-        ((mv status (ipasir$a new-solver)) (ipasir-solve$a solver)))
+   (b* (((mv status (ipasir$a new-solver)) (ipasir-solve$a solver)))
      (implies (equal status :failed)
               (equal new-solver.status :input)))))
 
@@ -901,7 +897,7 @@ tags.  Additionally, "ipasir-tools.lisp" builds on that to create some useful
 shortcuts, also without any trust tags.</p>
 
 <p>To load the backend, include "ipasir-backend.lisp".  This book first loads
-the shared library specified by the environmnent variable
+the shared library specified by the environment variable
 IPASIR_SHARED_LIBRARY, which should contain the path to a SAT solver shared
 library. It then overrides the executable definitions of the ipasir interface
 functions so that they instead call the appropriate functions from the shared
