@@ -506,7 +506,7 @@ svex-assigns-compose)).</li>
        ;; Set the new assignment: outside of bits rsh:rsh+width, same as before;
        ;; in bits rsh:rsh+width, it's override-test ? (rsh offset override-val) : (rsh rsh expr),
        (last (svex-rsh  (+ x.atom.rsh x.w) expr))
-       (mid  (svex-call '? (list (svex-zerox 1 override-test)
+       (mid  (svex-call '?* (list (svex-zerox 1 override-test)
                                  (svex-rsh offset override-val)
                                  (svex-rsh x.atom.rsh expr))))
        (newexpr (svex-concat x.atom.rsh
@@ -975,7 +975,7 @@ should address this again later.</p>"
                  ;; Bozo -- convert this to a zero-extend when possible?
                  (make-svex-call
                   :fn 'bit?
-                  :args (list (svex-quote (2vec (svex-mask-lookup (make-svex-var :name key) masks)))
+                  :args (list (svex-quote (2vec (sparseint-val (svex-mask-lookup (make-svex-var :name key) masks))))
                               ;; care
                               (make-svex-var :name val)
                               ;; don't-care
