@@ -587,8 +587,8 @@ substitution are left in place."
 
   (local (defthm svex-fix-under-iff
            (svex-fix x)
-           :hints (("goal" :use RETURN-TYPE-OF-SVEX-FIX$INLINE.NEW-X
-                    :in-theory (disable RETURN-TYPE-OF-SVEX-FIX$INLINE.NEW-X)))))
+           :hints (("goal" :use RETURN-TYPE-OF-SVEX-FIX.NEW-X
+                    :in-theory (disable RETURN-TYPE-OF-SVEX-FIX.NEW-X)))))
 
   (defthm svex-lookup-of-svex-alist-compose*
     (iff (svex-lookup v (svex-alist-compose* x a))
@@ -1944,7 +1944,10 @@ we've seen before with a mask that overlaps with that one.</p>"
        (updates-vals (svex-alist-vals updates))
        (- (cw "Updates count: ~x0~%" (svexlist-opcount updates-vals)))
        (updates-vals
-        (if rewrite (cwtime (svexlist-rewrite-top updates-vals :verbosep t) :mintime 0) updates-vals))
+        ;; (if rewrite (cwtime (svexlist-rewrite-top updates-vals :verbosep t) :mintime 0) updates-vals)
+        ;; Note: it seems quite important to rewrite here or else
+        ;; svexlist-compose-to-fix-rec2 takes a very long time.
+        (cwtime (svexlist-rewrite-top updates-vals :verbosep t) :mintime 0))
        (- (cw "Updates count after rewrite: ~x0~%" (svexlist-opcount updates-vals)))
        (masks (svexlist-mask-alist updates-vals))
        ;; (updates-vals (cwtime (svexlist-rewrite updates-vals masks) :mintime 1))
