@@ -37,7 +37,7 @@
 (include-book "centaur/sv/svtv/fsm" :dir :system)
 (include-book "centaur/vl/loader/top" :dir :system)
 (include-book "centaur/sv/svex/gl-rules" :dir :system)
-(include-book "misc/eval" :dir :system)
+(include-book "std/testing/eval" :dir :system)
 (include-book "oslib/ls" :dir :system)
 
 (local (in-theory (disable (tau-system))))
