@@ -219,7 +219,7 @@ information.</p>"
          (make-vl-coretype :name    :vl-logic
                            :signedp (if signed t nil)
                            :pdims   (and range
-                                         (list (vl-range->packeddimension range)))))))
+                                         (list (vl-range->dimension range)))))))
 
 (defparser vl-parse-taskport-declaration (atts)
   :short "Verilog-2005 only.  Match @('tf_input_declaration'), @('tf_output_declaration'), or @('tf_inout_declaration')."
@@ -274,7 +274,7 @@ information.</p>"
                           (:vl-kwd-time     *vl-plain-old-time-type*))
                       (make-vl-coretype :name :vl-logic
                                         :signedp (if signed t nil)
-                                        :pdims (and range (list (vl-range->packeddimension range))))))
+                                        :pdims (and range (list (vl-range->dimension range))))))
               (ret (vl-build-taskports atts dir type names)))
            (mv nil ret tokstream)))))
 
@@ -784,11 +784,6 @@ statements at all.\"</blockquote>
        (return (make-vl-blockstmt :blocktype :vl-beginend
                                   :stmts stmts))))
 
-;; (local (defthm vl-packeddimensionlist-p-when-vl-rangelist-p
-;;          (implies (vl-rangelist-p x)
-;;                   (vl-packeddimensionlist-p x))
-;;          :hints(("Goal" :induct (len x)))))
-
 (local (defthm vl-idtoken-p-of-car-by-vl-is-token-crock
          (implies (vl-is-token? :vl-idtoken)
                   (vl-idtoken-p (car (vl-tokstream->tokens))))
@@ -880,8 +875,8 @@ same direction.\"</blockquote>
        (udims := (vl-parse-0+-variable-dimensions))
 
        (when (vl-is-token? :vl-equalsign)
-         (return-raw
-          (vl-parse-error "BOZO implement default values for task/function arguments.")))
+         (:= (vl-match))
+         (default := (vl-parse-expression)))
 
        (return (make-vl-portdecl
                 :name (vl-idtoken->name name)
@@ -927,6 +922,7 @@ same direction.\"</blockquote>
 
                            (vl-portdecl->type prev))))
 
+                :default default
                 :atts atts
                 :nettype nil))))
 
@@ -962,9 +958,8 @@ same direction.\"</blockquote>
   :short "Temporary structure used when parsing @('list_of_tf_variable_identifiers')."
   :tag :vl-tf-parsed-var-id
   ((name    vl-idtoken-p)
-   (udims   vl-packeddimensionlist-p)
-   ;; BOZO eventually add default value
-   ))
+   (udims   vl-dimensionlist-p)
+   (default vl-maybe-expr-p)))
 
 (deflist vl-tf-parsed-var-idlist-p (x)
   (vl-tf-parsed-var-id-p x))
@@ -980,10 +975,11 @@ same direction.\"</blockquote>
        (name  := (vl-match-token :vl-idtoken))
        (udims := (vl-parse-0+-ranges))
        (when (vl-is-token? :vl-equalsign)
-         (return-raw
-          (vl-parse-error "BOZO implement default values for function/task ports.")))
+         (:= (vl-match))
+         (default := (vl-parse-expression)))
        (return (make-vl-tf-parsed-var-id :name name
-                                         :udims (vl-ranges->packeddimensions udims)))))
+                                         :udims (vl-ranges->dimensions udims)
+                                         :default default))))
 
 (defparser vl-parse-list-of-tf-variable-identifiers ()
   :short "Matches @('list_of_tf_variable_identifiers')."
@@ -1018,6 +1014,7 @@ same direction.\"</blockquote>
                             :nettype nil
                             :dir     dir
                             :type    (vl-datatype-update-udims id1.udims type)
+                            :default id1.default
                             :atts    atts)
           (vl-make-tf-ports-from-parsed-ids (cdr ids)
                                             :dir dir
@@ -1064,7 +1061,7 @@ same direction.\"</blockquote>
                   :type (make-vl-coretype :name    :vl-logic
                                           :signedp (and signing
                                                         (eq (vl-token->type signing) :vl-kwd-signed))
-                                          :pdims   (vl-ranges->packeddimensions ranges)))))
+                                          :pdims   (vl-ranges->dimensions ranges)))))
 
        ;; Otherwise, usual ambiguity between data types and identifiers.
        ;; As with ports, we know this is followed by an identifier.
