@@ -32,6 +32,7 @@
 (include-book "top")
 (include-book "print-defines")
 (include-book "../../mlib/print-warnings")
+(include-book "oslib/ls" :dir :system)
 (local (include-book "../../util/arithmetic"))
 
 ;; This will get run any time the book is included.
@@ -76,7 +77,7 @@
          (warnings nil)
          ((mv idcache ?warnings state)
           (vl-make-dirlist-cache include-dirs warnings state))
-         ((mv successp ?defs ?filemap ?iskips ?bytes warnings output state)
+         ((mv successp ?defs ?filemap ?iskips ?ifdefmap ?defmap ?bytes warnings output state)
           (vl-preprocess echars
                          :defines ,defines
                          :config (make-vl-loadconfig :include-dirs include-dirs)
@@ -116,7 +117,7 @@
          (warnings nil)
          ((mv idcache warnings state)
           (vl-make-dirlist-cache include-dirs warnings state))
-         ((mv successp ?defs ?filemap ?iskips ?bytes warnings output state)
+         ((mv successp ?defs ?filemap ?iskips ?ifdefmap ?defmap ?bytes warnings output state)
           (vl-preprocess echars
                          :defines ,defines
                          :config (make-vl-loadconfig :include-dirs include-dirs)
