@@ -170,6 +170,7 @@ their related warnings.</li>
 (def-vl-apply-reportcard udp)
 (def-vl-apply-reportcard interface)
 (def-vl-apply-reportcard program)
+(def-vl-apply-reportcard class)
 (def-vl-apply-reportcard package)
 (def-vl-apply-reportcard config)
 (def-vl-apply-reportcard typedef)
@@ -220,6 +221,7 @@ redundant/unnecessary information and is suitable for, e.g., printing.</p>"
                         (vl-udplist->names design.udps)
                         (vl-interfacelist->names design.interfaces)
                         (vl-programlist->names design.programs)
+                        (vl-classlist->names design.classes)
                         (vl-packagelist->names design.packages)
                         (vl-configlist->names design.configs)
                         (vl-typedeflist->names design.typedefs)
@@ -229,6 +231,7 @@ redundant/unnecessary information and is suitable for, e.g., printing.</p>"
                       (nrev (vl-udplist->names-nrev design.udps nrev))
                       (nrev (vl-interfacelist->names-nrev design.interfaces nrev))
                       (nrev (vl-programlist->names-nrev design.programs nrev))
+                      (nrev (vl-classlist->names-nrev design.classes nrev))
                       (nrev (vl-packagelist->names-nrev design.packages nrev))
                       (nrev (vl-configlist->names-nrev design.configs nrev))
                       (nrev (vl-typedeflist->names-nrev design.typedefs nrev))
@@ -344,6 +347,7 @@ associated with the top-level design, instead.</p>"
                :udps       (vl-udplist-apply-reportcard       x.udps       reportcard)
                :interfaces (vl-interfacelist-apply-reportcard x.interfaces reportcard)
                :programs   (vl-programlist-apply-reportcard   x.programs   reportcard)
+               :classes    (vl-classlist-apply-reportcard     x.classes    reportcard)
                :packages   (vl-packagelist-apply-reportcard   x.packages   reportcard)
                :configs    (vl-configlist-apply-reportcard    x.configs    reportcard)
                :typedefs   (vl-typedeflist-apply-reportcard   x.typedefs   reportcard)
@@ -372,6 +376,7 @@ associated with the top-level design, instead.</p>"
 (def-vl-gather-reportcard udplist udp)
 (def-vl-gather-reportcard interfacelist interface)
 (def-vl-gather-reportcard programlist program)
+(def-vl-gather-reportcard classlist class)
 (def-vl-gather-reportcard packagelist package)
 (def-vl-gather-reportcard configlist config)
 (def-vl-gather-reportcard typedeflist typedef)
@@ -387,6 +392,7 @@ associated with the top-level design, instead.</p>"
        (acc (vl-udplist-gather-reportcard       x.udps       acc))
        (acc (vl-interfacelist-gather-reportcard x.interfaces acc))
        (acc (vl-programlist-gather-reportcard   x.programs   acc))
+       (acc (vl-classlist-gather-reportcard     x.classes    acc))
        (acc (vl-packagelist-gather-reportcard   x.packages   acc))
        (acc (vl-configlist-gather-reportcard    x.configs    acc))
        (acc (vl-typedeflist-gather-reportcard   x.typedefs   acc))
@@ -424,6 +430,7 @@ design, in terms of the original design element names."
        (acc (vl-udplist-gather-reportcard       x.udps acc))
        (acc (vl-interfacelist-gather-reportcard x.interfaces acc))
        (acc (vl-programlist-gather-reportcard   x.programs acc))
+       (acc (vl-classlist-gather-reportcard     x.classes acc))
        (acc (vl-packagelist-gather-reportcard   x.packages acc))
        (acc (vl-configlist-gather-reportcard    x.configs acc))
        (acc (vl-typedeflist-gather-reportcard   x.typedefs acc))
