@@ -41,4 +41,5 @@
 (xdoc::archive-matching-topics
  (or (str::strprefixp "[books]/centaur/vl/" (cdr (assoc :from x)))
      ;; hack -- this book isn't included in sv, probably should be moved to vl/lint dir
-     (equal (cdr (assoc :from x)) "[books]/centaur/sv/vl/use-set.lisp")))
+     (equal (cdr (assoc :from x)) "[books]/centaur/sv/vl/use-set.lisp")
+     (equal (cdr (assoc :from x)) "[defxdoc-raw]"))) ;; for topics defined using defxdoc-raw
