@@ -172,7 +172,7 @@ is specified.
 
 
 (define vl-ansi-portdecl-to-regularport-from-previous-regularport
-  ((x vl-ansi-portdecl-p)
+  ((x         vl-ansi-portdecl-p)
    (prev      vl-portdecl-p "Previous portdecl.")
    (prev-var  vl-vardecl-p  "Previous vardecl.")
    (warnings  vl-warninglist-p))
@@ -195,18 +195,34 @@ is specified.
         (make-vl-regularport :name x.name
                              :expr (vl-idexpr x.name)
                              :loc x.loc)
-        (list (make-vl-portdecl :name x.name
-                                :dir prev.dir
-                                :nettype prev.nettype
-                                :type prev.type
-                                :atts x.atts
-                                :loc x.loc))
-        (list (make-vl-vardecl :name x.name
-                               :nettype prev.nettype
-                               :type prev.type
-                               :varp prev-var.varp
-                               :atts x.atts
-                               :loc x.loc)))))
+        ;; For better structure sharing, we want to CHANGE- the previous
+        ;; port/var instead of MAKE-ing new ones.
+        (list (change-vl-portdecl prev
+                                  :name x.name
+                                  :loc x.loc
+                                  :atts x.atts
+                                  :dir prev.dir
+                                  :nettype prev.nettype
+                                  :type prev.type))
+        (list (change-vl-vardecl prev-var
+                                 :name x.name
+                                 :loc x.loc
+                                 :type prev.type
+                                 :nettype prev.nettype
+                                 :varp prev-var.varp
+                                 :atts (if x.atts
+                                           (hons '("VL_ANSI_PORT_VARDECL") x.atts)
+                                         (hons-copy '(("VL_ANSI_PORT_VARDECL"))))
+                                 ;; All of the following should be never
+                                 ;; actually do anything, but it should be
+                                 ;; safe...
+                                 :initval nil
+                                 :constp nil
+                                 :lifetime nil
+                                 :vectoredp nil
+                                 :scalaredp nil
+                                 :delay nil
+                                 :cstrength nil)))))
 
 
 (local (defthm len-of-collect-regular-ports-when-car
@@ -297,7 +313,9 @@ is specified.
                                :nettype nettype
                                :type type
                                :varp x.varp
-                               :atts x.atts
+                               :atts (if x.atts
+                                         (hons '("VL_ANSI_PORT_VARDECL") x.atts)
+                                       (hons-copy '(("VL_ANSI_PORT_VARDECL"))))
                                :loc x.loc)))))
 
 
@@ -731,8 +749,7 @@ be a regular port, we don't look up the datatype to make sure it exists.</p>"
         (vl-loaditems-remove-interfaceport-decls loaditems ss))
        (ifport-alist (make-fast-alist ifport-alist))
        (vardecls (with-local-nrev
-                   (vl-fast-delete-vardecls (alist-keys ifport-alist) ifport-alist
-                                            x.vardecls nrev)))
+                   (vl-fast-delete-vardecls (alist-keys ifport-alist) ifport-alist x.vardecls nrev)))
        (ports (vl-ports-resolve-interfaces x.ports ifport-alist)))
     (change-vl-module x
                       :vardecls vardecls
@@ -764,8 +781,7 @@ be a regular port, we don't look up the datatype to make sure it exists.</p>"
         (vl-loaditems-remove-interfaceport-decls loaditems ss))
        (ifport-alist (make-fast-alist ifport-alist))
        (vardecls (with-local-nrev
-                   (vl-fast-delete-vardecls (alist-keys ifport-alist) ifport-alist
-                                            x.vardecls nrev)))
+                   (vl-fast-delete-vardecls (alist-keys ifport-alist) ifport-alist x.vardecls nrev)))
        (ports (vl-ports-resolve-interfaces x.ports ifport-alist)))
     (change-vl-interface x
                          :vardecls vardecls
