@@ -217,6 +217,8 @@
                ;; BOZO this is probably not right.  We probably need to fix up types
                ;; in the initial declarations before pushing the scope.  Think about it.
                (vl-scopestack-push (vl-forstmt->blockscope x) ss)
+               :vl-foreachstmt
+               (vl-scopestack-push (vl-foreachstmt->blockscope x) ss)
                :otherwise ss)))
       (vl-stmt-case x
         :vl-callstmt
@@ -234,7 +236,7 @@
               (vl-stmt-type-disambiguate-aux x ss))
              ;; Move arg1 over to become the typearg.
              ((wmv warnings id) (vl-scopeexpr-type-disambiguate x.id ss))
-             ((wmv warnings other-args) (vl-exprlist-type-disambiguate (cdr x.args) ss))
+             ((wmv warnings other-args) (vl-maybe-exprlist-type-disambiguate (cdr x.args) ss))
              (new-x (change-vl-callstmt x
                                         :id id
                                         :typearg type
