@@ -42,7 +42,7 @@
 (local (include-book "std/basic/arith-equivs" :dir :system))
 (local (include-book "arithmetic/top" :dir :system))
 (local (include-book "std/lists/top" :dir :system))
-(local (include-book "misc/assert" :dir :system))
+(local (include-book "std/testing/assert" :dir :system))
 (local (include-book "arithmetic"))
 (local (std::add-default-post-define-hook :fix))
 
@@ -448,7 +448,7 @@ the interface for constructing echars can be kept simple and bounds-free.</p>
 
 (fty::deflist vl-echarlist :elt-type vl-echar-p
   :elementp-of-nil nil
-  :true-listp nil)
+  :true-listp t)
 
 (defprojection vl-echarlist->chars ((x vl-echarlist-p))
   :returns (chars character-listp)
