@@ -40,10 +40,10 @@
 (include-book "../mlib/json")
 (include-book "oslib/file-types" :dir :system)
 (include-book "std/io/unsound-read" :dir :system)
-(include-book "centaur/quicklisp/hunchentoot" :dir :system)
-(include-book "centaur/quicklisp/bordeaux" :dir :system)
-(include-book "centaur/quicklisp/bt-semaphore" :dir :system)
-(include-book "centaur/quicklisp/html-template" :dir :system)
+(include-book "quicklisp/hunchentoot" :dir :system)
+(include-book "quicklisp/bordeaux" :dir :system)
+(include-book "quicklisp/bt-semaphore" :dir :system)
+(include-book "quicklisp/html-template" :dir :system)
 (include-book "centaur/bridge/to-json" :dir :system)
 (include-book "xdoc/defxdoc-raw" :dir :system)
 (include-book "centaur/misc/memory-mgmt" :dir :system)
