@@ -33,7 +33,7 @@
 (include-book "std/util/defval" :dir :system)
 (include-book "centaur/fty/fixequiv" :dir :system)
 (include-book "centaur/fty/basetypes" :dir :system)
-(local (include-book "misc/assert" :dir :system))
+(local (include-book "std/testing/assert" :dir :system))
 (local (include-book "arithmetic"))
 (local (include-book "std/basic/arith-equivs" :dir :system))
 (local (in-theory (enable acl2::arith-equiv-forwarding)))
