@@ -34,10 +34,21 @@
 (include-book "centaur/fty/fixequiv" :dir :system)
 (include-book "centaur/fty/fty-sum-casemacro" :dir :system)
 (include-book "tools/templates" :dir :system)
+(include-book "ev-find-rules")
 (local (include-book "std/lists/take" :dir :system))
 (local (include-book "ev-ind"))
 (local (std::add-default-post-define-hook :fix))
 
+(defthm pseudo-termp-car-when-pseudo-term-listp
+  (implies (pseudo-term-listp x)
+           (pseudo-termp (car x)))
+  :hints(("Goal" :in-theory (enable pseudo-term-listp))))
+
+(defthm pseudo-term-listp-cdr-when-pseudo-term-listp
+  (implies (pseudo-term-listp x)
+           (pseudo-term-listp (cdr x)))
+  :hints(("Goal" :in-theory (enable pseudo-term-listp))))
+
 (defxdoc pseudo-term-fty
   :parents (pseudo-termp)
   :short "Overview of FTY support for pseudo-terms."
@@ -315,7 +326,6 @@ of term and access the fields; see its documentation for examples.</p>
          (true-list-fix x)))
 
 
-
 (defxdoc def-ev-pseudo-term-congruence
   :parents (pseudo-term-fty)
   :short "Prove that @(see pseudo-term-fix) is transparent to an evaluator and
@@ -717,7 +727,8 @@ introduced by it.</p>")
        :exec (cdr x))
   ///
   (defthm acl2-count-of-pseudo-term-call->args
-    (implies (member (pseudo-term-kind x) '(:fncall :lambda))
+    (implies (or (equal (pseudo-term-kind x) :lambda)
+                 (equal (pseudo-term-kind x) :fncall))
              (< (acl2-count (pseudo-term-call->args x)) (acl2-count (pseudo-term-fix x))))
     :hints(("Goal" :in-theory (enable pseudo-term-kind)))
     :rule-classes ((:linear :trigger-terms ((acl2-count (pseudo-term-call->args x)))))))
@@ -790,11 +801,12 @@ introduced by it.</p>")
     :hints(("Goal" :in-theory (enable base-ev-of-fncall-args))))
 
   (defthm base-ev-when-pseudo-term-fncall
-    (implies (equal (pseudo-term-kind x) :fncall)
+    (implies (and (equal (pseudo-term-kind x) :fncall)
+                  (equal new-x (cons (pseudo-term-fncall->fn x)
+                                   (pseudo-term-call->args x)))
+                  (syntaxp (not (equal new-x x))))
              (equal (base-ev x a)
-                    (base-ev (cons (pseudo-term-fncall->fn x)
-                                   (pseudo-term-call->args x))
-                             a)))
+                    (base-ev new-x a)))
     :hints (("goal" :use ((:instance base-ev-of-pseudo-term-fix))
              :in-theory (e/d (pseudo-term-kind
                               pseudo-term-fncall->fn
@@ -1176,7 +1188,34 @@ introduced by it.</p>")
                                         (pseudo-lambda->body fn)
                                         args))))
 
+  (local (defthm kind-when-consp-of-pseudo-term-call->fn
+           (implies (consp (pseudo-term-call->fn x))
+                    (equal (pseudo-term-kind x) :lambda))
+           :hints(("Goal" :in-theory (enable pseudo-term-call->fn
+                                             pseudo-term-kind)))))
 
+  (local (defthm kind-when-not-consp-of-pseudo-term-call->fn
+           (implies (and (not (consp (pseudo-term-call->fn x)))
+                         (consp (pseudo-term-fix x))
+                         (not (equal (car (pseudo-term-fix x)) 'quote)))
+                    (equal (pseudo-term-kind x) :fncall))
+           :hints(("Goal" :in-theory (enable pseudo-term-call->fn
+                                             pseudo-term-kind
+                                             pseudo-term-fix)))))
+
+  (defthm pseudo-term-call-of-accessors
+    (implies (or (equal (pseudo-term-kind x) :lambda)
+                 (equal (pseudo-term-kind x) :fncall))
+             (equal (pseudo-term-call (pseudo-term-call->fn x)
+                                      (pseudo-term-call->args x))
+                    (pseudo-term-fix x)))
+    :hints(("Goal" :in-theory (enable ;; pseudo-term-call->fn ;; pseudo-term-call->args
+                                      pseudo-term-kind
+                                      ;; pseudo-term-fncall
+                                      ;; pseudo-term-lambda
+                                      ;; pseudo-lambda->formals
+                                      ;; pseudo-lambda->body
+                                      ))))
 
   (defthmd base-ev-of-pseudo-term-call
     (implies (syntaxp (not (equal a ''nil)))
@@ -1186,6 +1225,20 @@ introduced by it.</p>")
                              nil)))
     :hints(("Goal" :in-theory (enable base-ev-of-fncall-args))))
 
+  (defthmd base-ev-when-pseudo-term-call
+    (implies (and (or (equal (pseudo-term-kind x) :lambda)
+                      (equal (pseudo-term-kind x) :fncall))
+                  (syntaxp (not (and (consp x) (eq (car x) 'pseudo-term-call)))))
+             (equal (base-ev x a)
+                    (base-ev (pseudo-term-call (pseudo-term-call->fn x)
+                                               (kwote-lst
+                                                (base-ev-list (pseudo-term-call->args x) a)))
+                             nil)))
+    :hints (("goal" :use ((:instance base-ev-of-pseudo-term-call
+                           (fn (pseudo-term-call->fn x))
+                           (args (pseudo-term-call->args x))))
+             :in-theory (disable base-ev-of-pseudo-term-call pseudo-term-call))))
+
   (def-b*-binder pseudo-term-call
     :body
     (std::da-patbind-fn 'pseudo-term-call
@@ -1297,8 +1350,9 @@ all the cases and all the accessors that can be used in each case.</p>
     :rule-classes :linear)
 
   (defthm pseudo-term-list-count-of-pseudo-term-call->args
-    (implies (member (pseudo-term-kind x) '(:fncall :lambda))
-             (< (pseudo-term-list-count (pseudo-term-call->args x))
+    (implies (or (equal (pseudo-term-kind x) :lambda)
+                 (equal (pseudo-term-kind x) :fncall))
+             (< (pseudo-term-list-count (acl2::pseudo-term-call->args x))
                 (pseudo-term-count x)))
     :hints (("goal" :expand ((pseudo-term-count x))))
     :rule-classes :linear)
@@ -1346,6 +1400,41 @@ all the cases and all the accessors that can be used in each case.</p>
     :hints (("goal" :expand ((pseudo-term-list-count (cons x y)))))
     :rule-classes :linear))
 
+(define pair-vars ((vars symbol-listp) vals)
+  :guard (equal (len vars) (len vals))
+  :returns (subst alistp)
+  (if (atom vars)
+      nil
+    (if (and (mbt (symbolp (car vars))) (car vars))
+        (cons (cons (car vars) (car vals))
+              (pair-vars (cdr vars) (cdr vals)))
+      (pair-vars (cdr vars) (cdr vals))))
+  ///
+  (defthm lookup-in-pair-vars
+    (implies (pseudo-var-p v)
+             (equal (cdr (hons-assoc-equal v (pair-vars vars vals)))
+                    (cdr (hons-assoc-equal v (pairlis$ vars vals)))))
+    :hints(("Goal" :in-theory (enable pairlis$))))
+
+  (defthm assoc-in-pair-vars
+    (implies (pseudo-var-p v)
+             (equal (cdr (assoc v (pair-vars vars vals)))
+                    (cdr (assoc v (pairlis$ vars vals)))))
+    :hints(("Goal" :in-theory (enable pairlis$))))
+
+  (defthm-base-ev-flag
+    (defthm base-ev-of-pair-vars
+      (equal (base-ev x (pair-vars vars vals))
+             (base-ev x (pairlis$ vars vals)))
+      :hints('(:in-theory (enable base-ev-of-nonsymbol-atom
+                                  base-ev-of-bad-fncall
+                                  base-ev-of-fncall-args)))
+      :flag base-ev)
+    (defthm base-ev-list-of-pair-vars
+      (equal (base-ev-list x (pair-vars vars vals))
+             (base-ev-list x (pairlis$ vars vals)))
+      :flag base-ev-list)))
+
 
 (defxdoc def-ev-pseudo-term-fty-support
   :parents (pseudo-term-fty)
@@ -1358,22 +1447,12 @@ operates over FTY-style pseudo-term accessors and constructors:</p>
  @({
  (def-ev-pseudo-term-fty-support my-eval my-eval-list)
  })
-<p>This requires that several of the rules introduced by @('defevaluator') are enabled, including three that are not enabled by default.  For evaluators introduced using the @(':namedp t') defevaluator option, those not enabled by default are:</p>
- @({
-  my-eval-of-fncall-args
-  my-eval-of-nonsymbol-atom
-  my-eval-of-bad-fncall
- })
-<p>For those introduced without @(':namedp t'), they are:</p>
- @({
-  my-eval-constraint-0
-  my-eval-constraint-6
-  my-eval-constraint-7
- })
 ")
 
 (defconst *def-ev-pseudo-term-fty-support-template*
-  '(progn
+  '(encapsulate nil
+     (local (in-theory (enable . <disabled-ev-rules>)))
+
      (def-ev-pseudo-term-congruence <ev> <ev-list>)
 
      (defthm <ev>-when-pseudo-term-null
@@ -1419,11 +1498,12 @@ operates over FTY-style pseudo-term accessors and constructors:</p>
                               (base-ev-list <ev-list>))))))
 
      (defthm <ev>-when-pseudo-term-fncall
-       (implies (equal (pseudo-term-kind x) :fncall)
+       (implies (and (equal (pseudo-term-kind x) :fncall)
+                     (equal new-x (cons (pseudo-term-fncall->fn x)
+                                        (pseudo-term-call->args x)))
+                     (syntaxp (not (equal new-x x))))
                 (equal (<ev> x a)
-                       (<ev> (cons (pseudo-term-fncall->fn x)
-                                   (pseudo-term-call->args x))
-                             a)))
+                       (<ev> new-x a)))
        :hints (("goal" :use ((:functional-instance base-ev-when-pseudo-term-fncall
                               (base-ev <ev>)
                               (base-ev-list <ev-list>))))))
@@ -1451,7 +1531,7 @@ operates over FTY-style pseudo-term accessors and constructors:</p>
        :hints (("goal" :use ((:functional-instance base-ev-of-pseudo-term-lambda
                               (base-ev <ev>)
                               (base-ev-list <ev-list>))))))
-
+     
      (defthmd <ev>-of-pseudo-term-call
        (implies (syntaxp (not (equal a ''nil)))
                 (equal (<ev> (pseudo-term-call fn args) a)
@@ -1459,34 +1539,75 @@ operates over FTY-style pseudo-term accessors and constructors:</p>
                                                (kwote-lst (<ev-list> args a)))
                              nil)))
        :hints (("goal" :use ((:functional-instance base-ev-of-pseudo-term-call
+                              (base-ev <ev>)
+                              (base-ev-list <ev-list>))))))
+
+     (defthmd <ev>-when-pseudo-term-call
+       (implies (and (or (equal (pseudo-term-kind x) :lambda)
+                         (equal (pseudo-term-kind x) :fncall))
+                     (syntaxp (not (and (consp x) (eq (car x) 'pseudo-term-call)))))
+                (equal (<ev> x a)
+                       (<ev> (pseudo-term-call (pseudo-term-call->fn x)
+                                               (kwote-lst
+                                                (<ev-list> (pseudo-term-call->args x) a)))
+                             nil)))
+       :hints (("goal" :use ((:functional-instance base-ev-when-pseudo-term-call
+                              (base-ev <ev>)
+                              (base-ev-list <ev-list>))))))
+
+     (defthm <ev>-of-pair-vars
+       (equal (<ev> x (pair-vars vars vals))
+              (<ev> x (pairlis$ vars vals)))
+       :hints (("goal" :use ((:functional-instance base-ev-of-pair-vars
+                              (base-ev <ev>)
+                              (base-ev-list <ev-list>))))))
+
+     (defthm <ev-list>-of-pair-vars
+       (equal (<ev-list> x (pair-vars vars vals))
+              (<ev-list> x (pairlis$ vars vals)))
+       :hints (("goal" :use ((:functional-instance base-ev-list-of-pair-vars
                               (base-ev <ev>)
                               (base-ev-list <ev-list>))))))))
 
-(defmacro def-ev-pseudo-term-fty-support (ev ev-list)
-  (acl2::template-subst
-   *def-ev-pseudo-term-fty-support-template*
-   :atom-alist `((<ev> . ,ev)
-                 (<ev-list> . ,ev-list))
-   :str-alist `(("<EV>" . ,(symbol-name ev))
-                ("<EV-LIST>" . ,(symbol-name ev-list)))
-   :pkg-sym ev))
+(defun def-ev-pseudo-term-fty-support-fn (ev ev-list world)
+  (declare (Xargs :mode :program))
+  (b* ((bad-fncall-rule (ev-find-bad-fncall-rule ev world))
+       (nonsymbol-atom-rule (ev-find-nonsymbol-atom-rule ev world))
+       (fncall-rule (ev-find-fncall-generic-rule ev world))
+       ((unless (and bad-fncall-rule nonsymbol-atom-rule fncall-rule))
+        (er hard? 'def-ev-pseudo-term-fty-support-fn
+            "Couldn't find the right rules to enable -- is ~x0 an evaluator?" ev)))
+    (acl2::template-subst
+     *def-ev-pseudo-term-fty-support-template*
+     :atom-alist `((<ev> . ,ev)
+                   (<ev-list> . ,ev-list)
+                   (<disabled-ev-rules> . ,(list fncall-rule bad-fncall-rule nonsymbol-atom-rule)))
+     :str-alist `(("<EV>" . ,(symbol-name ev))
+                  ("<EV-LIST>" . ,(symbol-name ev-list)))
+     :pkg-sym ev)))
 
+(defmacro def-ev-pseudo-term-fty-support (ev ev-list)
+  `(make-event
+    (def-ev-pseudo-term-fty-support-fn ',ev ',ev-list (w state))))
+
+
+;; Alternative to kwote-lst that produces (pseudo-term-quote elt) instead of (list 'quote elt).
+(defthmd kwote-lst-redef
+  (equal (kwote-lst x)
+         (if (atom x)
+             nil
+           (cons (pseudo-term-quote (car x))
+                 (kwote-lst (cdr x)))))
+  :hints(("Goal" :in-theory (enable pseudo-term-quote)))
+  :rule-classes :definition)
 
 
 (local
  (progn
    (defevaluator next-ev next-ev-lst ((if a b c) (return-last a b c) (equal x y)) :namedp t)
-   (encapsulate nil
-     (local (in-theory (enable next-ev-of-fncall-args
-                               next-ev-of-nonsymbol-atom
-                               next-ev-of-bad-fncall)))
-     (def-ev-pseudo-term-fty-support next-ev next-ev-lst))))
+   (def-ev-pseudo-term-fty-support next-ev next-ev-lst)))
 
 (local
  (progn
    (defevaluator other-ev other-ev-lst ((if a b c) (return-last a b c) (equal x y)) :namedp nil)
-   (encapsulate nil
-     (local (in-theory (enable other-ev-constraint-0
-                               other-ev-constraint-6
-                               other-ev-constraint-7)))
-     (def-ev-pseudo-term-fty-support other-ev other-ev-lst))))
+   (def-ev-pseudo-term-fty-support other-ev other-ev-lst)))
