@@ -2,7 +2,7 @@
 ; Unify-subst.lisp: Term unification and substitution functions, and theorems
 ; for reasoning about them.
 
-; Copyright (C) 2010 Centaur Technology
+; Copyright (C) 2010-2018 Centaur Technology
 ;
 ; Contact:
 ;   Centaur Technology Formal Verification Group
@@ -50,13 +50,14 @@
 ;; for your evaluator, list-evaluator, and alist-evaluator.  You'll probably
 ;; also want to prove a lemma corresponding to assoc-equal-unify-ev-alist.
 
-(include-book "std/util/defines" :dir :system)
+(include-book "term-vars")
 (include-book "tools/def-functional-instance" :dir :system)
 (include-book "ev-find-rules")
 (include-book "meta/pseudo-termp-lemmas" :dir :system)
 
 (defevaluator unify-ev unify-ev-lst
-  ((cons a b) (binary-+ a b)))
+  ((cons a b) (binary-+ a b))
+  :namedp t)
 
 (define unify-ev-alist (x al)
   :verify-guards nil
@@ -100,21 +101,21 @@
 
 
 
-(define symbol-<-merge ((x symbol-listp)
-                        (y symbol-listp))
-  :measure (+ (len x) (len y))
-  :returns (merge symbol-listp :hyp :guard)
-  (b* (((when (atom x)) y)
-       ((when (atom y)) x)
-       ((when (equal (car x) (car y)))
-        (cons (car x) (symbol-<-merge (cdr x) (cdr y))))
-       ((when (symbol-< (car x) (car y)))
-        (cons (car x) (symbol-<-merge (cdr x) y))))
-    (cons (car y) (symbol-<-merge x (cdr y))))
-  ///
-  (defthm member-symbol-<-merge
-    (iff (member v (symbol-<-merge x y))
-         (or (member v x) (member v y)))))
+;; (define symbol-<-merge ((x symbol-listp)
+;;                         (y symbol-listp))
+;;   :measure (+ (len x) (len y))
+;;   :returns (merge symbol-listp :hyp :guard)
+;;   (b* (((when (atom x)) y)
+;;        ((when (atom y)) x)
+;;        ((when (equal (car x) (car y)))
+;;         (cons (car x) (symbol-<-merge (cdr x) (cdr y))))
+;;        ((when (symbol-< (car x) (car y)))
+;;         (cons (car x) (symbol-<-merge (cdr x) y))))
+;;     (cons (car y) (symbol-<-merge x (cdr y))))
+;;   ///
+;;   (defthm member-symbol-<-merge
+;;     (iff (member v (symbol-<-merge x y))
+;;          (or (member v x) (member v y)))))
 
 (define all-keys-bound (keys (alist alistp))
   (if (atom keys)
@@ -131,11 +132,12 @@
     (implies (all-keys-bound keys alist)
              (all-keys-bound keys (unify-ev-alist alist a))))
 
-  (defthm all-keys-bound-of-symbol-<-merge
-    (equal (all-keys-bound (symbol-<-merge x y) alist)
+  (defthm all-keys-bound-of-union-eq
+    (equal (all-keys-bound (union-eq x y) alist)
            (and (all-keys-bound x alist)
                 (all-keys-bound y alist)))
-    :hints(("Goal" :in-theory (enable symbol-<-merge))))
+    :hints(("Goal" :in-theory (enable union-eq)
+            :induct (len x))))
 
   (defthm all-keys-bound-of-cons
     (equal (all-keys-bound (cons x y) a)
@@ -149,85 +151,26 @@
   (defthm all-keys-bound-of-nil
     (all-keys-bound nil x)))
 
-(local (defthm true-listp-when-symbol-listp
-         (implies (symbol-listp x)
-                  (true-listp x))))
 
-(defines simple-term-vars
-  :verify-guards nil
-  :flag-local nil
-  (define simple-term-vars ((x pseudo-termp))
-    :returns (vars symbol-listp :hyp :guard)
-    (cond ((null x) nil)
-          ((atom x) (list x))
-          ((eq (car x) 'quote) nil)
-          (t (simple-term-vars-lst (cdr x)))))
-  (define simple-term-vars-lst ((x pseudo-term-listp))
-    :returns (vars symbol-listp :hyp :guard)
-    (if (atom x)
-        nil
-      (symbol-<-merge (simple-term-vars (car x))
-                      (simple-term-vars-lst (cdr x)))))
-  ///
+(local (in-theory (enable unify-ev-of-nonsymbol-atom)))
 
-  (verify-guards simple-term-vars)
-
-
-  (defthm-simple-term-vars-flag
-    (defthm unify-ev-of-acons-when-all-vars-bound
-      (implies (and (all-keys-bound (simple-term-vars x) a)
-                    (not (assoc k a))
-                    (pseudo-termp x))
-               (equal (unify-ev x (cons (cons k v) a))
-                      (unify-ev x a)))
-      :hints ((and stable-under-simplificationp
-                   '(:in-theory (enable unify-ev-constraint-0))))
-      :flag simple-term-vars)
-    (defthm unify-ev-lst-of-acons-when-all-vars-bound
-      (implies (and (all-keys-bound (simple-term-vars-lst x) a)
-                    (not (assoc k a))
-                    (pseudo-term-listp x))
-               (equal (unify-ev-lst x (cons (cons k v) a))
-                      (unify-ev-lst x a)))
-      :flag simple-term-vars-lst))
-
-  (defthm simple-term-vars-lst-of-atom
-    (implies (not (consp x))
-             (equal (simple-term-vars-lst x) nil))
-    :rule-classes ((:rewrite :backchain-limit-lst 0)))
-
-  
-  (defthm true-listp-of-symbol-<-merge
-    (implies (and (true-listp x)
-                  (true-listp y))
-             (true-listp (symbol-<-merge x y)))
-    :hints(("Goal" :in-theory (enable symbol-<-merge))))
-
-  (defthm-simple-term-vars-flag
-    (defthm true-listp-of-simple-term-vars
-      (true-listp (simple-term-vars x))
-      :hints ((and stable-under-simplificationp
-                   '(:expand ((simple-term-vars x)))))
-      :flag simple-term-vars
-      :rule-classes :type-prescription)
-    (defthm true-listp-of-simple-term-vars-lst
-      (true-listp (simple-term-vars-lst x))
-      :hints ((and stable-under-simplificationp
-                   '(:expand ((simple-term-vars-lst x)))))
-      :flag simple-term-vars-lst
-      :rule-classes :type-prescription))
-
-  (defthm-simple-term-vars-flag
-    (defthm simple-term-vars-nonnil
-      (not (member nil (simple-term-vars x)))
-      :hints ((and stable-under-simplificationp
-                   '(:expand ((simple-term-vars x)))))
-      :flag simple-term-vars)
-    (defthm simple-term-vars-lst-nonnil
-      (not (member nil (simple-term-vars-lst x)))
-      :hints ((and stable-under-simplificationp
-                   '(:expand ((simple-term-vars-lst x)))))
-      :flag simple-term-vars-lst)))
+(defthm-simple-term-vars-flag
+  (defthm unify-ev-of-acons-when-all-vars-bound
+    (implies (and (all-keys-bound (simple-term-vars x) a)
+                  (not (assoc k a)))
+             (equal (unify-ev x (cons (cons k v) a))
+                    (unify-ev x a)))
+    :hints ('(:expand ((simple-term-vars x)))
+            (and stable-under-simplificationp
+                 '(:in-theory (enable unify-ev-of-fncall-args))))
+    :flag simple-term-vars)
+  (defthm unify-ev-lst-of-acons-when-all-vars-bound
+    (implies (and (all-keys-bound (simple-term-vars-lst x) a)
+                  (not (assoc k a)))
+             (equal (unify-ev-lst x (cons (cons k v) a))
+                    (unify-ev-lst x a)))
+    :hints ('(:expand ((simple-term-vars-lst x))))
+    :flag simple-term-vars-lst))
 
 
 (defines substitute-into-term
@@ -239,8 +182,9 @@
                            (pseudo-term-substp al))
                  :hints ((and stable-under-simplificationp
                               '(:expand ((pseudo-termp x))))))
-    (cond ((null x) nil)
-          ((atom x) (cdr (assoc-equal x al)))
+    (cond ((atom x)
+           (and x (mbt (symbolp x))
+                (cdr (assoc-equal x al))))
           ((eq (car x) 'quote) x)
           (t (cons (car x) (substitute-into-list (cdr x) al)))))
   (define substitute-into-list ((x pseudo-term-listp)
@@ -257,21 +201,16 @@
 
   (defthm-substitute-into-term-flag
     substitute-into-term-correct-lemma
-    (substitute-into-term
-     (implies
-      (pseudo-termp x)
+    (defthm substitute-into-term-correct
       (equal (unify-ev (substitute-into-term x subst) a)
-             (unify-ev x (unify-ev-alist subst a))))
-     :name substitute-into-term-correct)
-    (substitute-into-list
-     (implies
-      (pseudo-term-listp x)
-      (equal (unify-ev-lst (substitute-into-list x subst) a)
-             (unify-ev-lst x (unify-ev-alist subst a))))
-     :name substitute-into-list-correct)
-    :hints (("goal" :induct (substitute-into-term-flag flag x subst))
-            (and stable-under-simplificationp
-                 '(:in-theory (enable unify-ev-constraint-0)))))
+             (unify-ev x (unify-ev-alist subst a)))
+      :hints ((and stable-under-simplificationp
+                   '(:in-theory (enable unify-ev-of-fncall-args))))
+      :flag substitute-into-term)
+    (defthm substitute-into-list-correct
+     (equal (unify-ev-lst (substitute-into-list x subst) a)
+            (unify-ev-lst x (unify-ev-alist subst a)))
+     :flag substitute-into-list ))
 
   (defthm substitute-into-list-of-cons
     (equal (substitute-into-list (cons x y) a)
@@ -295,21 +234,21 @@
                                         (pseudo-term-substp alist)))
                         (equal (alistp al)
                                (alistp alist)))))
-  (cond ((null pat)
-         (if (eq const nil)
-             (mv t alist)
-           (mv nil alist)))
-        ((variablep pat)
-         (let ((pair (assoc pat alist)))
-           (if pair
-               (let ((term (cdr pair)))
-                 (if (and (quotep term)
-                          (consp (cdr term))
-                          (equal (unquote term) const)
-                          (null (cddr term)))
-                     (mv t alist)
-                   (mv nil alist)))
-             (mv t (cons (cons pat (kwote const)) alist)))))
+  (cond ((atom pat)
+         (if (and pat (mbt (symbolp pat)))
+             (let ((pair (assoc pat alist)))
+               (if pair
+                   (let ((term (cdr pair)))
+                     (if (and (quotep term)
+                              (consp (cdr term))
+                              (equal (unquote term) const)
+                              (null (cddr term)))
+                         (mv t alist)
+                       (mv nil alist)))
+                 (mv t (cons (cons pat (kwote const)) alist))))
+           (if (eq const nil)
+               (mv t alist)
+             (mv nil alist))))
         ((eq (car pat) 'quote)
          (if (equal (unquote pat) const)
              (mv t alist)
@@ -391,7 +330,6 @@
     (mv-let (ok subst)
       (unify-const pat const alist)
       (implies (and ok
-                    (pseudo-termp term2)
                     (all-keys-bound (simple-term-vars term2) alist))
                (equal (unify-ev term2 (unify-ev-alist subst a))
                       (unify-ev term2 (unify-ev-alist alist a))))))
@@ -400,7 +338,6 @@
     (mv-let (ok subst)
       (unify-const pat const alist)
       (implies (and ok
-                    (pseudo-term-listp term2)
                     (all-keys-bound (simple-term-vars-lst term2) alist))
                (equal (unify-ev-lst term2 (unify-ev-alist subst a))
                       (unify-ev-lst term2 (unify-ev-alist alist a))))))
@@ -409,13 +346,12 @@
   (defthm unify-const-correct
     (mv-let (ok subst)
       (unify-const pat const alist)
-      (implies (and ok
-                    (pseudo-termp pat))
+      (implies (and ok)
                (equal (unify-ev pat (unify-ev-alist subst a))
                       const)))
     :hints (("goal" :induct t)
             (and stable-under-simplificationp
-                 '(:in-theory (enable unify-ev-constraint-0)))))
+                 '(:in-theory (enable unify-ev-of-fncall-args)))))
 
   (defthm unify-const-vars-nonnil
     (implies (not (assoc nil alist))
@@ -423,6 +359,7 @@
 
 
 
+
 (defines simple-one-way-unify
   :flag-local nil
   :verify-guards nil
@@ -434,18 +371,18 @@
                     :hyp (and (pseudo-termp term)
                               (pseudo-termp pat)
                               (pseudo-term-substp alist))))
-    (cond ((null pat)
-           (if (or (eq term nil)
-                   (equal term *nil*))
-               (mv t alist)
-             (mv nil alist)))
-          ((atom pat)
-           (let ((pair (assoc-equal pat alist)))
-             (if pair
-                 (if (equal term (cdr pair))
-                     (mv t alist)
-                   (mv nil alist))
-               (mv t (cons (cons pat term) alist)))))
+    (cond ((atom pat)
+           (if (and pat (mbt (symbolp pat)))
+               (let ((pair (assoc-equal pat alist)))
+                 (if pair
+                     (if (equal term (cdr pair))
+                         (mv t alist)
+                       (mv nil alist))
+                   (mv t (cons (cons pat term) alist))))
+             (if (or (eq term nil)
+                     (equal term *nil*))
+                 (mv t alist)
+               (mv nil alist))))
           ((atom term)
            (mv nil alist))
           ((eq (car pat) 'quote)
@@ -638,7 +575,6 @@
       (mv-let (ok subst)
         (simple-one-way-unify pat term alist)
         (implies (and ok
-                      (pseudo-termp term2)
                       (all-keys-bound (simple-term-vars term2) alist))
                  (equal (unify-ev term2 (unify-ev-alist subst a))
                         (unify-ev term2 (unify-ev-alist alist a)))))
@@ -649,7 +585,6 @@
       (mv-let (ok subst)
         (simple-one-way-unify-lst pat term alist)
         (implies (and ok
-                      (pseudo-termp term2)
                       (all-keys-bound (simple-term-vars term2) alist))
                  (equal (unify-ev term2 (unify-ev-alist subst a))
                         (unify-ev term2 (unify-ev-alist alist a)))))
@@ -661,7 +596,6 @@
       (mv-let (ok subst)
         (simple-one-way-unify pat term alist)
         (implies (and ok
-                      (pseudo-term-listp term2)
                       (all-keys-bound (simple-term-vars-lst term2) alist))
                  (equal (unify-ev-lst term2 (unify-ev-alist subst a))
                         (unify-ev-lst term2 (unify-ev-alist alist a)))))
@@ -672,7 +606,6 @@
       (mv-let (ok subst)
         (simple-one-way-unify-lst pat term alist)
         (implies (and ok
-                      (pseudo-term-listp term2)
                       (all-keys-bound (simple-term-vars-lst term2) alist))
                  (equal (unify-ev-lst term2 (unify-ev-alist subst a))
                         (unify-ev-lst term2 (unify-ev-alist alist a)))))
@@ -683,22 +616,18 @@
     (defthm simple-one-way-unify-correct
       (mv-let (ok subst)
         (simple-one-way-unify pat term alist)
-        (implies (and ok
-                      (pseudo-termp term)
-                      (pseudo-termp pat))
+        (implies (and ok)
                  (equal (unify-ev pat (unify-ev-alist subst a))
                         (unify-ev term a))))
       :hints ('(:expand ((:free (term) (simple-one-way-unify pat term alist))
                          (:free (term) (simple-one-way-unify nil term alist))))
               (and stable-under-simplificationp
-                   '(:in-theory (enable unify-ev-constraint-0))))
+                   '(:in-theory (enable unify-ev-of-fncall-args))))
       :flag simple-one-way-unify)
     (defthm simple-one-way-unify-lst-correct
       (mv-let (ok subst)
         (simple-one-way-unify-lst pat term alist)
-        (implies (and ok
-                      (pseudo-term-listp term)
-                      (pseudo-term-listp pat))
+        (implies (and ok)
                  (equal (unify-ev-lst pat (unify-ev-alist subst a))
                         (unify-ev-lst term a))))
       :hints ('(:expand (simple-one-way-unify-lst pat term alist)))
@@ -868,9 +797,7 @@
                               `(mv-nth '0 (simple-one-way-unify ,pat ,term ,alist))
                               '(unify-ev unify-ev-lst unify-ev-alist)
                               mfc state)
-                             (envs))
-                  (pseudo-termp term)
-                  (pseudo-termp pat))
+                             (envs)))
              (iff ok
                   (and (unify-succeeded pat term alist)
                        (unify-ev-simple-one-way-unify-equalities
@@ -989,9 +916,7 @@
                                    `(mv-nth '0 (simple-one-way-unify ,pat ,term ,alist))
                                    '(new-ev new-ev-lst new-ev-alist)
                                    mfc state)
-                                  (envs))
-                       (pseudo-termp term)
-                       (pseudo-termp pat))
+                                  (envs)))
                   (iff ok
                        (and (unify-succeeded pat term alist)
                             (new-ev-simple-one-way-unify-equalities
@@ -1158,9 +1083,7 @@
 (defthm simple-one-way-unify-usage-for-id-nest-ev
   (mv-let (ok subst)
     (simple-one-way-unify template term alist)
-    (implies (and ok
-                  (pseudo-termp term)
-                  (pseudo-termp template))
+    (implies (and ok)
              (equal (id-nest-ev term a)
                     (id-nest-ev template (id-nest-ev-alist subst a)))))
   :hints (("goal" :use ((:functional-instance
@@ -1172,9 +1095,8 @@
                '(:in-theory (enable id-nest-ev-constraint-0)))))
 
 (defthm nest-of-ids-meta-correct
-  (implies (pseudo-termp term)
-           (equal (id-nest-ev term a)
-                  (id-nest-ev (nest-of-ids-meta term) a))))
+  (equal (id-nest-ev term a)
+         (id-nest-ev (nest-of-ids-meta term) a)))
 
 
 
