@@ -31,7 +31,7 @@
 ;; diverge.lisp
 ;; Divergence relations for lists
 
-(in-package "PATH")
+(in-package "CPATH")
 (include-book "dominates")
 (include-book "../bags/basic")
 (local (include-book "../util/iff"))
@@ -1105,4 +1105,4 @@
 ;; (defthm all-diverge-implies-unequal-extensions
 ;;   (implies (all-diverge (list x y))
 ;;            (not (equal (append x a)
-;;                        (append y b)))))
\ No newline at end of file
+;;                        (append y b)))))
