@@ -42,7 +42,7 @@
 
 (in-package "ACL2")
 
-(include-book "misc/eval" :dir :system)
+(include-book "std/testing/eval" :dir :system)
 
 (defconst *initial-number-to-square* 8)
 
