@@ -6,7 +6,7 @@
 (include-book "matrix-multiplication-serial")
 ||#
 
-(include-book "misc/assert" :dir :system)
+(include-book "std/testing/assert" :dir :system)
 (include-book "make-event/embeddable-event-forms" :dir :system)
 (include-book "matrix-multiplication-setup")
 
