@@ -30,7 +30,7 @@
 (in-package "ACL2")
 
 (include-book "std/util/bstar" :dir :system)
-(include-book "kestrel/utilities/symbols" :dir :system)
+(include-book "kestrel/std/basic/symbol-package-name-non-cl" :dir :system)
 
 (local (include-book "pattern-matching-ext-support"))
 
@@ -80,7 +80,7 @@
                         (coerce (explode-nonnegative-integer n 10 nil)
                                 'string)
                         "}")
-           (symbol-package-name-safe root-var)))
+           (symbol-package-name-non-cl root-var)))
 
 (defun ext-maybe-rename-formal (root-var var avoid-vars n)
   (declare (xargs :mode :program))
