@@ -1,6 +1,6 @@
-; Bitcoin -- Base58 Encoding and Decoding -- Tests
+; Bitcoin Library
 ;
-; Copyright (C) 2019 Kestrel Institute (http://www.kestrel.edu)
+; Copyright (C) 2020 Kestrel Institute (http://www.kestrel.edu)
 ;
 ; License: A 3-clause BSD license. See the LICENSE file distributed with ACL2.
 ;
@@ -10,7 +10,7 @@
 
 (in-package "BITCOIN")
 
-(include-book "kestrel/utilities/testing" :dir :system)
+(include-book "std/testing/assert-equal" :dir :system)
 (include-book "base58")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
