@@ -1,4 +1,4 @@
-; Bitcoin -- Base58 Encoding and Decoding
+; Bitcoin Library
 ;
 ; Copyright (C) 2019 Kestrel Institute (http://www.kestrel.edu)
 ;
@@ -10,6 +10,7 @@
 
 (in-package "BITCOIN")
 
+(include-book "kestrel/std/util/deffixer" :dir :system)
 (include-book "kestrel/utilities/lists/index-of-theorems" :dir :system)
 (include-book "std/util/defval" :dir :system)
 
@@ -40,13 +41,14 @@
 (defval *base58-characters*
   :short "List of characters used in Base58 encoding."
   :long
-  "<p>
-   These characters are listed in the table in
-   <a href=\"https://en.bitcoin.it/wiki/Base58Check_encoding#Base58_symbol_chart\"
-   >Section `Base58 symbol chart' of Page `Base58Check encoding' of [Wiki]</a>,
-   along with their corresponding values in base 58.
-   This list is ordered according to increasing values.
-   </p>"
+  (xdoc::topstring
+   (xdoc::p
+    "These characters are listed in the table in "
+    (xdoc::a
+     :href "https://en.bitcoin.it/wiki/Base58Check_encoding#Base58_symbol_chart"
+      "Section `Base58 symbol chart' of Page `Base58Check encoding' of [Wiki]")
+    ", along with their corresponding values in base 58.
+     This list is ordered according to increasing values."))
   (explode "123456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnopqrstuvwxyz")
   ///
 
@@ -59,9 +61,8 @@
 (defval *base58-zero*
   :short "Character that encodes 0 in the Base58 encoding."
   :long
-  "<p>
-   This is the first character of @(tsee *base58-characters*).
-   </p>"
+  (xdoc::topstring-p
+   "This is the first character of @(tsee *base58-characters*).")
   (car *base58-characters*)
   ///
 
@@ -81,20 +82,17 @@
              (characterp x))
     :rule-classes :compound-recognizer))
 
-(define base58-character-fix ((x base58-characterp))
-  :returns (fixed-x base58-characterp)
+(std::deffixer base58-character-fix
+  :pred base58-characterp
+  :body-fix *base58-zero*
   :parents (base58-character)
-  :short "Fixer for @(tsee base58-character)."
-  (mbe :logic (if (base58-characterp x) x *base58-zero*)
-       :exec x)
-  ///
+  :short "Fixer for @(tsee base58-character).")
 
-  (more-returns
-   (fixed-x characterp :rule-classes :type-prescription))
-
-  (defrule base58-character-fix-when-base58-characterp
-    (implies (base58-characterp x)
-             (equal (base58-character-fix x) x))))
+(defsection base58-character-fix-ext
+  :extension base58-character-fix
+  (defret characterp-of-base58-character-fix
+    (characterp fixed-x)
+    :rule-classes :type-prescription))
 
 (defsection base58-character
   :short "Base58 characters."
@@ -114,6 +112,7 @@
   :short "True lists of Base58 characters."
   :elt-type base58-character
   :true-listp t
+  :elementp-of-nil nil
   :pred base58-character-listp
   ///
 
@@ -189,6 +188,7 @@
   :short "True lists of Base58 values."
   :elt-type base58-value
   :true-listp t
+  :elementp-of-nil nil
   :pred base58-value-listp
   ///
 
