@@ -1,4 +1,4 @@
-; Ethereum -- RLP Decodability
+; Ethereum Library
 ;
 ; Copyright (C) 2019 Kestrel Institute (http://www.kestrel.edu)
 ;
@@ -225,8 +225,8 @@
        (if (or (rlp-tree-case x :leaf)
                (rlp-tree-case y :leaf))
            (cons x y)
-         (tree-list (rlp-tree-nonleaf->subtrees x)
-                    (rlp-tree-nonleaf->subtrees y)))
+         (tree-list (rlp-tree-branch->subtrees x)
+                    (rlp-tree-branch->subtrees y)))
        :measure (rlp-tree-count x))
      (define tree-list (xs ys)
        (declare (xargs :measure (rlp-tree-list-count xs)))
@@ -379,10 +379,14 @@
   :long
   (xdoc::topstring
    (xdoc::p
-    "This actually subsumes the injectivity property,
-     because every enconding is a prefix of itself.
-     We do a case split on whether the two encodings have the same length
-     (in which case the injectivity theorem applies),
+    "This is expressed by saying that
+     if a valid encoding is a prefix of another one,
+     the two encodings must be equal.
+     Thus, it is not possible for a valid encoding
+     to be a strict prefix of another valid encoding.")
+   (xdoc::p
+    "We do a case split on whether the two encodings have the same length
+     (in which case the prefix relationship implies equality),
      or not.
      In the latter case,
      we show that in fact the two encodings must have the same length
@@ -479,7 +483,7 @@
    (xdoc::p
     "This easily follows from the analogous property for byte arrays."))
 
-  (defrule rlp-encode-scalar-no-prefix
+  (defrule rlp-encode-scalar-unamb-prefix
     (implies (and (not (mv-nth 0 (rlp-encode-scalar x)))
                   (not (mv-nth 0 (rlp-encode-scalar y))))
              (equal (prefixp (mv-nth 1 (rlp-encode-scalar x))
