@@ -1,6 +1,6 @@
-; Ethereum -- RLP Decoding Executable Definitions
+; Ethereum Library
 ;
-; Copyright (C) 2019 Kestrel Institute (http://www.kestrel.edu)
+; Copyright (C) 2020 Kestrel Institute (http://www.kestrel.edu)
 ;
 ; License: A 3-clause BSD license. See the LICENSE file distributed with ACL2.
 ;
@@ -66,63 +66,55 @@
   :parents (rlp-decoding-executable)
   :short "Possible errors when parsing or decoding RLP encodings."
   :long
-  "<p>
-   These values provide information about the reason why
-   an RLP encoding is erroneous and cannot be parsed or decoded.
-   </p>
-   <p>
-   The @(':no-bytes') error occurs
-   when starting to parse or decode a (sub)tree but no bytes are available.
-   </p>
-   <p>
-   The @(':fewer-bytes-than-...') errors occur when,
-   after successfully reading a length,
-   there are fewer bytes available than the required length.
-   The length may be a short length (i.e. below 56, part of the first byte),
-   the length of a long length (i.e. between 1 and 8, part of the first byte),
-   or a long length (i.e. a big endian length).
-   In these errors, the @('fragment') field consists of the first byte,
-   possibly followed by the big endian length bytes as applicable.
-   </p>
-   <p>
-   The @(':leading-zeros-in-long-length') errors occurs when
-   a long length has leading zeros.
-   See the discussion in @(tsee rlp-parse-tree).
-   The @('fragment') field consists of the first byte
-   followed by the big endian length.
-   </p>
-   <p>
-   The @(':non-optimal-...') errors occur when
-   the encoding is longer than it must be.
-   See the discussion in @(tsee rlp-parse-tree).
-   The @('fragment') field consists of the first byte,
-   possibly followed by the big endian length bytes as applicable.
-   </p>
-   <p>
-   Since parsing and decoding are recursive,
-   errors from subtree encodings must be propagated upward,
-   because the supertree encodings are therefore erroneous.
-   The @(':error-in-subtree') errors propagate and wrap
-   the error from a subtree.
-   Note that this makes the definition of this fixtype of errors recursive.
-   </p>
-   <p>
-   The @(':extra-bytes') errors occur only in decoding, not in parsing.
-   Parsing always returns any remaining bytes as a result,
-   while decoding requires the input bytes to have the right length.
-   The @('bytes') field of these errors consists of the extra bytes.
-   </p>
-   <p>
-   The @(':non-leaf-tree') errors occur
-   when attempting to decode a byte array (i.e. a leaf tree)
-   results in a non-leaf tree instead.
-   The @('fragment') field contains the starting byte of the encoding.
-   </p>
-   <p>
-   The @(':leading-zeros-in-scalar') errors occur
-   when attempting to decode a scalar results in
-   a byte array with leading zeros.
-   </p>"
+  (xdoc::topstring
+   (xdoc::p
+    "These values provide information about the reason why
+     an RLP encoding is erroneous and cannot be parsed or decoded.")
+   (xdoc::p
+    "The @(':no-bytes') error occurs
+     when starting to parse or decode a (sub)tree but no bytes are available.")
+   (xdoc::p
+    "The @(':fewer-bytes-than-...') errors occur when,
+     after successfully reading a length,
+     there are fewer bytes available than the required length.
+     The length may be a short length (i.e. below 56, part of the first byte),
+     the length of a long length (i.e. between 1 and 8, part of the first byte),
+     or a long length (i.e. a big endian length).
+     In these errors, the @('fragment') field consists of the first byte,
+     possibly followed by the big endian length bytes as applicable.")
+   (xdoc::p
+    "The @(':leading-zeros-in-long-length') errors occurs when
+     a long length has leading zeros.
+     See the discussion in @(tsee rlp-parse-tree).
+     The @('fragment') field consists of the first byte
+     followed by the big endian length.")
+   (xdoc::p
+    "The @(':non-optimal-...') errors occur when
+     the encoding is longer than it must be.
+     See the discussion in @(tsee rlp-parse-tree).
+     The @('fragment') field consists of the first byte,
+     possibly followed by the big endian length bytes as applicable.")
+   (xdoc::p
+    "Since parsing and decoding are recursive,
+     errors from subtree encodings must be propagated upward,
+     because the supertree encodings are therefore erroneous.
+     The @(':error-in-subtree') errors propagate and wrap
+     the error from a subtree.
+     Note that this makes the definition of this fixtype of errors recursive.")
+   (xdoc::p
+    "The @(':extra-bytes') errors occur only in decoding, not in parsing.
+     Parsing always returns any remaining bytes as a result,
+     while decoding requires the input bytes to have the right length.
+     The @('bytes') field of these errors consists of the extra bytes.")
+   (xdoc::p
+    "The @(':branch-tree') errors occur
+     when attempting to decode a byte array (i.e. a leaf tree)
+     results in a branching tree instead.
+     The @('fragment') field contains the starting byte of the encoding.")
+   (xdoc::p
+    "The @(':leading-zeros-in-scalar') errors occur
+     when attempting to decode a scalar results in
+     a byte array with leading zeros."))
   (:no-bytes ())
   (:fewer-bytes-than-short-length ((fragment byte-list)
                                    (required nat)
@@ -138,7 +130,7 @@
   (:non-optimal-long-length ((fragment byte-list)))
   (:subtree ((error rlp-error)))
   (:extra-bytes ((bytes byte-list)))
-  (:non-leaf-tree ((fragment byte-list)))
+  (:branch-tree ((fragment byte-list)))
   (:leading-zeros-in-scalar ((bytes byte-list))))
 
 (fty::defoption maybe-rlp-error
@@ -182,7 +174,7 @@
      (i) the form @('(129 x)') is not used with @('x') below 128,
      (ii) a big endian length has no leading zeros, and
      (iii) a big endian length is not below 56.
-     Cases (ii) and (iii) apply to both leaf and non-leaf trees,
+     Cases (ii) and (iii) apply to both leaf and branching trees,
      while case (i) applies to leaf trees only.
      Without these extra checks, the decoder would accept
      not only all the valid encodings,
@@ -257,15 +249,10 @@
      for calls that ACL2's heuristics do not expand;
      note that there is an @(':expand') hint
      for each possible range of the first byte of the encoding,
-     except for the range below 128.
-     It also needs two instances of a theorem that relates
-     the length of the big endian lengths to the lengths themselves;
-     note that there are two instances,
-     one for leaf trees (i.e. byte arrays encoded with long lengths)
-     and one for non-leaf trees (i.e. subtrees encoded with long lengths).")
+     except for the range below 128.")
    (xdoc::p
     "@(tsee rlp-parse-tree) is right inverse of @(tsee rlp-encode-tree),
-     over the valid byte array encodings.
+     over the valid tree encodings.
      This implies that @(tsee rlp-parse-tree) accepts
      only valid encodings of tree:
      if it accepted an invalid encoding,
@@ -281,12 +268,7 @@
      concatenated with the reamining bytes from the decoding,
      is the initial input of the encoding (modulo fixing).
      The proof is by induction on the parsing functions.
-     It is not particularly difficult.
-     Similarly to the proof for left inverse,
-     it uses two instances of the theorem that relates
-     the length of the big endian lengths to the lengths themselves;
-     the two instances correspond to leaf and non-leaf trees
-     encoded with long lengths.")
+     It is not particularly difficult.")
    (xdoc::p
     "Without the extra checks for optimal lengths in the parser,
      the left inverse theorem would still be provable,
@@ -300,7 +282,7 @@
     :returns (mv (error? maybe-rlp-error-p)
                  (tree rlp-treep)
                  (rest byte-listp))
-    (b* ((encoding (mbe :logic (byte-list-fix encoding) :exec encoding))
+    (b* ((encoding (byte-list-fix encoding))
          (irrelevant (rlp-tree-leaf nil))
          ((when (endp encoding)) (mv (rlp-error-no-bytes) irrelevant nil))
          ((cons first encoding) encoding)
@@ -365,7 +347,7 @@
                (encoding (nthcdr len encoding))
                ((mv error? subtrees) (rlp-parse-tree-list subencoding))
                ((when error?) (mv (rlp-error-subtree error?) irrelevant nil)))
-            (mv nil (rlp-tree-nonleaf subtrees) encoding)))
+            (mv nil (rlp-tree-branch subtrees) encoding)))
          (lenlen (- first 247))
          ((when (< (len encoding) lenlen))
           (mv (rlp-error-fewer-bytes-than-length-of-length (list first)
@@ -396,7 +378,7 @@
          ((mv error? subtrees) (rlp-parse-tree-list subencoding))
          ((when error?)
           (mv (rlp-error-subtree error?) irrelevant nil)))
-      (mv nil (rlp-tree-nonleaf subtrees) encoding))
+      (mv nil (rlp-tree-branch subtrees) encoding))
     :measure (two-nats-measure (len encoding) 0)
     :no-function t)
 
@@ -480,8 +462,6 @@
                       (:free (x y) (rlp-parse-tree (cons (+ 192 x) y)))
                       (:free (x y) (rlp-parse-tree (cons (+ 247 x) y)))))))
 
-
-
   (defthm-rlp-parse-tree-flag
 
     (defthm rlp-encode-tree-of-rlp-parse-tree
@@ -493,7 +473,7 @@
                              (byte-list-fix encoding)))))
       :flag rlp-parse-tree)
 
-    (defthm rlp-encode-tree-list-of-rl-decode-tree-list-exec
+    (defthm rlp-encode-tree-list-of-rlp-parse-tree-list
       (b* (((mv d-error? trees) (rlp-parse-tree-list encoding))
            ((mv e-error? encoding1) (rlp-encode-tree-list trees)))
         (implies (not d-error?)
@@ -680,7 +660,7 @@
   (b* (((mv error? tree) (rlp-decodex-tree encoding))
        ((when error?) (mv error? nil))
        ((unless (rlp-tree-case tree :leaf))
-        (mv (rlp-error-non-leaf-tree (list (car encoding))) nil))
+        (mv (rlp-error-branch-tree (list (car encoding))) nil))
        (bytes (rlp-tree-leaf->bytes tree)))
     (mv nil bytes))
   :hooks (:fix)
