@@ -1,6 +1,6 @@
-; Ethereum -- RLP Encoding
+; Ethereum Library
 ;
-; Copyright (C) 2019 Kestrel Institute (http://www.kestrel.edu)
+; Copyright (C) 2020 Kestrel Institute (http://www.kestrel.edu)
 ;
 ; License: A 3-clause BSD license. See the LICENSE file distributed with ACL2.
 ;
@@ -10,11 +10,12 @@
 
 (in-package "ETHEREUM")
 
-(include-book "kestrel/utilities/define-sk" :dir :system)
-
 (include-book "big-endian")
 (include-book "trees")
 
+(include-book "kestrel/fty/deffixequiv-sk" :dir :system)
+(include-book "kestrel/utilities/define-sk" :dir :system)
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (defxdoc+ rlp-encoding
@@ -133,7 +134,7 @@
      and @($s$) [YP:(184)].
      More precisely,
      @(tsee rlp-encode-tree) corresponds to @($\\mathtt{RLP}$),
-     the non-leaf case of @(tsee rlp-encode-tree)
+     the branching case of @(tsee rlp-encode-tree)
      corresponds to @($R_{\\mathrm{l}}$),
      and @(tsee rlp-encode-tree-list) corresponds to @($s$).")
    (xdoc::p
@@ -150,9 +151,9 @@
     "The first byte of the encoding of a leaf tree is always below 192:
      see theorems @('car-of-rlp-encode-tree-leaf-upper-bound-when-no-error')
      and @('rlp-encode-tree-car-ineq-to-tree-leaf').
-     The first byte of the encoding of a non-leaf tree is always at least 192:
+     The first byte of the encoding of a branching tree is always at least 192:
      see theorems @('car-of-rlp-encode-tree-leaf-upper-bound-when-no-error')
-     and @('rlp-encode-tree-car-ineq-to-tree-nonleaf').")
+     and @('rlp-encode-tree-car-ineq-to-tree-branch').")
    (xdoc::p
     "The total length of an encoding can be determined
      from the first few bytes (i.e. a prefix) of the encoding:
@@ -188,19 +189,19 @@
     (rlp-tree-case
      tree
      :leaf (rlp-encode-bytes tree.bytes)
-     :nonleaf (b* (((mv error? encoding) (rlp-encode-tree-list tree.subtrees))
-                   ((when error?) (mv t nil)))
-                (cond ((< (len encoding) 56)
-                       (b* ((encoding (cons (+ 192 (len encoding))
-                                            encoding)))
-                         (mv nil encoding)))
-                      ((< (len encoding)
-                          (expt 2 64))
-                       (b* ((be (nat=>bebytes* (len encoding)))
-                            (encoding (cons (+ 247 (len be))
-                                            (append be encoding))))
-                         (mv nil encoding)))
-                      (t (mv t nil)))))
+     :branch (b* (((mv error? encoding) (rlp-encode-tree-list tree.subtrees))
+                  ((when error?) (mv t nil)))
+               (cond ((< (len encoding) 56)
+                      (b* ((encoding (cons (+ 192 (len encoding))
+                                           encoding)))
+                        (mv nil encoding)))
+                     ((< (len encoding)
+                         (expt 2 64))
+                      (b* ((be (nat=>bebytes* (len encoding)))
+                           (encoding (cons (+ 247 (len be))
+                                           (append be encoding))))
+                        (mv nil encoding)))
+                     (t (mv t nil)))))
     :measure (rlp-tree-count tree)
     :no-function t)
 
@@ -240,9 +241,9 @@
                  191))
     :rule-classes :linear)
 
-  (defrule car-of-rlp-encode-tree-nonleaf-upper-bound-when-no-error
+  (defrule car-of-rlp-encode-tree-branch-upper-bound-when-no-error
     (implies (and (not (mv-nth 0 (rlp-encode-tree tree)))
-                  (rlp-tree-case tree :nonleaf))
+                  (rlp-tree-case tree :branch))
              (>= (car (mv-nth 1 (rlp-encode-tree tree)))
                  192))
     :rule-classes :linear
@@ -254,11 +255,11 @@
                         191)
                     (rlp-tree-case tree :leaf))))
 
-  (defrule rlp-encode-tree-car-ineq-to-tree-nonleaf
+  (defrule rlp-encode-tree-car-ineq-to-tree-branch
     (implies (not (mv-nth 0 (rlp-encode-tree tree)))
              (equal (>= (car (mv-nth 1 (rlp-encode-tree tree)))
                         192)
-                    (rlp-tree-case tree :nonleaf))))
+                    (rlp-tree-case tree :branch))))
 
   (defruled len-of-rlp-encode-tree-from-prefix
     (b* (((mv error? encoding) (rlp-encode-tree tree)))
@@ -361,15 +362,8 @@
   :skolem-name rlp-tree-encoding-witness
   ///
 
-  (fty::deffixequiv rlp-tree-encoding-p
-    :args ((encoding byte-listp))
-    :hints (("Goal"
-             :in-theory (disable rlp-tree-encoding-p-suff)
-             :use ((:instance rlp-tree-encoding-p-suff
-                    (tree (rlp-tree-encoding-witness (byte-list-fix encoding))))
-                   (:instance rlp-tree-encoding-p-suff
-                    (tree (rlp-tree-encoding-witness encoding))
-                    (encoding (byte-list-fix encoding)))))))
+  (fty::deffixequiv-sk rlp-tree-encoding-p
+    :args ((encoding byte-listp)))
 
   (defrule rlp-treep-of-rlp-tree-encoding-witness
     (implies (rlp-tree-encoding-p encoding)
@@ -419,16 +413,8 @@
   :skolem-name rlp-bytes-encoding-witness
   ///
 
-  (fty::deffixequiv rlp-bytes-encoding-p
-    :args ((encoding byte-listp))
-    :hints (("Goal"
-             :in-theory (disable rlp-bytes-encoding-p-suff)
-             :use ((:instance rlp-bytes-encoding-p-suff
-                    (bytes (rlp-bytes-encoding-witness
-                            (byte-list-fix encoding))))
-                   (:instance rlp-bytes-encoding-p-suff
-                    (bytes (rlp-bytes-encoding-witness encoding))
-                    (encoding (byte-list-fix encoding)))))))
+  (fty::deffixequiv-sk rlp-bytes-encoding-p
+    :args ((encoding byte-listp)))
 
   (defrule byte-listp-of-rlp-bytes-encoding-witness
     (implies (rlp-bytes-encoding-p encoding)
@@ -494,16 +480,8 @@
   :skolem-name rlp-scalar-encoding-witness
   ///
 
-  (fty::deffixequiv rlp-scalar-encoding-p
-    :args ((encoding byte-listp))
-    :hints (("Goal"
-             :in-theory (disable rlp-scalar-encoding-p-suff)
-             :use ((:instance rlp-scalar-encoding-p-suff
-                    (scalar (rlp-scalar-encoding-witness
-                             (byte-list-fix encoding))))
-                   (:instance rlp-scalar-encoding-p-suff
-                    (scalar (rlp-scalar-encoding-witness encoding))
-                    (encoding (byte-list-fix encoding)))))))
+  (fty::deffixequiv-sk rlp-scalar-encoding-p
+    :args ((encoding byte-listp)))
 
   (defrule natp-of-rlp-scalar-encoding-witness
     (implies (rlp-scalar-encoding-p encoding)
