@@ -1,6 +1,6 @@
-; Java -- ATJ
+; Java Library
 ;
-; Copyright (C) 2019 Kestrel Institute (http://www.kestrel.edu)
+; Copyright (C) 2020 Kestrel Institute (http://www.kestrel.edu)
 ;
 ; License: A 3-clause BSD license. See the LICENSE file distributed with ACL2.
 ;
@@ -12,3 +12,4 @@
 
 (include-book "documentation")
 (include-book "implementation")
+(include-book "tutorial")
