@@ -1,6 +1,6 @@
 ; Representation of Natural Numbers as Specific Digits in Specific Bases
 ;
-; Copyright (C) 2019 Kestrel Institute (http://www.kestrel.edu)
+; Copyright (C) 2020 Kestrel Institute (http://www.kestrel.edu)
 ;
 ; License: A 3-clause BSD license. See the LICENSE file distributed with ACL2.
 ;
@@ -10,9 +10,9 @@
 
 (in-package "ACL2")
 
-(include-book "kestrel/utilities/xdoc/defxdoc-plus" :dir :system)
 (include-book "std/util/defaggregate" :dir :system)
 (include-book "std/util/defval" :dir :system)
+(include-book "xdoc/defxdoc-plus" :dir :system)
 
 (include-book "core")
 
@@ -25,7 +25,7 @@
   :short
   (xdoc::topstring
    "Generate specialized versions of "
-   (xdoc::seeurl
+   (xdoc::seetopic
     "digits-any-base"
     "the operations to convert between natural numbers and digits")
    ", using specified recognizers and fixers for the digits.")
@@ -38,7 +38,7 @@
 
    (xdoc::p
     "The operations in the "
-    (xdoc::seeurl
+    (xdoc::seetopic
      "digits-any-base"
      "library to convert between natural numbers and digits")
     " are parameterized over the base.
@@ -221,14 +221,13 @@
           recorded as a pair's value in the
           <see topic='@(url defdigits-table)'>@(tsee defdigits) table</see>."
   :long
-  "<p>
-   The name input of the @(tsee defdigits) call
-   is the key of the pair in the table.
-   Each field of this aggregate except the last two
-   corresponds to the input of @(tsee defdigits) with the same name.
-   The last two fields are the names of
-   two theorems generated by @(tsee defdigits).
-   </p>"
+  (xdoc::topstring-p
+   "The name input of the @(tsee defdigits) call
+    is the key of the pair in the table.
+    Each field of this aggregate except the last two
+    corresponds to the input of @(tsee defdigits) with the same name.
+    The last two fields are the names of
+    two theorems generated by @(tsee defdigits).")
   ((base dab-basep)
    (digits-pred symbolp)
    (digits-fix symbolp)
