@@ -1,6 +1,6 @@
 ; Error Checking
 ;
-; Copyright (C) 2018 Kestrel Institute (http://www.kestrel.edu)
+; Copyright (C) 2020 Kestrel Institute (http://www.kestrel.edu)
 ;
 ; License: A 3-clause BSD license. See the LICENSE file distributed with ACL2.
 ;
@@ -11,9 +11,9 @@
 (in-package "ACL2")
 
 (include-book "kestrel/utilities/system/numbered-names" :dir :system)
-(include-book "kestrel/utilities/symbol-true-list-alists" :dir :system)
 (include-book "kestrel/utilities/system/terms" :dir :system)
-(include-book "kestrel/utilities/xdoc/defxdoc-plus" :dir :system)
+(include-book "std/typed-alists/symbol-truelist-alistp" :dir :system)
+(include-book "xdoc/defxdoc-plus" :dir :system)
 
 (include-book "def-error-checker")
 
@@ -91,10 +91,10 @@
   (((symbol-alistp x)
     "~@0 must be an alist with symbols as keys." description)))
 
-(def-error-checker ensure-symbol-true-list-alist
+(def-error-checker ensure-symbol-truelist-alist
   ((x "Value to check."))
   "Cause an error if a value is not an alist from symbols to true lists."
-  (((symbol-true-list-alistp x)
+  (((symbol-truelist-alistp x)
     "~@0 must be an alist from symbols to true lists."
     description)))
 
