@@ -9,7 +9,7 @@
 (include-book "kestrel/utilities/er-soft-plus" :dir :system)
 
 (defxdoc orelse
-  :parents (system-utilities)
+  :parents (system-utilities-non-built-in)
   :short "Evaluate an event and, if it fails, then evaluate a second event"
   :long "<p>NOTE: Also see @(see orelse*) for a similar utility that allows any
  number of @(see events).</p>
@@ -18,9 +18,9 @@
  General Form:
 
  (orelse form1 form2
-         :quiet      q ; default nil
-         :no-error   n ; default nil
-         :expansion? e ; default t
+         :quiet       q ; default nil
+         :no-error    n ; default nil
+         :expansion?p e ; default t
  })
 
  <p>where @('form1') and @('form2') are @(see events) (see @(see
@@ -29,15 +29,15 @@
  that is, if the result is an @(see error-triple) @('(mv nil val state)')
  &mdash; then the @('orelse') call returns that error-triple.  Otherwise, it
  return the result of evaluating @('form2'), except that if that evaluation
- also fails and if @(':no-error') is @('nil') (the default), then evaluation
- concludes by submitting the event @('(value-triple :failed)').</p>
+ also fails and if @(':no-error') is non-@('nil'), then evaluation concludes by
+ submitting the event @('(value-triple :failed)').</p>
 
  <p>If @(':quiet') has a non-@('nil') value, then output is suppressed using
  @(tsee with-output) with argument @(':stack :push'), so that @('form1') and
  @('form2') may recover the original output environment using @('with-output')
  with argument @(':stack :pop').</p>
 
- <p>The sizes of @(see certificate) files may be reduced with @(':expansion?
+ <p>The sizes of @(see certificate) files may be reduced with @(':expansion?p
  t') (the default).  That argument avoids storing a @(tsee make-event)
  expansion for @('(orelse form1 form2 ...)') when evaluation of the first event
  form succeeds.</p>
@@ -46,23 +46,22 @@
  encapsulate-report-errors), that employs @('orelse').</p>")
 
 (defxdoc orelse*
-  :parents (system-utilities)
+  :parents (system-utilities-non-built-in)
   :short "Evaluate a sequence of @(see events), until one succeeds"
   :long "<p>@('Orelse*') behaves as described in the documentation for @(see
- orelse), except that @('orelse*') takes a list of forms, as shown below, and
- its default for @(':expansion?') is @('nil').</p>
+ orelse), except that @('orelse*') takes a list of forms.</p>
 
  @({
  General Form:
 
  (orelse* (form1 form2 ...)
-          :quiet      q ; default nil
-          :no-error   n ; default nil
-          :expansion? e ; default nil
+          :quiet       q ; default nil
+          :no-error    n ; default nil
+          :expansion?p e ; default t
  })")
 
 (defxdoc on-failure
-  :parents (system-utilities)
+  :parents (system-utilities-non-built-in)
   :short "Run an event, printing a custom error message if it fails."
   :long "
  @({
@@ -116,7 +115,7 @@
  @('books/kestrel/utilities/orelse.lisp').</p>")
 
 (defxdoc encapsulate-report-errors
-  :parents (system-utilities)
+  :parents (system-utilities-non-built-in)
   :short "Run @(tsee encapsulate), but with a helpful error at the first
  failure of one of its top-level events (if any)."
   :long "<p>This macro is equivalent to @(see encapsulate) except that it takes
@@ -167,7 +166,7 @@
                                 `(:expansion? ,(car form-list)))
                          :on-behalf-of :quiet!)))
     (cond (quiet `(with-output
-                    ,@(and quiet '(:stack :push))
+                    :stack :push
                     :gag-mode nil
                     :off :all
                     ,ev))
@@ -177,7 +176,7 @@
                   &key
                   quiet
                   no-error
-                  expansion?p)
+                  (expansion?p 't))
   (orelse-fn form-list quiet no-error expansion?p))
 
 (defmacro orelse (form1 form2
@@ -220,15 +219,24 @@
 ; event unless it's truly huge.
                       event
                       (evisc-tuple 12 12 nil nil)))))
-    `(orelse (with-output :stack :pop
+
+; It would be much simpler to use the following below:
+; (orelse ,event (fail-event ,ctx ,erp ,val ,msg))
+; The problem is that then output from make-event -- specifically, from its
+; summary -- can be printed.  The :stack :push from ORELSE by using :quiet t
+; prevents that, and the use of :stack :pop below (twice) undoes that ":push"
+; so that the ambient output environment is used for each event.
+
+    `(orelse (with-output :stack :pop ; see comment above for explanation
                ,event)
-             (with-output :stack :pop
+             (with-output :stack :pop ; see comment above for explanation
                (fail-event
                 ,ctx
                 ,erp ; erp
                 ,val ; val
                 ,msg))
-             :quiet t)))
+             :quiet t ; see comment above for explanation
+             )))
 
 ; Below is alternate code that takes advantage of the existing implementation
 ; of try-event.  It seems to me that the code above is a bit simpler; plus, it
@@ -261,7 +269,7 @@
 ||#
 
 (defxdoc identity-macro
-  :parents (system-utilities)
+  :parents (system-utilities-non-built-in)
   :short "The most trivial macro imaginable"
   :long "<p>@('(Identity-macro x)') macroexpands to @('x').</p>")
 
