@@ -1,6 +1,6 @@
 ; System Utilities -- Numbered Names
 ;
-; Copyright (C) 2018 Kestrel Institute (http://www.kestrel.edu)
+; Copyright (C) 2020 Kestrel Institute (http://www.kestrel.edu)
 ;
 ; License: A 3-clause BSD license. See the LICENSE file distributed with ACL2.
 ;
@@ -10,11 +10,11 @@
 
 (in-package "ACL2")
 
+(include-book "kestrel/std/system/pseudo-event-formp" :dir :system)
 (include-book "kestrel/utilities/strings/char-kinds" :dir :system)
 (include-book "std/strings/decimal" :dir :system)
 (include-book "std/util/defval" :dir :system)
 (include-book "system/kestrel" :dir :system)
-(include-book "event-forms")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -376,7 +376,9 @@
                            index-start-chars
                            index-or-wildcard-chars
                            index-end-chars)))
-    (intern-in-package-of-symbol (implode name-chars) base)))
+    (if (equal (symbol-package-name base) *main-lisp-package-name*)
+        (intern (implode name-chars) "ACL2")
+      (intern-in-package-of-symbol (implode name-chars) base))))
 
 (define set-numbered-name-index
   ((name symbolp) (index posp) (wrld plist-worldp))
