@@ -10,8 +10,9 @@
 
 (in-package "ACL2")
 
-(include-book "misc/assert" :dir :system)
-(include-book "misc/eval" :dir :system)
+(include-book "std/testing/assert" :dir :system)
+(include-book "std/testing/eval" :dir :system)
+(include-book "xdoc/constructors" :dir :system)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
@@ -19,11 +20,11 @@
   :parents (kestrel-utilities)
   :short "Utilities for testing that are part of the @(see kestrel-books)."
   :long
-  "<p>
-   The utilities that used to be here have been moved into
-   @('[books]/misc/eval.lisp') and @('[books]/misc/assert.lisp').
-   They can be found under the @(see testing-utilities) topic in the manual.
-   </p>
-   <p>
-   New utilities may be (perhaps temporarily) added here in the future.
-   </p>")
+  (xdoc::topstring
+   (xdoc::p
+    "The utilities that used to be here have been moved into
+     @('[books]/std/testing/eval.lisp') and
+     @('[books]/std/testing/assert.lisp').  They can be found under the @(see
+     std/testing) topic in the manual.")
+   (xdoc::p
+    "New utilities may be (perhaps temporarily) added here in the future.")))
