@@ -1,6 +1,6 @@
 ; Kestrel Utilities
 ;
-; Copyright (C) 2019 Kestrel Institute (http://www.kestrel.edu)
+; Copyright (C) 2020 Kestrel Institute (http://www.kestrel.edu)
 ;
 ; License: A 3-clause BSD license. See the LICENSE file distributed with ACL2.
 ;
@@ -11,9 +11,7 @@
 (in-package "ACL2")
 
 (include-book "acceptable-rewrite-rule-p")
-(include-book "alists/top")
 (include-book "apply-fn-if-known")
-(include-book "assert")
 (include-book "auto-instance")
 (include-book "auto-termination")
 (include-book "bits-as-digits")
@@ -23,20 +21,21 @@
 (include-book "copy-def")
 (include-book "define-sk")
 (include-book "defmacroq")
-(include-book "defmax-nat/top")
+(include-book "deftest")
 (include-book "defthmr")
 (include-book "digits-any-base/top")
 (include-book "directed-untranslate")
 (include-book "doublets")
 (include-book "enumerations")
+(include-book "erp")
 (include-book "er-soft-plus")
 (include-book "error-checking/top")
-(include-book "event-macros/top")
 (include-book "include-book-paths")
 (include-book "integer-arithmetic/top")
 (include-book "integer-range-fixing")
 (include-book "integer-range-lists")
 (include-book "integers-from-to")
+(include-book "integers-from-to-as-set")
 (include-book "keyword-value-lists")
 (include-book "lists/top")
 (include-book "magic-macroexpand")
@@ -58,9 +57,6 @@
 (include-book "skip-in-book")
 (include-book "strings/top")
 (include-book "sublis-expr-plus")
-(include-book "symbol-symbol-alists")
-(include-book "symbol-true-list-alists")
-(include-book "symbols")
 (include-book "system/top")
 (include-book "testing")
 (include-book "trans-eval-error-triple")
@@ -74,7 +70,6 @@
 (include-book "untranslate-preprocessing")
 (include-book "user-interface")
 (include-book "verify-guards-program")
-(include-book "xdoc/top")
 (include-book "zp-lists")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
