@@ -10,4 +10,4 @@
 
 (deflabel assert-include-label)
 
-(include-book "misc/assert" :dir :system)
+(include-book "std/testing/assert" :dir :system)
