@@ -332,7 +332,7 @@ sublis-fn.
 ;; use the must-succeed and must-fail macros.
 
 (local
- (include-book "misc/eval" :dir :system))
+ (include-book "std/testing/eval" :dir :system))
 
 ;; All the tests are marked local.  I do it this way rather than in comments
 ;; since I want to make sure that the tests execute when I certify the book,
