@@ -2,17 +2,17 @@
 ; Written by Matt Kaufmann (sometime before that)
 ; License: A 3-clause BSD license.  See the LICENSE file distributed with ACL2.
 
-; This was originally a modification of community book misc/eval.lisp that uses
-; :check-expansion t.  Now, misc/eval.lisp provides utilities with a
-; :check-expansion option, which is used in this file to create "!" versions of
-; the macros that check expansions, leave output on, and generally leave
-; ld-skip-proofsp alone, to obtain behavior originally (and still) tested in
-; eval-check-tests.lisp.  One can similarly define one's own "!" versions,
-; rather than including the present book.
+; This was originally a modification of community book misc/eval.lisp (now
+; std/testing/eval.lisp) that uses :check-expansion t.  Now, std/testing/eval.lisp
+; provides utilities with a :check-expansion option, which is used in this file
+; to create "!" versions of the macros that check expansions, leave output on,
+; and generally leave ld-skip-proofsp alone, to obtain behavior originally (and
+; still) tested in eval-check-tests.lisp.  One can similarly define one's own
+; "!" versions, rather than including the present book.
 
 (in-package "ACL2")
 
-(include-book "misc/eval" :dir :system)
+(include-book "std/testing/eval" :dir :system)
 (include-book "xdoc/top" :dir :system) ; redundant
 
 (defmacro must-eval-to! (form expr)
