@@ -12,8 +12,8 @@
 
 (in-package "ACL2")
 
-(include-book "assert")
-(include-book "eval")
+(include-book "std/testing/assert" :dir :system)
+(include-book "std/testing/eval" :dir :system)
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
