@@ -864,10 +864,17 @@
 				rcfn-find-zero-<=-z
 				rcfn-find-zero->=-z)))))
 
-(defthm x-outside-interval
-    (not (inside-interval-p x (interval (+ 1 x) (+ 2 x))))
-  :hints (("Goal"
-	   :in-theory (enable interval-definition-theory))))
+
+(local
+ (defthm rcfn-domain-non-trivial-direct
+   (implies (and (interval-left-endpoint (rcfn-domain))
+		 (interval-right-endpoint (rcfn-domain)))
+	    (< (interval-left-endpoint (rcfn-domain))
+	       (interval-right-endpoint (rcfn-domain))))
+   :hints (("Goal"
+	    :use ((:instance rcfn-domain-non-trivial))))
+   :rule-classes (:built-in-clause)))
+
 
 (defthm intermediate-value-theorem
    (implies (and (inside-interval-p a (rcfn-domain))
@@ -888,11 +895,12 @@
 ; Originally for "Subgoal 3", but deleted now:
 ;           :in-theory (disable subinterval-interval-closed-closed inside-trivial-interval)
 	    :use ((:functional-instance weak-intermediate-value-theorem
-					(rcfn-domain (lambda () (if (and (< a b)
-									   (inside-interval-p a (rcfn-domain))
-									   (inside-interval-p b (rcfn-domain)))
-								      (interval a b)
-								      (interval (+ 1 (realfix x)) (+ 2 (realfix x)))))))
+					(rcfn-domain (lambda ()
+						       (if (and (< a b)
+								(inside-interval-p a (rcfn-domain))
+								(inside-interval-p b (rcfn-domain)))
+							   (interval a b)
+							 (rcfn-domain)))))
                   (:instance inside-interval-p-contains-left-endpoint
 			     (interval (interval a b)))
 		  (:instance inside-interval-p-contains-right-endpoint
@@ -903,9 +911,7 @@
 			     (interval (rcfn-domain)))
 		  (:instance inside-trivial-interval
 			     (a y)
-			     (b x))
-                  (:instance rcfn-domain-non-trivial)))
-	   ))
+                             (b x))))))
 
 ;; Now, what happens when f(a)>z and f(b)<z.  First, we find the root.
 
@@ -1838,4 +1844,3 @@
 			    (x (is-minimum-point-witness a b (find-min-rcfn-x a b)))))
 	   :in-theory (disable achieves-minimum-point-suff
 			       find-min-rcfn-is-minimum))))
-
