@@ -6,5 +6,5 @@
 (include-book "ordinals/lexicographic-ordering-without-arithmetic" :dir :system)
 (include-book "tools/flag" :dir :system)
 (include-book "arithmetic-5/top" :dir :system)
-(include-book "misc/eval" :dir :system)
+(include-book "std/testing/eval" :dir :system)
 ||#
