@@ -4,7 +4,7 @@
 ;; ACL2.
 
 ;; Cuong Chau <ckcuong@cs.utexas.edu>
-;; November 2018
+;; May 2019
 
 (in-package "ADE")
 
@@ -29,7 +29,6 @@
 ;; generator.
 
 (defconst *alt-branch$go-num* 2)
-(defconst *alt-branch$st-len* 2)
 
 (defun alt-branch$data-ins-len (data-size)
   (declare (xargs :guard (natp data-size)))
@@ -133,8 +132,8 @@
 ;; Constraints on the state of ALT-BRANCH
 
 (defund alt-branch$valid-st (st)
-  (b* ((select (get-field *alt-branch$select* st))
-       (select-buf (get-field *alt-branch$select-buf* st)))
+  (b* ((select (nth *alt-branch$select* st))
+       (select-buf (nth *alt-branch$select-buf* st)))
     (and (link1$valid-st select)
          (link1$valid-st select-buf))))
 
@@ -165,11 +164,11 @@
 
          (go-alt-branch (nth 0 go-signals))
 
-         (select (get-field *alt-branch$select* st))
-         (select.s (get-field *link1$s* select))
-         (select.d (get-field *link1$d* select))
-         (select-buf (get-field *alt-branch$select-buf* st))
-         (select-buf.s (get-field *link1$s* select-buf))
+         (select (nth *alt-branch$select* st))
+         (select.s (nth *link1$s* select))
+         (select.d (nth *link1$d* select))
+         (select-buf (nth *alt-branch$select-buf* st))
+         (select-buf.s (nth *link1$s* select-buf))
 
          (m-full-in (f-and full-in (car select.s)))
          (m-empty-out0- (f-or3 empty-out0- (car select-buf.s) (car select.d))))
@@ -191,11 +190,11 @@
 
          (go-alt-branch (nth 0 go-signals))
 
-         (select (get-field *alt-branch$select* st))
-         (select.s (get-field *link1$s* select))
-         (select.d (get-field *link1$d* select))
-         (select-buf (get-field *alt-branch$select-buf* st))
-         (select-buf.s (get-field *link1$s* select-buf))
+         (select (nth *alt-branch$select* st))
+         (select.s (nth *link1$s* select))
+         (select.d (nth *link1$d* select))
+         (select-buf (nth *alt-branch$select-buf* st))
+         (select-buf.s (nth *link1$s* select-buf))
 
          (m-full-in (f-and full-in (car select.s)))
          (m-empty-out1- (f-or3 empty-out1-
@@ -258,12 +257,12 @@
 
        (go-buf (nth 1 go-signals))
 
-       (select (get-field *alt-branch$select* st))
-       (select.s (get-field *link1$s* select))
-       (select.d (get-field *link1$d* select))
-       (select-buf (get-field *alt-branch$select-buf* st))
-       (select-buf.s (get-field *link1$s* select-buf))
-       (select-buf.d (get-field *link1$d* select-buf))
+       (select (nth *alt-branch$select* st))
+       (select.s (nth *link1$s* select))
+       (select.d (nth *link1$d* select))
+       (select-buf (nth *alt-branch$select-buf* st))
+       (select-buf.s (nth *link1$s* select-buf))
+       (select-buf.d (nth *link1$d* select-buf))
 
        (act (alt-branch$act inputs st data-size))
        (buf-act (joint-act (car select-buf.s) (car select.s) go-buf))
@@ -276,10 +275,6 @@
      ;; Select-buf
      (link1$step select-buf-inputs select-buf))))
 
-(defthm len-of-alt-branch$step
-  (equal (len (alt-branch$step inputs st data-size))
-         *alt-branch$st-len*))
-
 ;; The state lemma for ALT-BRANCH
 
 (defthm alt-branch$state
@@ -361,8 +356,7 @@
            (alt-branch$valid-st
             (alt-branch$step inputs st data-size)))
   :hints (("Goal"
-           :in-theory (e/d (get-field
-                            f-sr
+           :in-theory (e/d (f-sr
                             alt-branch$input-format
                             alt-branch$valid-st
                             alt-branch$step
@@ -374,10 +368,10 @@
 ;; A state invariant
 
 (defund alt-branch$inv (st)
-  (b* ((select (get-field *alt-branch$select* st))
-       (select.s (get-field *link1$s* select))
-       (select-buf (get-field *alt-branch$select-buf* st))
-       (select-buf.s (get-field *link1$s* select-buf)))
+  (b* ((select (nth *alt-branch$select* st))
+       (select.s (nth *link1$s* select))
+       (select-buf (nth *alt-branch$select-buf* st))
+       (select-buf.s (nth *link1$s* select-buf)))
     (not (equal select.s select-buf.s))))
 
 (defthm alt-branch$inv-preserved
@@ -386,8 +380,7 @@
                 (alt-branch$inv st))
            (alt-branch$inv (alt-branch$step inputs st data-size)))
   :hints (("Goal"
-           :in-theory (e/d (get-field
-                            f-sr
+           :in-theory (e/d (f-sr
                             alt-branch$input-format
                             alt-branch$valid-st
                             alt-branch$inv
