@@ -1,10 +1,13 @@
 ;; Copyright (C) 2017, Regents of the University of Texas
-;; Written by Cuong Chau
+;; Written by Cuong Chau (derived from the FM9001 work of Brock and Hunt)
 ;; License: A 3-clause BSD license.  See the LICENSE file distributed with
 ;; ACL2.
 
+;; The ACL2 source code for the FM9001 work is available at
+;; https://github.com/acl2/acl2/tree/master/books/projects/fm9001.
+
 ;; Cuong Chau <ckcuong@cs.utexas.edu>
-;; December 2017
+;; March 2019
 
 (in-package "ADE")
 
@@ -82,12 +85,12 @@
     (and (booleanp (car x))
          (bvp (cdr x)))))
 
-(defthmd booleanp-car-of-bvp
+(defthmd booleanp-car-of-bv
   (implies (bvp x)
            (booleanp (car x)))
   :rule-classes :type-prescription)
 
-(defthmd nth-of-bvp-is-booleanp
+(defthmd nth-of-bv-is-boolean
   (implies (bvp x)
            (booleanp (nth n x)))
   :rule-classes :type-prescription)
@@ -103,7 +106,7 @@
            (bvp (nthcdr n x)))
   :rule-classes (:rewrite :type-prescription))
 
-(defthm bvp-repeat-of-booleanp
+(defthm bvp-repeat-of-boolean
   (implies (booleanp x)
            (bvp (repeat n x)))
   :hints (("Goal" :in-theory (enable bvp repeat)))
@@ -119,7 +122,7 @@
            (bvp (rev x)))
   :rule-classes (:rewrite :type-prescription))
 
-(defthm bvp-is-true-listp
+(defthm bv-is-true-list
   (implies (bvp x)
            (true-listp x)))
 
@@ -127,7 +130,7 @@
   (true-listp (make-list n :initial-element v))
   :rule-classes :type-prescription)
 
-(defthm bvp-make-list
+(defthm bvp-make-list-rewrite
   (equal (bvp (make-list n :initial-element v))
          (or (zp n) (booleanp v)))
   :hints (("Goal" :in-theory (enable repeat))))
@@ -271,6 +274,10 @@
   (declare (xargs :guard t))
   (and a b c (bool-fix d)))
 
+(defun b-and5 (a b c d e)
+  (declare (xargs :guard t))
+  (and a b c d (bool-fix e)))
+
 (defun b-nor (a b)
   (declare (xargs :guard t))
   (not (or a b)))
@@ -301,17 +308,20 @@
 
 ;; A boolean gate theory
 
-(deftheory b-gates
+(defconst *b-gates*
   '(b-buf
     b-not
     b-nand b-nand3 b-nand4 b-nand5 b-nand6 b-nand8
     b-or b-or3 b-or4 b-or5
     b-xor b-xor3 b-xnor
     b-equv b-equv3
-    b-and b-and3 b-and4
+    b-and b-and3 b-and4 b-and5
     b-nor b-nor3 b-nor4 b-nor5 b-nor6 b-nor8
     b-if))
 
+(deftheory b-gates
+  *b-gates*)
+
 ;; This lemma allows us to prove that specifications written in terms of
 ;; 4-valued gate-level functions (see below) are equivalent to Boolean
 ;; gate-level functions when the inputs are constrained to be Boolean, without
@@ -340,6 +350,7 @@
    (booleanp (b-and a b))
    (booleanp (b-and3 a b c))
    (booleanp (b-and4 a b c d))
+   (booleanp (b-and5 a b c d e))
    (booleanp (b-nor a b))
    (booleanp (b-nor3 a b c))
    (booleanp (b-nor4 a b c d))
@@ -679,6 +690,14 @@
     (cons (v-to-nat (car x))
           (v-to-nat-lst (cdr x)))))
 
+(defun v-to-nat2-lst (x)
+    (declare (xargs :guard (alistp x)))
+    (if (atom x)
+        nil
+      (cons (list (v-to-nat (caar x))
+                  (v-to-nat (cdar x)))
+            (v-to-nat2-lst (cdr x)))))
+
 (in-theory (disable v-to-nat))
 
 (defun bit->bool (x)
@@ -906,6 +925,12 @@
   (equal (len (v-adder-output c a b))
          (len a)))
 
+(defthm bvp-v-adder-output
+  (bvp (v-adder-output c a b))
+  :rule-classes (:rewrite :type-prescription))
+
+(in-theory (disable v-adder-output))
+
 (defun v-adder-carry-out (c a b)
   (declare (xargs :guard (true-listp b)))
   (nth (len a) (v-adder c a b)))
@@ -1010,6 +1035,14 @@
   (equal (car (v-threefix x))
          (3v-fix (car x))))
 
+(defthm cadr-v-threefix
+  (equal (cadr (v-threefix x))
+         (3v-fix (cadr x))))
+
+(defthm caddr-v-threefix
+  (equal (caddr (v-threefix x))
+         (3v-fix (caddr x))))
+
 (defthm append-v-threefix
   (equal (append (v-threefix a)
                  (v-threefix b))
@@ -1023,7 +1056,7 @@
   (equal (v-threefix (v-threefix x))
          (v-threefix x)))
 
-(defthm bvp-v-threefix
+(defthm bvp-of-v-threefix
   (implies (true-listp v)
            (equal (bvp (v-threefix v))
                   (bvp v)))
@@ -1043,6 +1076,13 @@
          (make-list n :initial-element *x*))
   :hints (("Goal" :in-theory (enable repeat))))
 
+(defthm v-or-of-v-threefix-canceled
+  (and (equal (v-or (v-threefix x) y)
+              (v-or x y))
+       (equal (v-or x (v-threefix y))
+              (v-or x y)))
+  :hints (("Goal" :in-theory (enable v-or))))
+
 ;; V-FOURFIX
 
 (defun v-fourfix (v)
