@@ -4,7 +4,7 @@
 ;; ACL2.
 
 ;; Cuong Chau <ckcuong@cs.utexas.edu>
-;; February 2019
+;; May 2019
 
 (in-package "ADE")
 
@@ -273,8 +273,6 @@
 
 ;; DE module of LINK1
 
-(defconst *link1$st-len* 2)
-
 (module-generator
  link1* ()
  'link1
@@ -313,8 +311,8 @@
 ;; Constraints on the state of LINK1
 
 (defun link1$valid-st (st)
-  (b* ((s (get-field *link1$s* st))
-       (d (get-field *link1$d* st)))
+  (b* ((s (nth *link1$s* st))
+       (d (nth *link1$d* st)))
     (and (validp s)
          (true-listp d)
          (equal (len d) 1)
@@ -326,8 +324,8 @@
 (defthm link1$value
   (b* ((fill$ (car inputs))
        (bit-in (caddr inputs))
-       (s (get-field *link1$s* st))
-       (d (get-field *link1$d* st)))
+       (s (nth *link1$s* st))
+       (d (nth *link1$d* st)))
     (implies (link1& netlist)
              (equal (se 'link1 inputs st netlist)
                     (list (f-buf (car s))
@@ -348,16 +346,12 @@
        (drain (nth 1 inputs))
        (bit-in (nth 2 inputs))
 
-       (s (get-field *link1$s* st))
-       (d (get-field *link1$d* st)))
+       (s (nth *link1$s* st))
+       (d (nth *link1$d* st)))
     (list
      (list (f-sr fill$ drain (car s)))
      (list (f-if fill$ bit-in (car d))))))
 
-(defthm len-of-link1$step
-  (equal (len (link1$step inputs st))
-         *link1$st-len*))
-
 ;; The state lemma for LINK1
 
 (defthm link1$state
@@ -372,14 +366,12 @@
                            ((link1*)
                             de-module-disabled-rules)))))
 
-;;(in-theory (disable link1$step))
+;; (in-theory (disable link1$step))
 
 ;; ======================================================================
 
 ;; DE module generator of LINK
 
-(defconst *link$st-len* 2)
-
 (defun link$ins-len (data-size)
   (declare (xargs :guard (natp data-size)))
   (+ 2 (mbe :logic (nfix data-size)
@@ -411,8 +403,8 @@
   (if (atom st)
       nil
     (b* ((link (car st)))
-      (if (fullp (get-field *link$s* link))
-          (cons (strip-cars (get-field *link$d* link))
+      (if (fullp (nth *link$s* link))
+          (cons (strip-cars (nth *link$d* link))
                 (extract-valid-data (cdr st)))
         (extract-valid-data (cdr st))))))
 
@@ -446,7 +438,7 @@
 ;; Constraints on the state of LINK
 
 (defun link$st-format (st data-size)
-  (b* ((d (get-field *link$d* st)))
+  (b* ((d (nth *link$d* st)))
     (and (len-1-true-listp d)
          (equal (len d) data-size))))
 
@@ -457,8 +449,8 @@
   :rule-classes :forward-chaining)
 
 (defun link$valid-st (st data-size)
-  (b* ((s (get-field *link$s* st))
-       (d (get-field *link$d* st)))
+  (b* ((s (nth *link$s* st))
+       (d (nth *link$d* st)))
     (and (link$st-format st data-size)
 
          (validp s) ;; The link status is either full or empty.
@@ -475,8 +467,8 @@
 (defthm link$value
   (b* ((fill$ (car inputs))
        (data-in (cddr inputs))
-       (s (get-field *link$s* st))
-       (d (get-field *link$d* st)))
+       (s (nth *link$s* st))
+       (d (nth *link$d* st)))
     (implies (and (link& netlist data-size)
                   (true-listp data-in)
                   (equal (len data-in) data-size)
@@ -500,17 +492,13 @@
        (data-in (take (nfix data-size)
                       (nthcdr 2 inputs)))
 
-       (s (get-field *link$s* st))
-       (d (get-field *link$d* st)))
+       (s (nth *link$s* st))
+       (d (nth *link$d* st)))
     (list
      (list (f-sr fill$ drain (car s)))
      (pairlis$ (fv-if fill$ data-in (strip-cars d))
                nil))))
 
-(defthm len-of-link$step
-  (equal (len (link$step inputs st data-size))
-         *link$st-len*))
-
 ;; The state lemma for LINK
 
 (defthm link$state
@@ -528,8 +516,6 @@
                             link*$destructure)
                            (de-module-disabled-rules)))))
 
-;;(in-theory (disable link$step))
-
 (defthm link$valid-st-preserved
   (implies (and (booleanp (nth 0 inputs))
                 (booleanp (nth 1 inputs))
@@ -539,7 +525,9 @@
                 (link$valid-st st data-size))
            (link$valid-st (link$step inputs st data-size)
                           data-size))
-  :hints (("Goal" :in-theory (enable get-field f-sr))))
+  :hints (("Goal" :in-theory (enable f-sr))))
+
+;; (in-theory (disable link$step))
 
 
 
