@@ -5,7 +5,7 @@
 
 ;; Warren A. Hunt, Jr. <hunt@cs.utexas.edu>
 ;; Cuong Chau <ckcuong@cs.utexas.edu>
-;; January 2019
+;; May 2019
 
 ; This collection of things we need to define ACL2 version of DUAL-EVAL.
 
@@ -1396,7 +1396,7 @@
           netlist
           (1- n))))
 
-(defthm de-m+n
+(defthm de-plus
   (implies (and (natp m)
                 (natp n))
            (equal (de-n fn inputs-seq st netlist (+ m n))
@@ -1445,7 +1445,6 @@
 
 (deftheory de-rules
   '(open-nth
-    get-field
     len-1-true-listp=>true-listp
     nthcdr-of-pos-const-idx
     md-name md-ins md-outs md-st md-occs
@@ -1465,6 +1464,7 @@
     no-duplicatesp-eq
     nth
     nthcdr
+    nthcdr-of-nthcdr
     prefixp-of-cons-left
     prefixp-when-equal-lengths
     str::iprefixp-of-cons-left
@@ -1474,3 +1474,4 @@
     take-of-take-split
     take-of-too-many
     v-threefix))
+
