@@ -66,7 +66,7 @@
 
 ;; Page 36 of the FAT specification states that a directory shouldn't have more
 ;; than 65536 entries. However, *ms-max-dir-ent-count* below is used for the
-;; definition of m1-bounded-file-alist-p, and since that's applicable to our
+;; definition of hifat-bounded-file-alist-p, and since that's applicable to our
 ;; internal representation of the filesystem, we need to leave room for two
 ;; entries (dot and dotdot) to be added when we store a directory in the stobj
 ;; representation. However, *ms-max-dir-size* is applicable to extracting
@@ -165,8 +165,16 @@
 (defthm
   fat32-entry-fix-correctness-1
   (and (<= 0 (fat32-entry-fix x))
-       (< (fat32-entry-fix x) (ash 1 32)))
-  :rule-classes :linear
+       (< (fat32-entry-fix x) (ash 1 32))
+       (integerp (fat32-entry-fix x)))
+  :rule-classes
+  ((:linear
+    :corollary
+    (and (<= 0 (fat32-entry-fix x))
+         (< (fat32-entry-fix x) (ash 1 32))))
+   (:type-prescription
+    :corollary
+    (integerp (fat32-entry-fix x))))
   :hints
   (("goal" :in-theory (enable fat32-entry-fix fat32-entry-p))))
 
@@ -188,16 +196,14 @@
                  :fix    fat32-entry-fix
                  :equiv  fat32-entry-equiv
                  :define t
-                 :forward t
-                 )
+                 :forward t)
 
 (fty::deffixtype fat32-masked-entry
                  :pred   fat32-masked-entry-p
                  :fix    fat32-masked-entry-fix
                  :equiv  fat32-masked-entry-equiv
                  :define t
-                 :forward t
-                 )
+                 :forward t)
 
 (fty::deflist fat32-entry-list :elt-type fat32-entry-p :true-listp t)
 
@@ -296,10 +302,21 @@
   :hints (("goal" :in-theory (enable fat32-entry-p)))
   :rule-classes :forward-chaining)
 
-(defthm fat32-entry-p-of-nth
-  (implies (and (fat32-entry-list-p l)
-                (< (nfix n) (len l)))
-           (fat32-entry-p (nth n l))))
+(encapsulate
+  ()
+
+  (local (include-book "arithmetic-5/top" :dir :system))
+
+  (local
+   (defthm fat32-entry-p-of-nth-lemma-1
+     (equal (< (+ -1 n) (len (cdr l)))
+            (< n (+ 1 (len (cdr l)))))))
+
+  (defthm fat32-entry-p-of-nth
+    (implies (fat32-entry-list-p l)
+             (equal (fat32-entry-p (nth n l))
+                    (< (nfix n) (len l))))
+    :hints (("Goal" :in-theory (disable nth-when->=-n-len-l)))))
 
 (defund
   fat32-update-lower-28
@@ -311,17 +328,25 @@
       :in-theory (enable fat32-entry-p fat32-masked-entry-p)))
     :guard (and (fat32-entry-p entry)
                 (fat32-masked-entry-p masked-entry))))
-  (logapp 28 masked-entry (logtail 28 entry)))
+  (logapp 28 masked-entry
+          (logtail 28
+                   (mbe :exec entry
+                        :logic (fat32-entry-fix entry)))))
 
 (defthm
   fat32-update-lower-28-correctness-1
-  (implies
-   (and (fat32-entry-p entry)
-        (fat32-masked-entry-p masked-entry))
-   (fat32-entry-p (fat32-update-lower-28 entry masked-entry)))
-  :hints
-  (("goal"
-    :in-theory (e/d (fat32-update-lower-28 fat32-entry-p) (unsigned-byte-p logapp logtail)))))
+  (implies (fat32-masked-entry-p masked-entry)
+           (fat32-entry-p (fat32-update-lower-28 entry masked-entry)))
+  :hints (("goal" :in-theory (e/d (fat32-update-lower-28 fat32-entry-p)
+                                  (logapp logtail))))
+  :rule-classes
+  (:rewrite
+   (:rewrite
+    :corollary
+    (implies (fat32-masked-entry-p masked-entry)
+             (unsigned-byte-p 32
+                              (fat32-update-lower-28 entry masked-entry)))
+    :hints (("goal" :in-theory (enable fat32-entry-p))))))
 
 (defthm
   fat32-entry-mask-of-fat32-update-lower-28
@@ -341,8 +366,15 @@
    (equal (fat32-update-lower-28 (fat32-update-lower-28 entry masked-entry1)
                                  masked-entry2)
           (fat32-update-lower-28 entry masked-entry2)))
-  :hints (("goal" :in-theory (e/d (fat32-update-lower-28)
-                                  (logapp logtail)))))
+  :hints
+  (("goal"
+    :in-theory (e/d (fat32-update-lower-28)
+                    (logapp logtail
+                            (:rewrite fat32-update-lower-28-correctness-1
+                                      . 1)))
+    :use (:instance (:rewrite fat32-update-lower-28-correctness-1 . 1)
+                    (masked-entry masked-entry1)
+                    (entry entry)))))
 
 (defthmd
   fat32-update-lower-28-of-fat32-entry-mask
@@ -366,7 +398,7 @@
            (not (fat32-is-eof fat-content)))
   :hints (("Goal" :in-theory (enable fat32-is-eof)) ))
 
-(defun
+(defund
   fat32-build-index-list
   (fa-table masked-current-cluster
             length cluster-size)
@@ -404,17 +436,18 @@
     (mv (list* masked-current-cluster tail-index-list)
         tail-error)))
 
-(defthm fat32-build-index-list-correctness-1
+(defthm bounded-nat-listp-of-fat32-build-index-list
   (implies (and (equal b (len fa-table))
                 (fat32-masked-entry-p masked-current-cluster)
                 (< masked-current-cluster (len fa-table)))
            (b* (((mv index-list &)
                  (fat32-build-index-list fa-table masked-current-cluster
                                          length cluster-size)))
-             (bounded-nat-listp index-list b))))
+             (bounded-nat-listp index-list b)))
+  :hints (("Goal" :in-theory (enable fat32-build-index-list))))
 
 (defthm
-  fat32-build-index-list-correctness-2
+  fat32-masked-entry-list-p-of-fat32-build-index-list
   (implies
    (and
     (fat32-masked-entry-p masked-current-cluster)
@@ -423,10 +456,11 @@
    (b* (((mv index-list &)
          (fat32-build-index-list fa-table masked-current-cluster
                                  length cluster-size)))
-     (fat32-masked-entry-list-p index-list))))
+     (fat32-masked-entry-list-p index-list)))
+  :hints (("Goal" :in-theory (enable fat32-build-index-list))))
 
 (defthm
-  fat32-build-index-list-correctness-4
+  fat32-build-index-list-of-update-nth
   (implies
    (and (<= *ms-first-data-cluster*
             masked-current-cluster)
@@ -435,29 +469,25 @@
      (index-list error-code)
      (fat32-build-index-list fa-table masked-current-cluster
                              length cluster-size)
-     (implies
-      (and (not (member-equal key index-list))
-           (< (nfix key) (len fa-table))
-           (equal error-code 0))
-      (equal
-       (fat32-build-index-list (update-nth key val fa-table)
-                               masked-current-cluster
-                               length cluster-size)
-       (fat32-build-index-list fa-table masked-current-cluster
-                               length cluster-size)))))
+     (declare (ignore error-code))
+     (implies (and (not (member-equal key index-list))
+                   (< (nfix key) (len fa-table)))
+              (equal (fat32-build-index-list (update-nth key val fa-table)
+                                             masked-current-cluster
+                                             length cluster-size)
+                     (fat32-build-index-list fa-table masked-current-cluster
+                                             length cluster-size)))))
   :hints
-  (("goal"
-    :induct
-    (fat32-build-index-list fa-table masked-current-cluster
-                            length cluster-size)
-    :in-theory (disable nth update-nth)
-    :expand
-    (fat32-build-index-list (update-nth key val fa-table)
-                            masked-current-cluster
-                            length cluster-size))))
+  (("goal" :induct (fat32-build-index-list fa-table masked-current-cluster
+                                           length cluster-size)
+    :in-theory (e/d (fat32-build-index-list)
+                    (nth update-nth))
+    :expand (fat32-build-index-list (update-nth key val fa-table)
+                                    masked-current-cluster
+                                    length cluster-size))))
 
 (defthm
-  fat32-build-index-list-correctness-5
+  lower-bounded-integer-listp-of-fat32-build-index-list
   (implies
    (and (fat32-masked-entry-p masked-current-cluster)
         (<= *ms-first-data-cluster*
@@ -469,7 +499,7 @@
                              length cluster-size))
     *ms-first-data-cluster*))
   :hints
-  (("goal" :in-theory (enable lower-bounded-integer-listp))))
+  (("goal" :in-theory (enable fat32-build-index-list))))
 
 (defthm
   true-listp-of-fat32-build-index-list
@@ -477,7 +507,90 @@
     (mv-nth
      0
      (fat32-build-index-list fa-table masked-current-cluster
-                             length cluster-size))))
+                             length cluster-size)))
+  :hints
+  (("goal" :in-theory (enable fat32-build-index-list))))
+
+(defun count-free-clusters-helper (fa-table n)
+  (declare (xargs :guard (and (fat32-entry-list-p fa-table)
+                              (natp n)
+                              (>= (len fa-table) n))
+                  :guard-hints (("Goal" :in-theory (disable nth)) )))
+  (if
+      (zp n)
+      0
+    (if
+        (not (equal (fat32-entry-mask (nth (- n 1) fa-table)) 0))
+        (count-free-clusters-helper fa-table (- n 1))
+      (+ 1 (count-free-clusters-helper fa-table (- n 1))))))
+
+(defthm
+  count-free-clusters-helper-of-update-nth-1
+  (implies (not (equal (fat32-entry-mask val) 0))
+           (equal (count-free-clusters-helper (update-nth key val fa-table)
+                                              n)
+                  (if (and (< (nfix key) (nfix n))
+                           (equal (fat32-entry-mask (nth key fa-table))
+                                  0))
+                      (- (count-free-clusters-helper fa-table n)
+                         1)
+                      (count-free-clusters-helper fa-table n))))
+  :hints (("goal" :in-theory (disable update-nth))))
+
+(defthm
+  count-free-clusters-helper-of-update-nth-2
+  (implies (equal (fat32-entry-mask val) 0)
+           (equal (count-free-clusters-helper (update-nth key val fa-table)
+                                              n)
+                  (if (and (< (nfix key) (nfix n))
+                           (not (equal (fat32-entry-mask (nth key fa-table))
+                                       0)))
+                      (+ (count-free-clusters-helper fa-table n)
+                         1)
+                      (count-free-clusters-helper fa-table n))))
+  :hints (("goal" :in-theory (disable update-nth))))
+
+(defthm count-free-clusters-helper-correctness-1
+  (<= (count-free-clusters-helper fa-table n)
+      (nfix n))
+  :rule-classes :linear)
+
+(defund
+  count-free-clusters (fa-table)
+  (declare
+   (xargs :guard (and (fat32-entry-list-p fa-table)
+                      (>= (len fa-table)
+                          *ms-first-data-cluster*))
+          :guard-hints (("goal" :in-theory (disable nth)))))
+  (count-free-clusters-helper
+   (nthcdr *ms-first-data-cluster* fa-table)
+   (- (len fa-table)
+      *ms-first-data-cluster*)))
+
+(defthm count-free-clusters-of-update-nth
+  (implies (and (<= *ms-first-data-cluster* (nfix key))
+                (< (nfix key) (len fa-table)))
+           (equal (count-free-clusters (update-nth key val fa-table))
+                  (cond ((and (equal (fat32-entry-mask (nth key fa-table))
+                                     0)
+                              (not (equal (fat32-entry-mask val) 0)))
+                         (- (count-free-clusters fa-table) 1))
+                        ((and (equal (fat32-entry-mask val) 0)
+                              (not (equal (fat32-entry-mask (nth key fa-table))
+                                          0)))
+                         (+ (count-free-clusters fa-table) 1))
+                        (t (count-free-clusters fa-table)))))
+  :hints (("goal" :in-theory (enable count-free-clusters))))
+
+(defthm
+  count-free-clusters-correctness-1
+  (implies (>= (len fa-table)
+               *ms-first-data-cluster*)
+           (<= (count-free-clusters fa-table)
+               (- (len fa-table)
+                  *ms-first-data-cluster*)))
+  :rule-classes :linear
+  :hints (("goal" :in-theory (enable count-free-clusters))))
 
 (defund
   find-n-free-clusters-helper
@@ -551,21 +664,18 @@
 
 (defthm
   find-n-free-clusters-helper-correctness-6
-  (implies (and (fat32-entry-list-p fa-table)
-                (natp n)
-                (natp start))
-           (no-duplicatesp-equal
-            (find-n-free-clusters-helper fa-table n start)))
+  (implies
+   (and (fat32-entry-list-p fa-table)
+        (natp start))
+   (no-duplicatesp-equal (find-n-free-clusters-helper fa-table n start)))
   :hints
   (("goal" :in-theory (enable find-n-free-clusters-helper))
-   ("goal'"
-    :induct (find-n-free-clusters-helper fa-table n start))
-   ("subgoal *1/11"
-    :use (:instance find-n-free-clusters-helper-correctness-3
-                    (x start)
-                    (fa-table (cdr fa-table))
-                    (n (- n 1))
-                    (start (+ 1 start))))))
+   ("goal'" :induct (find-n-free-clusters-helper fa-table n start))
+   ("subgoal *1/9" :use (:instance find-n-free-clusters-helper-correctness-3
+                                   (x start)
+                                   (fa-table (cdr fa-table))
+                                   (n (- n 1))
+                                   (start (+ 1 start))))))
 
 (defthm
   find-n-free-clusters-helper-correctness-7
@@ -616,13 +726,60 @@
       (nth m
            (find-n-free-clusters-helper fa-table n start)))))))
 
-(defthm
-  len-of-find-n-free-clusters-helper
-  (<= (len (find-n-free-clusters-helper fa-table n start))
-      (nfix n))
-  :rule-classes :linear
-  :hints
-  (("goal" :in-theory (enable find-n-free-clusters-helper))))
+
+(encapsulate
+  ()
+
+  (local
+   (defthm
+     len-of-find-n-free-clusters-helper-lemma-1
+     (implies
+      (consp fa-table)
+      (equal
+       (len (find-n-free-clusters-helper fa-table n start))
+       (if
+           (and
+            (<
+             (len (find-n-free-clusters-helper (take (- (len fa-table) 1) fa-table)
+                                               n start))
+             (nfix n))
+            (equal (fat32-entry-mask (nth (- (len fa-table) 1) fa-table))
+                   0))
+           (+ (len (find-n-free-clusters-helper (take (- (len fa-table) 1) fa-table)
+                                                n start))
+              1)
+         (len (find-n-free-clusters-helper (take (- (len fa-table) 1) fa-table)
+                                           n start)))))
+     :hints (("goal" :in-theory (enable find-n-free-clusters-helper)
+              :induct (find-n-free-clusters-helper fa-table n start)
+              :expand (len (cdr fa-table))))))
+
+  (local
+   (defthm
+     len-of-find-n-free-clusters-helper-lemma-2
+     (<= (len (find-n-free-clusters-helper fa-table n start))
+         (nfix n))
+     :rule-classes :linear
+     :hints
+     (("goal" :in-theory (enable find-n-free-clusters-helper)))))
+
+  (defthm
+    len-of-find-n-free-clusters-helper
+    (equal (len (find-n-free-clusters-helper (take n2 fa-table)
+                                             n1 start))
+           (min (count-free-clusters-helper fa-table n2)
+                (nfix n1)))
+    :hints
+    (("goal" :in-theory (enable find-n-free-clusters-helper
+                                len-of-find-n-free-clusters-helper-lemma-1)))
+    :rule-classes
+    (:rewrite
+     (:linear
+      :corollary
+      (<= (len (find-n-free-clusters-helper fa-table n start))
+          (nfix n))))))
+
+(in-theory (disable (:linear len-of-find-n-free-clusters-helper)))
 
 (defund
     find-n-free-clusters (fa-table n)
@@ -745,14 +902,9 @@
            (x (nth n2
                    (find-n-free-clusters fa-table n1))))))))
 
-(defthm
-  find-n-free-clusters-correctness-6
-  (implies
-   (and (fat32-entry-list-p fa-table)
-        (>= (len fa-table)
-            *ms-first-data-cluster*)
-        (natp n))
-   (no-duplicatesp-equal (find-n-free-clusters fa-table n)))
+(defthm find-n-free-clusters-correctness-6
+  (implies (fat32-entry-list-p fa-table)
+           (no-duplicatesp-equal (find-n-free-clusters fa-table n)))
   :hints (("goal" :in-theory (enable find-n-free-clusters))))
 
 (defthm
@@ -760,8 +912,8 @@
   (integer-listp (find-n-free-clusters fa-table n)))
 
 (defthm find-n-free-clusters-correctness-7
-  (implies (< (nfix m)
-              (len (find-n-free-clusters fa-table n)))
+  (implies (force (< (nfix m)
+                     (len (find-n-free-clusters fa-table n))))
            (and (<= *ms-first-data-cluster*
                     (nth m (find-n-free-clusters fa-table n)))
                 (< (nth m (find-n-free-clusters fa-table n))
@@ -769,12 +921,34 @@
   :rule-classes :linear
   :hints (("goal" :in-theory (e/d (find-n-free-clusters) (nth)))))
 
+(defthm
+  find-n-free-clusters-helper-of-true-list-fix
+  (equal (find-n-free-clusters-helper (true-list-fix fa-table)
+                                      n start)
+         (find-n-free-clusters-helper fa-table n start))
+  :hints
+  (("goal" :in-theory (enable find-n-free-clusters-helper))))
+
 (defthm
   len-of-find-n-free-clusters
-  (<= (len (find-n-free-clusters fa-table n))
-      (nfix n))
-  :rule-classes :linear
-  :hints (("goal" :in-theory (enable find-n-free-clusters))))
+  (equal (len (find-n-free-clusters fa-table n))
+         (min (count-free-clusters fa-table)
+              (nfix n)))
+  :hints (("goal" :in-theory (e/d (count-free-clusters find-n-free-clusters)
+                                  (nthcdr len-of-find-n-free-clusters-helper))
+           :use (:instance len-of-find-n-free-clusters-helper
+                           (n2 (len (nthcdr 2 fa-table)))
+                           (fa-table (nthcdr 2 fa-table))
+                           (n1 n)
+                           (start 2))))
+  :rule-classes
+  (:rewrite
+   (:linear
+    :corollary
+    (<= (len (find-n-free-clusters fa-table n))
+        (nfix n)))))
+
+(in-theory (disable (:linear len-of-find-n-free-clusters)))
 
 (defthmd
   fat32-masked-entry-list-p-alt
@@ -930,31 +1104,26 @@
   :hints (("goal" :in-theory (enable fat32-masked-entry-p))))
 
 (defthm
-  fat32-build-index-list-correctness-6
+  fat32-build-index-list-of-set-indices-disjoint
   (implies
    (and
     (natp masked-current-cluster)
     (nat-listp index-list)
-    (not
-     (intersectp-equal
-      (mv-nth
-       0
-       (fat32-build-index-list fa-table masked-current-cluster
-                               length cluster-size))
-      index-list)))
-   (equal
-    (fat32-build-index-list
-     (set-indices-in-fa-table fa-table index-list value-list)
-     masked-current-cluster
-     length cluster-size)
-    (fat32-build-index-list fa-table masked-current-cluster
-                            length cluster-size)))
+    (not (intersectp-equal
+          (mv-nth 0
+                  (fat32-build-index-list fa-table masked-current-cluster
+                                          length cluster-size))
+          index-list)))
+   (equal (fat32-build-index-list
+           (set-indices-in-fa-table fa-table index-list value-list)
+           masked-current-cluster
+           length cluster-size)
+          (fat32-build-index-list fa-table masked-current-cluster
+                                  length cluster-size)))
   :hints
-  (("goal"
-    :induct
-    (fat32-build-index-list fa-table masked-current-cluster
-                            length cluster-size)
-    :in-theory (e/d (intersectp-equal)
+  (("goal" :induct (fat32-build-index-list fa-table masked-current-cluster
+                                           length cluster-size)
+    :in-theory (e/d (intersectp-equal fat32-build-index-list)
                     (intersectp-is-commutative)))))
 
 (encapsulate
@@ -971,123 +1140,106 @@
                            cluster-size))))
 
   (defthm
-    fat32-build-index-list-of-set-indices-in-fa-table
+    fat32-build-index-list-of-set-indices-in-fa-table-coincident
     (implies
      (and (natp file-length)
           (no-duplicatesp-equal file-index-list)
           (< (* cluster-size
                 (+ -1 (len file-index-list)))
              file-length)
-          (lower-bounded-integer-listp file-index-list *ms-first-data-cluster*)
+          (lower-bounded-integer-listp
+           file-index-list *ms-first-data-cluster*)
           (bounded-nat-listp file-index-list (len fa-table))
           (consp file-index-list)
-          (fat32-entry-list-p fa-table)
           (<= (len fa-table) *ms-bad-cluster*)
           (not (zp cluster-size)))
-     (equal
-      (fat32-build-index-list
-       (set-indices-in-fa-table fa-table file-index-list
-                                (append (cdr file-index-list)
-                                        (list *ms-end-of-clusterchain*)))
-       (car file-index-list)
-       file-length cluster-size)
-      (mv file-index-list 0)))
+     (equal (fat32-build-index-list
+             (set-indices-in-fa-table
+              fa-table file-index-list
+              (append (cdr file-index-list)
+                      (list *ms-end-of-clusterchain*)))
+             (car file-index-list)
+             file-length cluster-size)
+            (mv file-index-list 0)))
     :hints
-    (("goal" :in-theory (enable set-indices-in-fa-table
-                                lower-bounded-integer-listp)
+    (("goal" :in-theory (e/d (set-indices-in-fa-table fat32-build-index-list)
+                             (fat32-masked-entry-list-p-when-bounded-nat-listp))
       :induct (induction-scheme file-index-list
-                                file-length cluster-size))
-     ("subgoal *1/2"
+                                file-length cluster-size)
       :expand
       ((:free (fa-table value-list)
-              (set-indices-in-fa-table fa-table file-index-list value-list))
+              (set-indices-in-fa-table
+               fa-table file-index-list value-list))
        (fat32-build-index-list
-        (update-nth (car file-index-list)
-                    (fat32-update-lower-28 (nth (car file-index-list) fa-table)
-                                           (cadr file-index-list))
-                    (set-indices-in-fa-table fa-table (cdr file-index-list)
-                                             (append (cddr file-index-list)
-                                                     '(268435455))))
+        (update-nth
+         (car file-index-list)
+         (fat32-update-lower-28
+          (nth (car file-index-list) fa-table)
+          (cadr file-index-list))
+         (set-indices-in-fa-table fa-table (cdr file-index-list)
+                                  (append (cddr file-index-list)
+                                          '(268435455))))
         (car file-index-list)
-        file-length cluster-size))
-      :in-theory (e/d (set-indices-in-fa-table lower-bounded-integer-listp)
-                      (fat32-masked-entry-list-p-when-bounded-nat-listp))
+        file-length cluster-size)))
+     ("subgoal *1/2"
       :use fat32-masked-entry-list-p-when-bounded-nat-listp))))
 
 (defthm
   member-of-fat32-build-index-list
   (implies
-   (and
-    (equal
-     (mv-nth
-      1
-      (fat32-build-index-list fa-table masked-current-cluster
-                              length cluster-size))
-     0)
-    (equal (fat32-entry-mask (nth x fa-table))
-           0))
-   (not
-    (member-equal
-     x
-     (mv-nth
-      0
-      (fat32-build-index-list fa-table masked-current-cluster
-                              length cluster-size))))))
+   (and (equal (mv-nth 1
+                       (fat32-build-index-list fa-table masked-current-cluster
+                                               length cluster-size))
+               0)
+        (equal (fat32-entry-mask (nth x fa-table))
+               0))
+   (not (member-equal
+         x
+         (mv-nth 0
+                 (fat32-build-index-list fa-table masked-current-cluster
+                                         length cluster-size)))))
+  :hints (("goal" :in-theory (enable fat32-build-index-list))))
 
 (defthm
   integerp-of-fat32-build-index-list
   (implies
-   (not
-    (equal
-     (mv-nth
-      1
-      (fat32-build-index-list fa-table masked-current-cluster
-                              length cluster-size))
-     0))
-   (equal
-    (mv-nth
-     1
-     (fat32-build-index-list fa-table masked-current-cluster
-                             length cluster-size))
-    (- *eio*)))
+   (not (equal (mv-nth 1
+                       (fat32-build-index-list fa-table masked-current-cluster
+                                               length cluster-size))
+               0))
+   (equal (mv-nth 1
+                  (fat32-build-index-list fa-table masked-current-cluster
+                                          length cluster-size))
+          (- *eio*)))
+  :hints (("goal" :in-theory (enable fat32-build-index-list)))
   :rule-classes
   (:rewrite
    (:type-prescription
     :corollary
-    (integerp
-     (mv-nth
-      1
-      (fat32-build-index-list fa-table masked-current-cluster
-                              length cluster-size))))
-   (:linear
-    :corollary
-    (<=
-     (mv-nth
-      1
-      (fat32-build-index-list fa-table masked-current-cluster
-                              length cluster-size))
-     0))))
+    (and
+     (integerp (mv-nth 1
+                       (fat32-build-index-list fa-table masked-current-cluster
+                                               length cluster-size)))
+     (<= (mv-nth 1
+                 (fat32-build-index-list fa-table masked-current-cluster
+                                         length cluster-size))
+         0)))))
 
 (defthm
-  fat32-build-index-list-correctness-7
+  fat32-build-index-list-correctness-1
   (implies
-   (and
-    (fat32-entry-list-p fa-table)
-    (natp n)
-    (equal
-     (mv-nth
-      1
-      (fat32-build-index-list fa-table masked-current-cluster
-                              length cluster-size))
-     0))
-   (not
-    (intersectp-equal
-     (mv-nth
-      0
-      (fat32-build-index-list fa-table masked-current-cluster
-                              length cluster-size))
-     (find-n-free-clusters fa-table n))))
-  :hints (("goal" :in-theory (e/d (intersectp-equal)
+   (and (fat32-entry-list-p fa-table)
+        (natp n)
+        (equal (mv-nth 1
+                       (fat32-build-index-list fa-table masked-current-cluster
+                                               length cluster-size))
+               0))
+   (not (intersectp-equal
+         (mv-nth 0
+                 (fat32-build-index-list fa-table masked-current-cluster
+                                         length cluster-size))
+         (find-n-free-clusters fa-table n))))
+  :hints (("goal" :in-theory (e/d (intersectp-equal fat32-build-index-list)
                                   (intersectp-is-commutative))))
   :rule-classes
   (:rewrite
@@ -1097,16 +1249,62 @@
      (and
       (fat32-entry-list-p fa-table)
       (natp n)
-      (equal
-       (mv-nth
-        1
-        (fat32-build-index-list fa-table masked-current-cluster
-                                length cluster-size))
-       0))
-     (not
-      (intersectp-equal
-       (find-n-free-clusters fa-table n)
-       (mv-nth
-        0
-        (fat32-build-index-list fa-table masked-current-cluster
-                                length cluster-size))))))))
+      (equal (mv-nth 1
+                     (fat32-build-index-list fa-table masked-current-cluster
+                                             length cluster-size))
+             0))
+     (not (intersectp-equal
+           (find-n-free-clusters fa-table n)
+           (mv-nth 0
+                   (fat32-build-index-list fa-table masked-current-cluster
+                                           length cluster-size))))))))
+
+(defthm
+  nth-of-set-indices-in-fa-table-when-member
+  (implies (and (bounded-nat-listp index-list (len fa-table))
+                (fat32-masked-entry-p val)
+                (member-equal n index-list))
+           (equal (nth n
+                       (set-indices-in-fa-table fa-table index-list
+                                                (make-list-ac (len index-list)
+                                                              val nil)))
+                  (fat32-update-lower-28 (nth n fa-table)
+                                         val)))
+  :hints (("goal" :in-theory (enable set-indices-in-fa-table))))
+
+(defthm
+  fat32-build-index-list-correctness-2
+  (implies
+   (equal (mv-nth 1
+                  (fat32-build-index-list fa-table masked-current-cluster
+                                          length cluster-size))
+          0)
+   (member-equal
+    masked-current-cluster
+    (mv-nth 0
+            (fat32-build-index-list fa-table masked-current-cluster
+                                    length cluster-size))))
+  :hints
+  (("goal" :in-theory (enable fat32-build-index-list))))
+
+(defthm
+  car-of-last-of-fat32-build-index-list
+  (implies
+   (and (fat32-masked-entry-p masked-current-cluster)
+        (< masked-current-cluster (len fa-table)))
+   (<
+    (car (last (mv-nth 0
+                       (fat32-build-index-list fa-table masked-current-cluster
+                                               length cluster-size))))
+    (len fa-table)))
+  :hints
+  (("goal"
+    :in-theory (disable car-of-last-when-bounded-nat-listp)
+    :use
+    (:instance
+     car-of-last-when-bounded-nat-listp
+     (l (mv-nth 0
+                (fat32-build-index-list fa-table masked-current-cluster
+                                        length cluster-size)))
+     (b (len fa-table)))))
+  :rule-classes :linear)
