@@ -94,20 +94,20 @@
   l5-make-regular-file-correctness-2
   (let ((entry (l5-make-regular-file contents length user-read user-write
                                      other-read other-write user)))
-       (and (equal (l5-regular-file-contents entry)
-                   contents)
-            (equal (l5-regular-file-length entry)
-                   length)
-            (equal (l5-regular-file-user-read entry)
-                   user-read)
-            (equal (l5-regular-file-user-write entry)
-                   user-write)
-            (equal (l5-regular-file-other-read entry)
-                   other-read)
-            (equal (l5-regular-file-other-write entry)
-                   other-write)
-            (equal (l5-regular-file-user entry)
-                   user)))
+    (and (equal (l5-regular-file-contents entry)
+                contents)
+         (equal (l5-regular-file-length entry)
+                length)
+         (equal (l5-regular-file-user-read entry)
+                user-read)
+         (equal (l5-regular-file-user-write entry)
+                user-write)
+         (equal (l5-regular-file-other-read entry)
+                other-read)
+         (equal (l5-regular-file-other-write entry)
+                other-write)
+         (equal (l5-regular-file-user entry)
+                user)))
   :hints (("goal" :in-theory (enable l5-regular-file-entry-p
                                      l5-make-regular-file
                                      l5-regular-file-contents
@@ -303,18 +303,18 @@
             ))))))
 
 (defun l5-to-l4-fs (fs)
-    (declare (xargs :guard (l5-fs-p fs)))
+  (declare (xargs :guard (l5-fs-p fs)))
   (if (atom fs)
       nil
     (cons (let ((directory-or-file-entry (car fs)))
-           (let ((name (car directory-or-file-entry))
-                 (entry (cdr directory-or-file-entry)))
-             (if (l5-regular-file-entry-p entry)
-                 (list* name
-                        (l5-regular-file-contents entry)
-                        (l5-regular-file-length entry))
-               (cons name (l5-to-l4-fs entry)))))
-         (l5-to-l4-fs (cdr fs)))))
+            (let ((name (car directory-or-file-entry))
+                  (entry (cdr directory-or-file-entry)))
+              (if (l5-regular-file-entry-p entry)
+                  (list* name
+                         (l5-regular-file-contents entry)
+                         (l5-regular-file-length entry))
+                (cons name (l5-to-l4-fs entry)))))
+          (l5-to-l4-fs (cdr fs)))))
 
 (defthm
   l5-to-l4-fs-correctness-1
@@ -365,17 +365,17 @@
         (l5-fs-p fs)
         (block-listp disk))
    (let
-    ((file (l5-stat hns fs disk)))
-    (implies
-     (and (l5-regular-file-entry-p file)
-          (l5-regular-file-readable-p file user))
-     (equal
-      (l3-stat hns (l5-to-l4-fs fs) disk)
-      (coerce
-       (unmake-blocks
-        (fetch-blocks-by-indices disk (l5-regular-file-contents file))
-        (l5-regular-file-length file))
-       'string)))))
+       ((file (l5-stat hns fs disk)))
+     (implies
+      (and (l5-regular-file-entry-p file)
+           (l5-regular-file-readable-p file user))
+      (equal
+       (l3-stat hns (l5-to-l4-fs fs) disk)
+       (coerce
+        (unmake-blocks
+         (fetch-blocks-by-indices disk (l5-regular-file-contents file))
+         (l5-regular-file-length file))
+        'string)))))
   :rule-classes
   (:rewrite
    (:rewrite
@@ -385,18 +385,18 @@
           (l5-fs-p fs)
           (block-listp disk))
      (let
-      ((file (l5-stat hns fs disk)))
-      (implies
-       (and (l5-regular-file-entry-p file)
-            (l5-regular-file-readable-p file user)
-            (natp user))
-       (equal
-        (l4-stat hns (l5-to-l4-fs fs) disk)
-        (coerce
-         (unmake-blocks
-          (fetch-blocks-by-indices disk (l5-regular-file-contents file))
-          (l5-regular-file-length file))
-         'string))))))))
+         ((file (l5-stat hns fs disk)))
+       (implies
+        (and (l5-regular-file-entry-p file)
+             (l5-regular-file-readable-p file user)
+             (natp user))
+        (equal
+         (l4-stat hns (l5-to-l4-fs fs) disk)
+         (coerce
+          (unmake-blocks
+           (fetch-blocks-by-indices disk (l5-regular-file-contents file))
+           (l5-regular-file-length file))
+          'string))))))))
 
 (defthm
   l5-stat-correctness-2-lemma-1
@@ -642,7 +642,7 @@
                            new-disk new-alv))))))
   :hints
   (("goal" :in-theory (enable l3-regular-file-entry-p)
-               :induct (l5-stat hns fs disk))))
+    :induct (l5-stat hns fs disk))))
 
 (defthm l5-rdchs-correctness-1-lemma-1
   (implies (and (symbol-listp hns)
@@ -673,9 +673,9 @@
       (l5-regular-file-contents (cdr (assoc-equal (car hns) fs))))
      (l5-regular-file-length (cdr (assoc-equal (car hns) fs))))))
   :hints
-  (("goal" :in-theory (enable l3-regular-file-entry-p))
-   ("subgoal *1/1''" :in-theory (disable l5-stat-correctness-1-lemma-2)
-    :use l5-stat-correctness-1-lemma-2)))
+  (("goal" :in-theory (e/d (l3-regular-file-entry-p)
+                           (l5-stat-correctness-1-lemma-2)))
+   ("subgoal *1/1" :use l5-stat-correctness-1-lemma-2)))
 
 ;; This theorem proves the equivalence of the l5 and l4 versions of rdchs.
 (defthm l5-rdchs-correctness-1
@@ -685,8 +685,8 @@
                 (natp n)
                 (block-listp disk)
                 (let ((file (l5-stat hns fs disk)))
-                     (and (or (not (l5-regular-file-entry-p file))
-                              (l5-regular-file-readable-p file user))))
+                  (and (or (not (l5-regular-file-entry-p file))
+                           (l5-regular-file-readable-p file user))))
                 (natp user))
            (equal (l4-rdchs hns (l5-to-l4-fs fs)
                             disk start n)
@@ -798,19 +798,19 @@
         (integerp user)
         (<= 0 user))
    (let
-    ((file (l5-stat hns fs disk))
-     (new-file (l5-stat hns
-                        (mv-nth 0
-                                (l5-wrchs hns fs disk alv start text user))
-                        (mv-nth 1
-                                (l5-wrchs hns fs disk alv start text user)))))
-    (implies (l5-regular-file-entry-p file)
-             (and (equal (l5-regular-file-user-read new-file)
-                         (l5-regular-file-user-read file))
-                  (equal (l5-regular-file-user new-file)
-                         (l5-regular-file-user file))
-                  (equal (l5-regular-file-other-read new-file)
-                         (l5-regular-file-other-read file)))))))
+       ((file (l5-stat hns fs disk))
+        (new-file (l5-stat hns
+                           (mv-nth 0
+                                   (l5-wrchs hns fs disk alv start text user))
+                           (mv-nth 1
+                                   (l5-wrchs hns fs disk alv start text user)))))
+     (implies (l5-regular-file-entry-p file)
+              (and (equal (l5-regular-file-user-read new-file)
+                          (l5-regular-file-user-read file))
+                   (equal (l5-regular-file-user new-file)
+                          (l5-regular-file-user file))
+                   (equal (l5-regular-file-other-read new-file)
+                          (l5-regular-file-other-read file)))))))
 
 (defthm
   l5-read-after-write-1-lemma-3
@@ -834,9 +834,9 @@
                            (l5-wrchs hns fs disk alv start text user2))
                    (mv-nth 1
                            (l5-wrchs hns fs disk alv start text user2)))))
-        (implies (l5-regular-file-entry-p file)
-                 (equal (l5-regular-file-readable-p new-file user1)
-                        (l5-regular-file-readable-p file user1)))))
+     (implies (l5-regular-file-entry-p file)
+              (equal (l5-regular-file-readable-p new-file user1)
+                     (l5-regular-file-readable-p file user1)))))
   :hints (("goal" :in-theory (enable l5-regular-file-readable-p))))
 
 (defthm
