@@ -2,9 +2,9 @@
 
 ;; Some lemmas below are taken from other books with credit; in most cases they
 ;; replaced a theorem developed for this project which either had the same name
-;; as a theorem from a community book (causing a name conflict), or which
-;; rewrote the same target (causing :use hints to become :useless even if the
-;; project-specific lemma was disabled for the goal in question.)
+;; (causing a name conflict), or which rewrote the same target (causing :use
+;; hints to become :useless even if the project-specific lemma was disabled for
+;; the goal in question.)
 
 (defthm make-character-list-makes-character-list
   (character-listp (make-character-list x)))
@@ -46,15 +46,22 @@
              (equal (first-n-ac i l ac)
                     (revappend ac (true-list-fix l)))))))
 
-(defthm by-slice-you-mean-the-whole-cake-2
-  (implies (equal i (len l))
-           (equal (take i l) (true-list-fix l))))
+;; The following is redundant with the definition in
+;; books/std/lists/take.lisp, from where it was taken with thanks.
+(defthm take-of-len-free
+  (implies (equal len (len x)) (equal (take len x) (true-list-fix x))))
 
 (defthm assoc-after-remove1-assoc
   (implies (not (equal name1 name2))
            (equal (assoc-equal name1 (remove1-assoc name2 alist))
                   (assoc-equal name1 alist))))
 
+(defthm assoc-after-remove-assoc
+  (equal (assoc-equal name1 (remove-assoc name2 alist))
+         (if (not (equal name1 name2))
+             (assoc-equal name1 alist)
+           nil)))
+
 (defthm character-listp-of-revappend
   (equal (character-listp (revappend x y))
          (and (character-listp (true-list-fix x))
@@ -97,8 +104,8 @@
            :expand (len (nthcdr n x)))))
 
 (defthm revappend-of-binary-append-1
-  (equal (revappend x (binary-append y z))
-         (binary-append (revappend x y) z)))
+  (equal (binary-append (revappend x y) z)
+         (revappend x (binary-append y z))))
 
 (defthm
   binary-append-first-n-ac-nthcdr
@@ -106,12 +113,7 @@
            (equal (binary-append (first-n-ac i l ac)
                                  (nthcdr i l))
                   (revappend ac l)))
-  :hints (("goal" :induct (first-n-ac i l ac))
-          ("subgoal *1/1''"
-           :in-theory (disable revappend-of-binary-append-1)
-           :use (:instance revappend-of-binary-append-1 (x ac)
-                           (y nil)
-                           (z l)))))
+  :hints (("goal" :induct (first-n-ac i l ac))))
 
 ;; The following is redundant with the definition in books/std/lists/nth.lisp,
 ;; from where it was taken with thanks.
@@ -184,9 +186,11 @@
   (equal (subsetp-equal (binary-append x y) z)
          (and (subsetp-equal x z) (subsetp-equal y z))))
 
-(defthm subsetp-is-transitive
-  (implies (and (subsetp-equal x y) (subsetp-equal y z))
-           (subsetp-equal x z)))
+;; The following is redundant with the eponymous theorem in
+;; books/std/lists/sets.lisp, from where it was taken with thanks.
+(defthm subsetp-trans
+  (implies (and (subsetp x y) (subsetp y z))
+           (subsetp x z)))
 
 ;; The following is redundant with the eponymous theorem in
 ;; books/std/lists/sets.lisp, from where it was taken with thanks.
@@ -435,7 +439,7 @@
 
 (defthm nthcdr-of-nil (equal (nthcdr n nil) nil))
 
-(defthmd nthcdr-when->=-n-len-l
+(defthm nthcdr-when->=-n-len-l
   (implies (and (true-listp l)
                 (>= (nfix n) (len l)))
            (equal (nthcdr n l) nil)))
@@ -500,7 +504,8 @@
   (implies
    (and (not (equal key1 nil))
         (not (consp (assoc-equal key1 alist))))
-   (not (consp (assoc-equal key1 (remove1-equal x alist))))))
+   (not (consp (assoc-equal key1 (remove1-equal x alist)))))
+  :rule-classes (:rewrite :type-prescription))
 
 (defthm assoc-equal-when-member-equal
   (implies (and (member-equal x lst)
@@ -597,6 +602,17 @@
            (equal (< 0 (* x1 (len x2)))
                   (consp x2))))
 
+(defthmd
+  painful-debugging-lemma-12
+  (implies
+   (and (integerp x) (integerp y))
+   (iff (equal (+ x (- y)) 0)
+        (equal x y))))
+
+(defthmd painful-debugging-lemma-13
+  (implies (and (integerp x) (integerp y) (< x y))
+           (<= (+ 1 x) y)))
+
 ;; The following is redundant with the eponymous theorem in
 ;; books/std/typed-lists/integer-listp.lisp, from where it was taken with
 ;; thanks.
@@ -610,7 +626,7 @@
   (equal (true-list-listp (append x y))
          (and (true-list-listp (true-list-fix x)) (true-list-listp y))))
 
-(defthm rationalp-of-nth-when-rational-listp
+(defthmd rationalp-of-nth-when-rational-listp
   (implies (rational-listp x)
            (iff (rationalp (nth n x))
                 (< (nfix n) (len x)))))
@@ -653,12 +669,6 @@
          (nthcdr (+ (nfix a) (nfix b)) x))
   :hints(("goal" :induct (nthcdr b x))))
 
-(defthm last-of-member-equal
-  (equal (last (member-equal x lst))
-         (if (member-equal x lst)
-             (last lst)
-           nil)))
-
 (defthm acl2-count-of-member-equal
   (<= (acl2-count (member-equal x lst))
       (acl2-count lst))
@@ -708,23 +718,15 @@
              (update-nth key val (take n l))
            (take n l))))
 
-(defthmd
-  remember-that-time-with-update-nth-lemma-1
+(defthmd remember-that-time-with-update-nth-lemma-1
   (implies (and (equal (nfix key) (- (len l) 1))
                 (true-listp l))
            (equal (revappend ac (update-nth key val l))
                   (append (first-n-ac key l ac)
                           (list val))))
-  :hints
-  (("goal" :induct (mv (first-n-ac key l ac)
-                       (update-nth key val l))
-    :expand ((len l) (len (cdr l))))
-   ("subgoal *1/1"
-    :in-theory (disable (:rewrite revappend-of-binary-append-1))
-    :use (:instance (:rewrite revappend-of-binary-append-1)
-                    (z (list val))
-                    (y nil)
-                    (x ac)))))
+  :hints (("goal" :induct (mv (first-n-ac key l ac)
+                              (update-nth key val l))
+           :expand ((len l) (len (cdr l))))))
 
 (defthmd
   remember-that-time-with-update-nth
@@ -747,8 +749,454 @@
   (equal (take n1 (nthcdr n2 l))
          (nthcdr n2 (take (+ (nfix n1) (nfix n2)) l))))
 
+(defthm
+  put-assoc-equal-without-change
+  (iff (equal (put-assoc-equal name val alist)
+              alist)
+       (and (consp (assoc-equal name alist))
+            (equal (cdr (assoc-equal name alist))
+                   val)))
+  :rule-classes
+  ((:rewrite
+    :corollary (implies (not (and (consp (assoc-equal name alist))
+                                  (equal (cdr (assoc-equal name alist))
+                                         val)))
+                        (not (equal (put-assoc-equal name val alist)
+                                    alist))))
+   (:rewrite :corollary (implies (and (consp (assoc-equal name alist))
+                                      (equal (cdr (assoc-equal name alist))
+                                             val))
+                                 (equal (put-assoc-equal name val alist)
+                                        alist)))))
+
 ;; Contributed to books/std/lists/remove1-equal.lisp
 (defthm member-equal-of-remove1-equal
   (implies (not (equal x1 x2))
            (iff (member-equal x1 (remove1-equal x2 l))
                 (member-equal x1 l))))
+
+(defthm
+  member-of-intersection$
+  (implies (or (not (member-equal x l1)) (not (member-equal x l2)))
+           (not (member-equal x (intersection-equal l1 l2))))
+  :rule-classes
+  (:rewrite
+   (:type-prescription
+    :corollary
+    (implies (not (member-equal x l1))
+             (not (member-equal x (intersection-equal l1 l2)))))
+   (:type-prescription
+    :corollary
+    (implies (not (member-equal x l2))
+             (not (member-equal x (intersection-equal l1 l2)))))))
+
+(defthm
+  nth-of-intersection$
+  (implies (< (nfix n)
+              (len (intersection-equal l1 l2)))
+           (and
+            (member-equal (nth n (intersection-equal l1 l2))
+                          l1)
+            (member-equal (nth n (intersection-equal l1 l2))
+                          l2)))
+  :hints
+  (("goal"
+    :in-theory (disable member-of-intersection$)
+    :use (:instance member-of-intersection$
+                    (x (nth n (intersection-equal l1 l2)))))))
+
+(defthm
+  member-of-strip-cars-of-remove-assoc
+  (iff
+   (member-equal x1
+                 (strip-cars (remove-assoc-equal x2 alist)))
+   (and
+    (member-equal x1 (strip-cars alist))
+    (not (equal x1 x2)))))
+
+(defthm
+  no-duplicatesp-of-strip-cars-of-remove-assoc
+  (implies (no-duplicatesp-equal (strip-cars alist))
+           (no-duplicatesp-equal
+            (strip-cars (remove-assoc-equal x alist)))))
+
+;; The following is redundant with the eponymous theorem in
+;; books/std/lists/take.lisp, from where it was taken with thanks.
+(defthm take-fewer-of-take-more
+  (implies (<= (nfix a) (nfix b))
+           (equal (take a (take b x)) (take a x))))
+
+(defthm len-of-remove-when-no-duplicatesp
+  (implies (no-duplicatesp-equal l)
+           (equal (len (remove-equal x l))
+                  (if (member-equal x l)
+                      (- (len l) 1)
+                    (len l)))))
+
+(defthm no-duplicatesp-of-remove
+  (implies (no-duplicatesp-equal l)
+           (no-duplicatesp-equal (remove-equal x l))))
+
+(defthm assoc-of-car-when-member
+  (implies (and (member-equal x lst) (alistp lst))
+           (consp (assoc-equal (car x) lst))))
+
+(encapsulate
+  ()
+
+  ;; The following is redundant with the eponymous function in
+  ;; books/std/basic/inductions.lisp, from where it was taken with thanks.
+  (local
+   (defun dec-dec-induct (n m)
+     (if (or (zp n)
+             (zp m))
+         nil
+       (dec-dec-induct (- n 1) (- m 1)))))
+
+  (local
+   (defthm take-of-make-list-ac-lemma-1
+     (implies (not (zp n1))
+              (equal (cons val (make-list-ac (+ -1 n1) val nil))
+                     (make-list-ac n1 val nil)))
+     :hints (("Goal" :in-theory (disable cons-car-cdr make-list-ac)
+              :use ((:instance cons-car-cdr
+                               (x (make-list-ac n1 val nil))))))))
+
+  (defthm take-of-make-list-ac
+    (implies (<= (nfix n1) (nfix n2))
+             (equal (take n1 (make-list-ac n2 val ac))
+                    (make-list-ac n1 val nil)))
+    :hints (("goal" :induct (dec-dec-induct n1 n2)))))
+
+(defthm
+  remove-assoc-when-absent
+  (implies (and (alistp alist)
+                (atom (assoc-equal x alist)))
+           (equal (remove-assoc-equal x alist)
+                  alist)))
+
+(defthm stringp-of-append
+  (equal (stringp (append x y)) (and (atom x) (stringp y))))
+
+(defthm remove-assoc-of-put-assoc
+  (equal (remove-assoc key (put-assoc name val alist))
+         (if
+             (equal key name)
+             (remove-assoc key alist)
+           (put-assoc name val (remove-assoc key alist)))))
+
+(defthm last-of-member-equal
+  (equal (last (member-equal x lst))
+         (if (member-equal x lst)
+             (last lst)
+           nil)))
+
+(defthm integerp-of-car-of-last-when-integer-listp
+  (implies (and (integer-listp l) (consp l))
+           (integerp (car (last l)))))
+
+(defthm non-negativity-of-car-of-last-when-nat-listp
+  (implies (nat-listp l)
+           (<= 0 (car (last l))))
+  :rule-classes :linear)
+
+(defthm len-of-put-assoc-equal
+  (implies (not (null name))
+           (equal (len (put-assoc-equal name val alist))
+                  (if (consp (assoc-equal name alist))
+                      (len alist)
+                      (+ 1 (len alist))))))
+
+(defthm len-of-remove-assoc-equal-2
+  (implies (and (not (null x))
+                (atom (assoc-equal x alist)))
+           (equal (remove-assoc-equal x alist)
+                  (true-list-fix alist))))
+
+(defthm len-of-remove-assoc-equal-1
+  (implies (and (not (null x))
+                (consp (assoc-equal x alist)))
+           (< (len (remove-assoc-equal x alist))
+              (len alist)))
+  :rule-classes :linear)
+
+(defthm strip-cars-of-remove-assoc
+  (equal (strip-cars (remove-assoc-equal x alist))
+         (remove-equal x (strip-cars alist))))
+
+(defthm strip-cars-of-put-assoc
+  (implies (consp (assoc-equal name alist))
+           (equal (strip-cars (put-assoc-equal name val alist))
+                  (strip-cars alist))))
+
+(defthm
+  member-of-strip-cars t
+  :rule-classes
+  ((:type-prescription
+    :corollary (implies (consp (assoc-equal x alist))
+                        (member-equal x (strip-cars alist))))
+   (:type-prescription
+    :corollary
+    (implies (and (not (null x))
+                  (not (consp (assoc-equal x alist))))
+             (not (member-equal x (strip-cars alist)))))))
+
+(defthm remove-when-absent
+  (implies (not (member-equal x l))
+           (equal (remove-equal x l)
+                  (true-list-fix l))))
+
+(defthmd intersectp-when-member
+  (implies (member-equal x l)
+           (iff (intersectp-equal l y)
+                (or (intersectp-equal (remove-equal x l) y)
+                    (member-equal x y))))
+  :hints (("goal" :in-theory (e/d (intersectp-equal)
+                                  (intersectp-is-commutative)))))
+
+(defthm consp-of-assoc-equal-of-append
+  (implies (not (null name))
+           (equal (consp (assoc-equal name (append x y)))
+                  (or (consp (assoc-equal name x))
+                      (consp (assoc-equal name y))))))
+
+(defthm consp-of-assoc-of-remove
+  (implies (and (not (null x1))
+                (not (consp (assoc-equal x1 l))))
+           (not (consp (assoc-equal x1 (remove-equal x2 l)))))
+  :rule-classes :type-prescription)
+
+(defthm strip-cars-of-append
+  (equal (strip-cars (append x y))
+         (append (strip-cars x) (strip-cars y))))
+
+(defthm remove-of-append
+  (equal (remove-equal x1 (append x2 y))
+         (append (remove-equal x1 x2)
+                 (remove-equal x1 y))))
+
+(defthm
+  remove-of-strip-cars-of-remove
+  (implies (atom x)
+           (equal (remove-equal nil (strip-cars (remove-equal x alist)))
+                  (remove-equal nil (strip-cars alist)))))
+
+(defthm assoc-equal-of-append-1
+  (implies (not (null x1))
+           (equal (assoc-equal x1 (append x2 y))
+                  (if (consp (assoc-equal x1 x2))
+                      (assoc-equal x1 x2)
+                      (assoc-equal x1 y)))))
+
+(defthm assoc-equal-of-append-2
+  (implies (and (atom (assoc-equal nil x))
+                (atom (assoc-equal nil y)))
+           (atom (assoc-equal nil (append x y))))
+  :rule-classes :type-prescription)
+
+(encapsulate
+  ()
+
+  (local (defthm lemma-1
+           (iff (equal (cons (car x) y) x)
+                (and (consp x) (equal (cdr x) y)))))
+
+  (local
+   (defthm
+     lemma-2
+     (iff (equal alist (put-assoc-equal name val alist))
+          (and (consp (assoc-equal name alist))
+               (equal (cdr (assoc-equal name alist))
+                      val)))
+     :rule-classes
+     (:rewrite
+      (:rewrite
+       :corollary (iff (equal (put-assoc-equal name val alist)
+                              alist)
+                       (and (consp (assoc-equal name alist))
+                            (equal (cdr (assoc-equal name alist))
+                                   val)))))))
+
+  (defthmd put-assoc-equal-match
+    (iff (equal (put-assoc-equal name1 val1 alist)
+                (put-assoc-equal name2 val2 alist))
+         (or (and (equal name1 name2)
+                  (equal val1 val2))
+             (and (consp (assoc-equal name1 alist))
+                  (equal (cdr (assoc-equal name1 alist))
+                         val1)
+                  (consp (assoc-equal name2 alist))
+                  (equal (cdr (assoc-equal name2 alist))
+                         val2))))))
+
+(defthm assoc-of-remove
+  (implies (and (atom x1) (not (null x2)))
+           (equal (assoc-equal x2 (remove-equal x1 l))
+                  (assoc-equal x2 l))))
+
+(defthm member-of-car-of-nth-in-strip-cars
+  (implies (< (nfix n) (len l))
+           (member-equal (car (nth n l))
+                         (strip-cars l))))
+
+(defthm
+  assoc-of-car-of-nth
+  (implies (and (no-duplicatesp-equal (strip-cars l))
+                (< (nfix n) (len l)))
+           (equal (assoc-equal (car (nth n l)) l)
+                  (nth n l)))
+  :hints
+  (("goal" :induct (mv (assoc-equal (car (nth n l)) l)
+                       (len l)
+                       (nth n l)))
+   ("subgoal *1/1"
+    :in-theory (disable (:rewrite member-of-car-of-nth-in-strip-cars))
+    :use (:instance (:rewrite member-of-car-of-nth-in-strip-cars)
+                    (l (cdr l))
+                    (n (+ -1 n))))))
+
+(defthm consp-of-nth-when-alistp
+  (implies (and (alistp l) (< (nfix n) (len l)))
+           (consp (nth n l))))
+
+(defthm member-equal-of-strip-cars-of-put-assoc
+  (iff (member-equal x
+                     (strip-cars (put-assoc-equal name val alist)))
+       (or (equal x name)
+           (member-equal x (strip-cars alist)))))
+
+(defthm
+  no-duplicatesp-of-strip-cars-of-put-assoc
+  (equal (no-duplicatesp-equal (strip-cars (put-assoc-equal name val alist)))
+         (no-duplicatesp-equal (strip-cars alist))))
+
+(defthm nth-when->=-n-len-l
+  (implies (and (true-listp l)
+                (>= (nfix n) (len l)))
+           (equal (nth n l) nil)))
+
+(defthm
+  remove-assoc-of-remove-assoc
+  (equal (remove-assoc x1 (remove-assoc x2 alist))
+         (remove-assoc x2 (remove-assoc x1 alist))))
+
+(defthm strip-cars-of-remove1-assoc
+  (equal (strip-cars (remove1-assoc-equal key alist))
+         (remove1-equal key (strip-cars alist))))
+
+(defthm
+  intersectp-equal-of-strip-cars-of-remove-equal
+  (implies
+   (not (intersectp-equal x1 (remove-equal nil (strip-cars lst))))
+   (not (intersectp-equal
+         x1
+         (remove-equal nil
+                       (strip-cars (remove-equal x2 lst))))))
+  :hints (("goal" :in-theory (e/d (intersectp-equal)
+                                  (intersectp-is-commutative)))))
+
+(defthm intersectp-of-remove
+  (implies (not (intersectp-equal l1 l2))
+	   (not (intersectp-equal (remove-equal x l1)
+				  l2)))
+  :hints (("goal" :in-theory (enable intersectp-equal)))
+  :rule-classes
+  (:type-prescription
+   (:type-prescription
+    :corollary
+    (implies (not (intersectp-equal l1 l2))
+	     (not (intersectp-equal l2
+				    (remove-equal x l1)))))))
+
+(defthm remove-of-remove
+  (equal (remove-equal x1 (remove-equal x2 l))
+	 (remove-equal x2 (remove-equal x1 l))))
+
+(defthm remove1-assoc-of-append
+  (equal (remove1-assoc key (append x y))
+         (if (equal (remove1-assoc key x)
+                    (true-list-fix x))
+             (append x (remove1-assoc key y))
+             (append (remove1-assoc key x) y))))
+
+(defthm remove1-assoc-when-absent
+  (implies (not (null key))
+           (iff
+            (equal (remove1-assoc key alist) (true-list-fix alist))
+            (atom (assoc key alist))))
+  :rule-classes
+  ((:rewrite
+    :corollary
+    (implies (and
+              (not (null key))
+              (atom (assoc key alist)))
+             (equal (remove1-assoc key alist) (true-list-fix alist))))
+   (:rewrite
+    :corollary
+    (implies (and
+              (not (null key))
+              (consp (assoc key alist)))
+             (not
+              (equal (remove1-assoc key alist) (true-list-fix alist)))))
+   (:rewrite
+    :corollary
+    (implies (and
+              (not (null key))
+              (consp (assoc key alist))
+              (true-listp alist))
+             (not
+              (equal (remove1-assoc key alist) alist))))))
+
+(defthm put-assoc-of-put-assoc-1
+  (equal (put-assoc-equal name val2 (put-assoc-equal name val1 alist))
+         (put-assoc-equal name val2 alist)))
+
+(defthm
+  put-assoc-of-put-assoc-2
+  (implies (and (or (consp (assoc-equal name1 alist))
+                    (consp (assoc-equal name2 alist)))
+                (not (equal name1 name2)))
+           (equal (put-assoc-equal name1
+                                   val1 (put-assoc-equal name2 val2 alist))
+                  (put-assoc-equal name2 val2
+                                   (put-assoc-equal name1 val1 alist)))))
+
+(defthm put-assoc-of-append
+  (implies (not (null name))
+           (equal (put-assoc-equal name val (append x y))
+                  (if (atom (assoc-equal name x))
+                      (append x (put-assoc-equal name val y))
+                      (append (put-assoc-equal name val x)
+                              y)))))
+
+;; This is disabled because I cannot decide on a normal form.
+(defthmd put-assoc-of-remove
+  (implies (and (not (null name)) (atom x))
+           (equal (remove-equal x (put-assoc-equal name val alist))
+                  (put-assoc-equal name val (remove-equal x alist)))))
+
+(defthm member-of-put-assoc
+  (implies (and (atom x) (force (not (null name))))
+           (iff (member x (put-assoc-equal name val alist))
+                (member x alist))))
+
+;; Move later.
+(defthm
+  consp-of-remove-assoc-1
+  (implies (and (not (equal x2 x1))
+                (consp (assoc-equal x1 alist)))
+           (consp (remove-assoc-equal x2 alist))))
+
+;; The following is redundant with the eponymous theorem in
+;;  books/kestrel/lists-light/nthcdr.lisp, from where it was taken after a
+;;  discussion with Eric Smith.
+(defthm nthcdr-iff
+  (iff (nthcdr n x)
+       (if (< (nfix n) (len x))
+           t
+         (if (equal (nfix n) (len x))
+             ;; If we know true-listp, this simplifies to nil and get merged
+             ;; with the nil branch below.
+             (not (true-listp x))
+           nil)))
+  :hints (("Goal" :in-theory (enable nthcdr))))
