@@ -1,10 +1,6 @@
-; Copyright (C) 2017, Regents of the University of Texas
-; Written by Mihir Mehta
-; License: A 3-clause BSD license.  See the LICENSE file distributed with ACL2.
-
 (in-package "ACL2")
 
-(include-book "file-system-lemmas")
+(local (include-book "file-system-lemmas"))
 (include-book "bounded-nat-listp")
 
 (defun set-indices (v index-list value-list)
