@@ -140,7 +140,7 @@
 ; theorems insure that the ??? exits on all the functions are never taken.
 
 (in-package "PLTP")
-(include-book "misc/eval" :dir :system)
+(include-book "std/testing/eval" :dir :system)
 
 (defun pltp-objectp (x)
   (declare (xargs :guard t))
