@@ -11,6 +11,8 @@ using namespace std;
 // In this section, only RAC code is acceptable
 
 typedef ac_int<8,false> ui8;
+typedef ac_int<16,false> ui16;
+typedef ac_int<8,true> si8;
 
 ui8 reverseByte(ui8 mumble)
 {
@@ -35,7 +37,7 @@ int main (int argc, char *argv[]) {
 
   while (! cin.eof()) {
 
-    cin >> in;
+    cin >> hex >> in;
     a_byte = in;
 
     another_byte = reverseByte (a_byte);
