@@ -1,6 +1,6 @@
 (in-package "ACL2")
 
-(include-book "misc/assert" :dir :system)
+(include-book "std/testing/assert" :dir :system)
 
 (include-book "des")
 
