@@ -120,8 +120,8 @@
         (sse-cvt-fp-to-int-special kind nbytes))
 
        ;; Check invalid operation
-       (mxcsr (if invalid (!mxcsr-slice :ie 1 mxcsr) mxcsr))
-       (im (equal (mxcsr-slice :im mxcsr) 1))
+       (mxcsr (if invalid (!mxcsrBits->ie 1 mxcsr) mxcsr))
+       (im (equal (mxcsrBits->im mxcsr) 1))
        ((when (and invalid (not im)))
         (mv 'invalid-operand-exception-is-not-masked 0 mxcsr)))
 
@@ -141,7 +141,7 @@
            (out-of-range (or (< rat-to-int min-signed-int)
                              (> rat-to-int max-signed-int)))
            ;; If the converted integer is out-of-range, set IE flag.
-           (mxcsr (if out-of-range (!mxcsr-slice :ie 1 mxcsr) mxcsr))
+           (mxcsr (if out-of-range (!mxcsrBits->ie 1 mxcsr) mxcsr))
            ((when (and out-of-range (not im)))
             (mv 'invalid-operand-exception-is-not-masked 0 mxcsr))
            ;; If out-of-range and IM is masked, return integer indefinite.
@@ -150,8 +150,8 @@
 
            ;; Check precision
            (pe (not (= rat-to-int rat)))
-           (mxcsr (if pe (!mxcsr-slice :pe 1 mxcsr) mxcsr))
-           (pm (equal (mxcsr-slice :pm mxcsr) 1))
+           (mxcsr (if pe (!mxcsrBits->pe 1 mxcsr) mxcsr))
+           (pm (equal (mxcsrBits->pm mxcsr) 1))
            ((when (and pe (not pm)))
             (mv 'precision-exception-is-not-masked 0 mxcsr)))
 
@@ -164,7 +164,7 @@
                                   nbytes op mxcsr trunc exp-width frac-width))))
     :rule-classes :type-prescription)
 
-  (defthm-usb n32p-mxcsr-sse-cvt-fp-to-int
+  (defthm-unsigned-byte-p n32p-mxcsr-sse-cvt-fp-to-int
     :bound 32
     :concl (mv-nth 2 (sse-cvt-fp-to-int
                       nbytes op mxcsr trunc exp-width frac-width))
@@ -196,8 +196,8 @@
 
        ;; Check precision
        (pe (not (= op int-to-rat)))
-       (mxcsr (if pe (!mxcsr-slice :pe 1 mxcsr) mxcsr))
-       (pm (equal (mxcsr-slice :pm mxcsr) 1))
+       (mxcsr (if pe (!mxcsrBits->pe 1 mxcsr) mxcsr))
+       (pm (equal (mxcsrBits->pm mxcsr) 1))
        ((when (and pe (not pm)))
         (mv 'precision-exception-is-not-masked 0 mxcsr))
 
@@ -213,7 +213,7 @@
     (integerp (mv-nth 1 (sse-cvt-int-to-fp op mxcsr exp-width frac-width)))
     :rule-classes :type-prescription)
 
-  (defthm-usb n32p-mxcsr-sse-cvt-int-to-fp
+  (defthm-unsigned-byte-p n32p-mxcsr-sse-cvt-int-to-fp
     :bound 32
     :concl (mv-nth 2 (sse-cvt-int-to-fp op mxcsr exp-width frac-width))
     :hints (("Goal" :in-theory (e/d* () (unsigned-byte-p))))
@@ -327,14 +327,14 @@
          (sse-cvt-fp1-to-fp2-special kind sign implicit frac frac-width1
                                      exp-width2 frac-width2))
         ;; Check invalid operation
-        (mxcsr (if invalid (!mxcsr-slice :ie 1 mxcsr) mxcsr))
-        (im (equal (mxcsr-slice :im mxcsr) 1))
+        (mxcsr (if invalid (!mxcsrBits->ie 1 mxcsr) mxcsr))
+        (im (equal (mxcsrBits->im mxcsr) 1))
         ((when (and invalid (not im)))
          (mv 'invalid-operand-exception-is-not-masked 0 mxcsr))
         ;; Check denormal operand
         (de (eq kind 'denormal))
-        (mxcsr (if de (!mxcsr-slice :de 1 mxcsr) mxcsr))
-        (dm (equal (mxcsr-slice :dm mxcsr) 1))
+        (mxcsr (if de (!mxcsrBits->de 1 mxcsr) mxcsr))
+        (dm (equal (mxcsrBits->dm mxcsr) 1))
         ((when (and de (not dm)))
          (mv 'denormal-operand-exception-is-not-masked 0 mxcsr)))
 
@@ -353,17 +353,17 @@
 
             ;; Post-computation Exceptions
             ;; Check overflow
-            (overflowp (equal (mxcsr-slice :oe mxcsr) 1))
+            (overflowp (equal (mxcsrBits->oe mxcsr) 1))
             ((when (and overflowp
-                        (equal (mxcsr-slice :om mxcsr) 0)))
+                        (equal (mxcsrBits->om mxcsr) 0)))
              (mv 'overflow-exception-is-not-masked result mxcsr))
             ;; Check underflow
-            ((when (and (equal (mxcsr-slice :ue mxcsr) 1)
-                        (equal (mxcsr-slice :um mxcsr) 0)))
+            ((when (and (equal (mxcsrBits->ue mxcsr) 1)
+                        (equal (mxcsrBits->um mxcsr) 0)))
              (mv 'underflow-exception-is-not-masked result mxcsr))
             ;; Check precision
-            ((when (and (equal (mxcsr-slice :pe mxcsr) 1)
-                        (equal (mxcsr-slice :pm mxcsr) 0)))
+            ((when (and (equal (mxcsrBits->pe mxcsr) 1)
+                        (equal (mxcsrBits->pm mxcsr) 0)))
              (mv 'precision-exception-is-not-masked result mxcsr))
 
             (rc
@@ -375,8 +375,8 @@
             (denormalp (denormalp rat rounded-expo bias2))
 
             (flush (and denormalp
-                        (equal (mxcsr-slice :um mxcsr) 1)
-                        (equal (mxcsr-slice :fz mxcsr) 1)))
+                        (equal (mxcsrBits->um mxcsr) 1)
+                        (equal (mxcsrBits->fz mxcsr) 1)))
             (fp-result
              (rat-to-fp rounded-rat sign overflowp
                         denormalp flush rc exp-width2 frac-width2)))
@@ -397,7 +397,7 @@
                                     bitops::loghead-of-logior))))
   :rule-classes :type-prescription)
 
-(defthm-usb n32p-mxcsr-sse-cvt-fp1-to-fp2
+(defthm-unsigned-byte-p n32p-mxcsr-sse-cvt-fp1-to-fp2
   :bound 32
   :concl (mv-nth
           2
@@ -440,7 +440,7 @@
               (ash nbytes 3)
               (mv-nth 1 (sp-sse-cvt-fp-to-int nbytes op mxcsr trunc)))))
 
-  (defthm-usb n32p-mxcsr-sp-sse-cvt-fp-to-int
+  (defthm-unsigned-byte-p n32p-mxcsr-sp-sse-cvt-fp-to-int
     :bound 32
     :concl (mv-nth 2 (sp-sse-cvt-fp-to-int nbytes op mxcsr trunc))
     :hints (("Goal" :in-theory (e/d () (unsigned-byte-p))))
@@ -457,13 +457,13 @@
     (mv flg result mxcsr))
   ///
 
-  (defthm-usb n32p-result-sp-sse-cvt-int-to-fp
+  (defthm-unsigned-byte-p n32p-result-sp-sse-cvt-int-to-fp
     :bound 32
     :concl (mv-nth 1 (sp-sse-cvt-int-to-fp op mxcsr))
     :gen-type t
     :gen-linear t)
 
-  (defthm-usb n32p-mxcsr-sp-sse-cvt-int-to-fp
+  (defthm-unsigned-byte-p n32p-mxcsr-sp-sse-cvt-int-to-fp
     :bound 32
     :concl (mv-nth 2 (sp-sse-cvt-int-to-fp op mxcsr))
     :hints (("Goal" :in-theory (e/d () (unsigned-byte-p))))
@@ -481,13 +481,13 @@
     (mv flg result mxcsr))
   ///
 
-  (defthm-usb n64p-result-sse-cvt-sp-to-dp
+  (defthm-unsigned-byte-p n64p-result-sse-cvt-sp-to-dp
     :bound 64
     :concl (mv-nth 1 (sse-cvt-sp-to-dp op mxcsr))
     :gen-type t
     :gen-linear t)
 
-  (defthm-usb n32p-mxcsr-sse-cvt-sp-to-dp
+  (defthm-unsigned-byte-p n32p-mxcsr-sse-cvt-sp-to-dp
     :bound 32
     :concl (mv-nth 2 (sse-cvt-sp-to-dp op mxcsr))
     :hints (("Goal" :in-theory (e/d () (unsigned-byte-p))))
@@ -517,7 +517,7 @@
               (ash nbytes 3)
               (mv-nth 1 (dp-sse-cvt-fp-to-int nbytes op mxcsr trunc)))))
 
-  (defthm-usb n32p-mxcsr-dp-sse-cvt-fp-to-int
+  (defthm-unsigned-byte-p n32p-mxcsr-dp-sse-cvt-fp-to-int
     :bound 32
     :concl (mv-nth 2 (dp-sse-cvt-fp-to-int nbytes op mxcsr trunc))
     :hints (("Goal" :in-theory (e/d () (unsigned-byte-p))))
@@ -534,13 +534,13 @@
     (mv flg result mxcsr))
   ///
 
-  (defthm-usb n64p-result-dp-sse-cvt-int-to-fp
+  (defthm-unsigned-byte-p n64p-result-dp-sse-cvt-int-to-fp
     :bound 64
     :concl (mv-nth 1 (dp-sse-cvt-int-to-fp op mxcsr))
     :gen-type t
     :gen-linear t)
 
-  (defthm-usb n32p-mxcsr-dp-sse-cvt-int-to-fp
+  (defthm-unsigned-byte-p n32p-mxcsr-dp-sse-cvt-int-to-fp
     :bound 32
     :concl (mv-nth 2 (dp-sse-cvt-int-to-fp op mxcsr))
     :hints (("Goal" :in-theory (e/d () (unsigned-byte-p))))
@@ -558,13 +558,13 @@
     (mv flg result mxcsr))
   ///
 
-  (defthm-usb n32p-result-sse-cvt-dp-to-sp
+  (defthm-unsigned-byte-p n32p-result-sse-cvt-dp-to-sp
     :bound 32
     :concl (mv-nth 1 (sse-cvt-dp-to-sp op mxcsr))
     :gen-type t
     :gen-linear t)
 
-  (defthm-usb n32p-mxcsr-sse-cvt-dp-to-sp
+  (defthm-unsigned-byte-p n32p-mxcsr-sse-cvt-dp-to-sp
     :bound 32
     :concl (mv-nth 2 (sse-cvt-dp-to-sp op mxcsr))
     :hints (("Goal" :in-theory (e/d () (unsigned-byte-p))))
