@@ -39,6 +39,7 @@
 (in-package "X86ISA")
 
 (include-book "abstract-state")
+(local (include-book "centaur/bitops/ihsext-basics" :dir :system))
 
 ;; ======================================================================
 
@@ -70,7 +71,7 @@ re-arrange these nests of updates.</p>
   the @(':RGF') field in a well-formed x86 state gives a well-formed
   x86 state.</li>
 
-<li>@(see x86-Writing-the-Read-Theorem): <p>Informally, this kind of a
+<li>@('x86-Writing-the-Read-Theorem'): <p>Informally, this kind of a
   theorem states that a write operation that writes the same value to
   a field that was already there, is superfluous, and can be
   eliminated.</p></li>
@@ -112,10 +113,14 @@ re-arrange these nests of updates.</p>
 (defconst *x86-array-fields-as-keywords*
   '(:RGF
     :SEG-VISIBLE
-    :SEG-HIDDEN
+    :SEG-HIDDEN-BASE
+    :SEG-HIDDEN-LIMIT
+    :SEG-HIDDEN-ATTR
     :STR
     :SSR-VISIBLE
-    :SSR-HIDDEN
+    :SSR-HIDDEN-BASE
+    :SSR-HIDDEN-LIMIT
+    :SSR-HIDDEN-ATTR
     :CTR
     :DBG
     :FP-DATA
@@ -179,8 +184,11 @@ re-arrange these nests of updates.</p>
 
 (defsection x86-Preservation-Theorems
 
+  ;; Also includes Writing-the-Read Theorems.
+
   :parents (state-field-theorems)
 
+
   ;; Types of readers in terms of XR:
 
   (defun x86-stobj-field-thms-fn-1 (x86-model-field)
@@ -204,12 +212,13 @@ re-arrange these nests of updates.</p>
              (namei     (mk-name name "I"))
              (constant (mk-name "*" name "I*"))
              (getter    namei)
-             (size      (cadr (cadr type))))
+             (size      (cadr (cadr type)))
+             (length (caaddr (caddr x86-model-field))))
           `(
             ;; Field type theorem:
             ,(if (equal (car (cadr type)) 'unsigned-byte)
-                 `(DEFTHM-USB ,(mk-name getter (if (< size 10) "-IS-N0" "-IS-N") size "P")
-                    :hyp (FORCE (X86P X86))
+                 `(DEFTHM-UNSIGNED-BYTE-P ,(mk-name getter (if (< size 10) "-IS-N0" "-IS-N") size "P")
+                    :hyp t
                     :bound ,size
                     :concl (XR ,keyword I X86)
                     :HINTS (("GOAL" :IN-THEORY (E/D (,getter X86P) ())
@@ -219,8 +228,8 @@ re-arrange these nests of updates.</p>
                     :gen-linear t
                     :gen-type t)
 
-               `(DEFTHM-SB ,(mk-name getter "-IS-I" size "P")
-                  :hyp (FORCE (X86P X86))
+               `(DEFTHM-SIGNED-BYTE-P ,(mk-name getter "-IS-I" size "P")
+                  :hyp t
                   :bound ,size
                   :concl (XR ,keyword I X86)
                   :HINTS (("GOAL" :IN-THEORY (E/D (,getter X86P) ())
@@ -228,33 +237,80 @@ re-arrange these nests of updates.</p>
                                             (I I)
                                             (X (NTH ,constant X86))))))
                   :gen-type t
-                  :gen-linear t)))))
+                  :gen-linear t))
+
+            (defthmd ,(mk-name "XW-XR-" name)
+              ;; Writing-the-read theorem
+              ;; Needed to add the case hyp. after adding fixing to the abstract
+              ;; accessors/updaters.  But this isn't worth thinking about removing: this
+              ;; theorem is used very rarely, if at all.
+              (implies (and
+                        (equal v (xr ,keyword i x86))
+                        (natp i)
+                        (< i ,length)
+                        (x86p x86))
+                       (equal (xw ,keyword i v x86) x86))
+              :hints (("Goal" :in-theory (e/d ()
+                                              (unsigned-byte-p
+                                               signed-byte-p
+                                               (tau-system)
+                                               ,(mk-name predicate "-AUX-NECC")))
+                       :use ((:instance ,(mk-name predicate "-AUX-NECC")
+                                        (x (nth ,constant x86))))))))))
 
        ((and (consp type)
              (equal (car type) 'unsigned-byte))
         (b* ((getter  (mk-name name))
              (size    (cadr type)))
           `( ;; Field Type Theorem:
-            (DEFTHM-USB ,(mk-name getter "-IS-N" size "P")
-              :hyp (FORCE (X86P X86))
+            (DEFTHM-UNSIGNED-BYTE-P ,(mk-name getter "-IS-N" size "P")
+              :hyp t
               :bound ,size
               :concl (XR ,keyword I X86)
               :HINTS (("GOAL" :IN-THEORY (E/D (,getter X86P) ())))
               :gen-type t
-              :gen-linear t))))
+              :gen-linear t)
+
+            (defthmd ,(mk-name "XW-XR-" name)
+              ;; Writing-the-read theorem
+              ;; Needed to add the case hyp. after adding fixing to the abstract
+              ;; accessors/updaters.  But this isn't worth thinking about removing: this
+              ;; theorem is used very rarely, if at all.
+              (implies (and
+                        (equal v (xr ,keyword i x86))
+                        (x86p x86))
+                       (equal (xw ,keyword i v x86) x86))
+              :hints (("Goal" :in-theory (e/d ()
+                                              (unsigned-byte-p
+                                               signed-byte-p
+                                               (tau-system)))))))))
 
        ((and (consp type)
              (equal (car type) 'signed-byte))
         (b* ((getter  (mk-name name))
              (size    (cadr type)))
           `( ;; Field Type Theorems:
-            (DEFTHM-SB ,(mk-name getter "-IS-I" size "P")
-              :hyp (FORCE (X86P X86))
+            (DEFTHM-SIGNED-BYTE-P ,(mk-name getter "-IS-I" size "P")
+              :hyp t
               :bound ,size
               :concl (XR ,keyword I X86)
               :HINTS (("GOAL" :IN-THEORY (E/D (,getter X86P) ())))
               :gen-linear t
-              :gen-type t))))
+              :gen-type t)
+
+            (defthmd ,(mk-name "XW-XR-" name)
+              ;; Writing-the-read theorem
+              ;; Needed to add the case hyp. after adding fixing to the abstract
+              ;; accessors/updaters.  But this isn't worth thinking about removing: this
+              ;; theorem is used very rarely, if at all.
+              (implies (and
+                        (equal v (xr ,keyword i x86))
+                        (x86p x86))
+                       (equal (xw ,keyword i v x86) x86))
+              :hints (("Goal" :in-theory (e/d ()
+                                              (unsigned-byte-p
+                                               signed-byte-p
+                                               (tau-system)))))))))
 
        ((and (consp type)
              (equal (car type) 'integer))
@@ -264,15 +320,31 @@ re-arrange these nests of updates.</p>
           `( ;; Field Type Theorem:
 
             (DEFTHM-NATP ,(mk-name "NATP-" getter)
-              :hyp (FORCE (X86P X86))
+              :hyp t
               :concl (XR ,keyword I X86)
+              :gen-type t
+              :gen-linear t
               :HINTS (("GOAL" :IN-THEORY (ENABLE ,predicate))))
 
             (DEFTHM ,(mk-name getter "-LESS-THAN-" size)
-              (IMPLIES (FORCE (X86P X86))
+              (IMPLIES t
                        (<= (XR ,keyword I X86) ,size))
               :HINTS (("GOAL" :IN-THEORY (ENABLE ,predicate)))
-              :RULE-CLASSES :LINEAR))))
+              :RULE-CLASSES :LINEAR)
+
+            (defthmd ,(mk-name "XW-XR-" name)
+              ;; Writing-the-read theorem
+              ;; Needed to add the case hyp. after adding fixing to the abstract
+              ;; accessors/updaters.  But this isn't worth thinking about removing: this
+              ;; theorem is used very rarely, if at all.
+              (implies (and
+                        (equal v (xr ,keyword i x86))
+                        (x86p x86))
+                       (equal (xw ,keyword i v x86) x86))
+              :hints (("Goal" :in-theory (e/d ()
+                                              (unsigned-byte-p
+                                               signed-byte-p
+                                               (tau-system)))))))))
 
        ((and (consp type)
              (equal (car type) 'satisfies))
@@ -280,15 +352,41 @@ re-arrange these nests of updates.</p>
         (b* ((predicate (cadr type)))
           `( ;; Field Type Theorem:
             (DEFTHM ,(mk-name predicate "-" name)
-              (IMPLIES (FORCE (X86P X86))
-                       (,predicate (XR ,keyword I X86)))))))
+              (IMPLIES t
+                       (,predicate (XR ,keyword I X86))))
+
+            (defthmd ,(mk-name "XW-XR-" name)
+              ;; Writing-the-read theorem
+              ;; Needed to add the case hyp. after adding fixing to the abstract
+              ;; accessors/updaters.  But this isn't worth thinking about removing: this
+              ;; theorem is used very rarely, if at all.
+              (implies (and
+                        (equal v (xr ,keyword i x86))
+                        (x86p x86))
+                       (equal (xw ,keyword i v x86) x86))
+              :hints (("Goal" :in-theory (e/d ()
+                                              (unsigned-byte-p
+                                               signed-byte-p
+                                               (tau-system)))))))))
 
        (t
         ;; type is presumably 'T (like MS and FAULT fields)
         `(
           ;; No Field Type Theorem
 
-          )))))
+          (defthmd ,(mk-name "XW-XR-" name)
+            ;; Writing-the-read theorem
+            ;; Needed to add the case hyp. after adding fixing to the abstract
+            ;; accessors/updaters.  But this isn't worth thinking about removing: this
+            ;; theorem is used very rarely, if at all.
+            (implies (and
+                      (equal v (xr ,keyword i x86))
+                      (x86p x86))
+                     (equal (xw ,keyword i v x86) x86))
+            :hints (("Goal" :in-theory (e/d ()
+                                            (unsigned-byte-p
+                                             signed-byte-p
+                                             (tau-system)))))))))))
 
   (defun x86-stobj-field-thms-fn (x86-model)
     (cond ((endp x86-model)
@@ -314,58 +412,8 @@ re-arrange these nests of updates.</p>
   ;; Type of writers in terms of XW:
 
   (defthm x86p-xw
-    (implies (forced-and (member fld *x86-field-names-as-keywords*)
-                         (case fld
-                           (:rgf          (and (integerp index)
-                                               (signed-byte-p 64 value)))
-                           (:rip          (signed-byte-p 48 value))
-                           (:rflags       (unsigned-byte-p 32 value))
-                           (:seg-visible  (and (integerp index)
-                                               (unsigned-byte-p 16 value)))
-                           (:seg-hidden   (and (integerp index)
-                                               (unsigned-byte-p 112 value)))
-                           (:str          (and (integerp index)
-                                               (unsigned-byte-p 80 value)))
-                           (:ssr-visible  (and (integerp index)
-                                               (unsigned-byte-p 16 value)))
-                           (:ssr-hidden   (and (integerp index)
-                                               (unsigned-byte-p 112 value)))
-                           (:ctr          (and (integerp index)
-                                               (unsigned-byte-p 64 value)))
-                           (:dbg          (and (integerp index)
-                                               (unsigned-byte-p 64 value)))
-                           (:fp-data      (and (integerp index)
-                                               (unsigned-byte-p 80 value)))
-                           (:fp-ctrl      (unsigned-byte-p 16 value))
-                           (:fp-status    (unsigned-byte-p 16 value))
-                           (:fp-tag       (unsigned-byte-p 16 value))
-                           (:fp-last-inst (unsigned-byte-p 48 value))
-                           (:fp-last-data (unsigned-byte-p 48 value))
-                           (:fp-opcode    (unsigned-byte-p 11 value))
-                           (:zmm          (and (integerp index)
-                                               (unsigned-byte-p 512 value)))
-                           (:mxcsr        (unsigned-byte-p 32 value))
-                           (:msr          (and (integerp index)
-                                               (unsigned-byte-p 64 value)))
-                           (:env          (env-alistp value))
-                           (:app-view (booleanp value))
-                           (:marking-view (booleanp value))
-                           (:os-info      (keywordp value))
-                           (:mem          (and (integerp index)
-                                               (unsigned-byte-p 8 value)))
-                           (otherwise     (equal index 0)))
-                         (x86p x86))
-             (x86p (xw fld index value x86)))
-    :hints (("Goal"
-             :in-theory (e/d*
-                         (rgfp ripp rflagsp seg-visiblep
-                               seg-hiddenp strp ssr-visiblep ssr-hiddenp
-                               ctrp msrp dbgp fp-datap fp-ctrlp
-                               fp-statusp fp-tagp fp-last-instp
-                               fp-last-datap fp-opcodep zmmp mxcsrp msrp
-                               msp faultp env-alistp undefp booleanp
-                               memp)
-                         ()))))
+    (implies (force (x86p x86))
+             (x86p (xw fld index value x86))))
 
   (defthmd xr-irrelevant-index-for-simple-fields
     (implies (and (syntaxp (not (and (consp index)
@@ -381,38 +429,60 @@ re-arrange these nests of updates.</p>
              (equal (xw fld index value x86)
                     (xw fld 0     value x86)))))
 
-(defsection x86-Writing-the-Read-Theorem
-
-  :parents (state-field-theorems)
-
-  (defthmd xw-xr
-    (implies (and (equal v (xr fld i x86))
-                  (x86p x86))
-             (equal (xw fld i v x86) x86))))
 
 (defsection x86-RoW-Theorems
 
   :parents (state-field-theorems)
 
-  ;; [Shilpi]: Maybe I should write a single RoW theorem with meta
-  ;; rules that weeds out all the independent writes.
-
   (defthm xr-xw-intra-array-field
     (implies (member fld *x86-array-fields-as-keywords*)
              (equal (xr fld i (xw fld j v x86))
                     (if (equal i j)
-                        v
+                        (case fld
+                          (:rgf                (logext   64 v))
+                          (:seg-visible        (loghead  16 v))
+                          (:seg-hidden-base    (loghead  64 v))
+                          (:seg-hidden-attr    (loghead  16 v))
+                          (:seg-hidden-limit   (loghead  32 v))
+                          (:str                (loghead  80 v))
+                          (:ssr-visible        (loghead  16 v))
+                          (:ssr-hidden-base    (loghead  64 v))
+                          (:ssr-hidden-limit   (loghead  32 v))
+                          (:ssr-hidden-attr    (loghead  16 v))
+                          (:ctr                (loghead  64 v))
+                          (:dbg                (loghead  64 v))
+                          (:fp-data            (loghead  80 v))
+                          (:zmm                (loghead 512 v))
+                          (:msr                (loghead  64 v))
+                          (:mem                (loghead   8 v)))
                       (xr fld i x86)))))
 
   (defthm xr-xw-intra-simple-field
     (implies (member fld *x86-simple-fields-as-keywords*)
              (equal (xr fld i (xw fld j v x86))
-                    v)))
+                    (case fld
+                      (:rip          (logext  48 v))
+                      (:rflags       (loghead 32 v))
+                      (:fp-ctrl      (loghead 16 v))
+                      (:fp-status    (loghead 16 v))
+                      (:fp-tag       (loghead 16 v))
+                      (:fp-last-inst (loghead 48 v))
+                      (:fp-last-data (loghead 48 v))
+                      (:fp-opcode    (loghead 11 v))
+                      (:mxcsr        (loghead 32 v))
+                      (:ms           v)
+                      (:fault        v)
+                      (:env          (if (env-alistp v) v 'nil))
+                      (:undef        v)
+                      (:app-view     (if (booleanp v) v 't))
+                      (:marking-view (if (booleanp v) v 't))
+                      (:os-info      (if (keywordp v) v ':linux))))))
 
   (defthm xr-xw-inter-field
     (implies (case-split (not (equal fld1 fld2)))
              (equal (xr fld2 i2 (xw fld1 i1 v x86))
-                    (xr fld2 i2 x86)))))
+                    (xr fld2 i2 x86)))
+    :hints (("Goal" :in-theory (e/d () ((tau-system)))))))
 
 (defsection x86-WoW-Theorems
 
@@ -439,6 +509,7 @@ re-arrange these nests of updates.</p>
     (implies (not (equal fld1 fld2))
              (equal (xw fld2 i2 v2 (xw fld1 i1 v1 x86))
                     (xw fld1 i1 v1 (xw fld2 i2 v2 x86))))
+    :hints (("Goal" :in-theory (e/d () ((tau-system)))))
     :rule-classes ((:rewrite :loop-stopper ((fld2 fld1))))))
 
 ;; ======================================================================
