@@ -477,6 +477,35 @@
 
 
 
+; Proof of induct-step-drepp-am modified April 2016 by Matt K. to accommodate
+; addition of a type-set bit for the set {1}.  The :cases hint in
+; induct-step-drepp-am no longer succeeded, but it was easy to separate out the
+; interesting case as a lemma, as follows.  Now there are no subgoal hints.
+
+(local
+ (defthm induct-step-drepp-am-not-equal-m-1
+   (IMPLIES (AND (DREPP (SPD P Q) P Q)
+                 (<= 1 M)
+                 (< M (EXPT 2 (+ -1 p)))
+                 (DREPP (+ (* -1 (SPD P Q)) (* M (SPD P Q)))
+                        P Q)
+                 (INTEGERP P)
+                 (< 1 P)
+                 (INTEGERP Q)
+                 (< 0 Q)
+                 (INTEGERP M)
+                 (not (equal m 1)))
+            (DREPP (* M (SPD P Q)) P Q))
+   :hints (("Goal" :in-theory (e/d (drepp positive-spd bias) (fp+ spd))
+            :use ((:instance FP+1
+                             (x (am (1- m) p q))
+                             (n (+ -2 P (EXPT 2 (- Q 1))
+                                   (EXPO (am (1- m) p q)))))
+                  (:instance am-is-fp+1
+                             (m (1- m)))
+                  (:instance induct-step-drepp-am-1-5))))
+   :rule-classes nil))
+
 (local
  (defthm induct-step-drepp-am
    (IMPLIES (AND (DREPP (SPD P Q) P Q)
@@ -490,16 +519,7 @@
                  (< 0 Q)
                  (INTEGERP M))
             (DREPP (* M (SPD P Q)) P Q))
-   :hints (("Goal" :cases ((not (equal m 1))))
-           ("Subgoal 1" :in-theory (e/d (drepp positive-spd) (fp+ spd))
-            :use ((:instance FP+1
-                             (x (am (1- m) p q))
-                             (n (+ -2 P (EXPT 2 (- Q 1))
-                                   (EXPO (am (1- m) p q)))))
-                  (:instance am-is-fp+1
-                             (m (1- m)))
-                  (:instance induct-step-drepp-am-1-5)))
-           ("Subgoal 1.1" :in-theory (enable bias)))))
+   :hints (("Goal" :use induct-step-drepp-am-not-equal-m-1))))
 
 (local
 (defthmd spd-mult-1
@@ -1056,9 +1076,10 @@
   :hints (("Goal" :in-theory (disable spd-mult-1)
            :use ((:instance spd-mult-1))))))
 
-
 ;;; only this is new!!
 
+; Modified 3/17/2016 by Matt K. for runic type-prescription mod (goal numbers
+; changed).
 (defthmd spd-mult
   (implies (and (integerp p)
                 (> p 1)
@@ -1073,14 +1094,9 @@
 		     (< m (expt 2 (1- p))))))
   :hints (("Goal" :in-theory (e/d () (am spd drepp
                                          spd-mult-1-specific-further
-                                         spd-mult-2-specific-further)))
-          ("Subgoal 5" :cases ((< (* R (/ (SPD P Q)))
-                                  (expt 2 (1- p)))))
-          ("Subgoal 5.1" :use ((:instance spd-mult-1-specific-further
-                                          (m (/ r (spd p q))))))
-          ("Subgoal 3" :use ((:instance spd-mult-1-specific-further
-                                        (m (/ r (spd p q))))))
-          ("Subgoal 2" :use ((:instance spd-mult-2-specific-further)))
-          ("Subgoal 1" :use ((:instance smallest-spd)))))
+                                         spd-mult-2-specific-further))
+           :use ((:instance spd-mult-1-specific-further
+                            (m (/ r (spd p q))))
+                 (:instance spd-mult-2-specific-further)))))
 
 ;------------------------------------------------------------------------------
