@@ -505,163 +505,6 @@ See also merge2.lisp.
   )
 
 
-
-
-
-
-
-;;;**********************************************************************
-;;;                         BITS
-;;;**********************************************************************
-
-
-
-#|
-(local
- (defthm logand-expt-4-1
-   (implies (and (integerp n) (>= n 0)
-                 (integerp k) (>= k 0)
-                 (integerp l) (>= l 0) (< l k)
-                 (< k n))
-            (= (logand (- (1- (expt 2 n)) (expt 2 l)) (- (expt 2 n) (expt 2 k)))
-               (* (expt 2 k) (bits (- (1- (expt 2 n)) (expt 2 l)) (1- n) k))))
-   :rule-classes ()
-   :hints (("goal"  :in-theory (disable expt-compare)
-            :use ((:instance logand-slice (x (- (1- (expt 2 n)) (expt 2 l))))
-                  (:instance expt-strong-monotone (n l) (m n)))))))
-|#
-
-(local
- (defthm logand-expt-4-2
-   (implies (and (integerp n) (>= n 0)
-                 (integerp k) (>= k 0)
-                 (integerp l) (>= l 0) (< l k)
-                 (< k n))
-            (= (logand (- (1- (expt 2 n)) (expt 2 l)) (- (expt 2 n) (expt 2 k)))
-               (* (expt 2 k) (fl (/ (mod (- (1- (expt 2 n)) (expt 2 l)) (expt 2 n)) (expt 2 k))))))
-   :rule-classes ()
-   :hints (("goal" :in-theory (e/d (bits
-                                    ) ( EXPT-EXCEEDS-2 ;bozo why needed?
-                                    expt-compare
-                                    ))
-            :use ((:instance logand-slice (x (- (1- (expt 2 n)) (expt 2 l))))
-                  (:instance expt-strong-monotone (n l) (m n))
-                  )))))
-
-(local
- (defthm logand-expt-4-3
-   (implies (and (integerp n) (>= n 0)
-                 (integerp k) (>= k 0)
-                 (integerp l) (>= l 0) (< l k)
-                 (< k n))
-            (= (mod (- (1- (expt 2 n)) (expt 2 l)) (expt 2 n))
-               (- (1- (expt 2 n)) (expt 2 l))))
-   :rule-classes ()
-   :hints (("goal"   :in-theory (disable expt-compare)
-            :use ((:instance expt-strong-monotone (n l) (m n))
-;			(:instance expt-pos (x l))
-                  (:instance mod-does-nothing (m (- (1- (expt 2 n)) (expt 2 l)))
-                             (n (expt 2 n))))))))
-
-(local
- (defthm logand-expt-4-4
-   (implies (and (integerp n) (>= n 0)
-                 (integerp k) (>= k 0)
-                 (integerp l) (>= l 0) (< l k)
-                 (< k n))
-            (= (fl (/ (mod (- (1- (expt 2 n)) (expt 2 l)) (expt 2 n))
-                      (expt 2 k)))
-               (fl (/ (- (1- (expt 2 n)) (expt 2 l))
-                      (expt 2 k)))))
-   :rule-classes ()
-   :hints (("goal" :in-theory (enable mod-does-nothing)
-            :use (logand-expt-4-3
-)))))
-
-(local
- (defthm logand-expt-4-5
-   (implies (and (integerp n) (>= n 0)
-                 (integerp k) (>= k 0)
-                 (integerp l) (>= l 0) (< l k)
-                 (< k n))
-            (= (logand (- (1- (expt 2 n)) (expt 2 l)) (- (expt 2 n) (expt 2 k)))
-               (* (expt 2 k) (fl (/ (- (1- (expt 2 n)) (expt 2 l)) (expt 2 k))))))
-   :rule-classes ()
-   :hints (("goal" :hands-off (expt mod fl)
-            :use ((:instance logand-expt-4-2)
-                  (:instance logand-expt-4-4))))))
-
-(local
- (defthm logand-expt-4-6
-   (implies (and (integerp n) (>= n 0)
-                 (integerp k) (>= k 0)
-                 (integerp l) (>= l 0) (< l k)
-                 (< k n))
-            (= (fl (/ (- (1- (expt 2 n)) (expt 2 l)) (expt 2 k)))
-               (fl (- (expt 2 (- n k)) (/ (1+ (expt 2 l)) (expt 2 k))))))
-   :rule-classes ()
-   :hints (("goal" :use ((:instance expt-split (r 2) (i (- n k)) (j k)))))))
-
-(local
- (defthm logand-expt-4-8
-   (implies (and (integerp n) (>= n 0)
-                 (integerp k) (>= k 0)
-                 (integerp l) (>= l 0) (< l k)
-                 (< k n))
-            (= (fl (- (expt 2 (- n k)) (/ (1+ (expt 2 l)) (expt 2 k))))
-               (- (expt 2 (- n k)) 1)))
-   :rule-classes ()
-   :hints (("goal" :in-theory (disable expt-2-integerp
-                                       )
-            :use (logand-expt-4-6
-;                  logand-expt-4-7
-                  (:instance expt-2-integerp (i (- n k)))
-                  (:instance fl-unique
-                             (x (- (expt 2 (- n k)) (/ (1+ (expt 2 l)) (expt 2 k))))
-                             (n (- (expt 2 (- n k)) 1))))))))
-
-(local
- (defthm logand-expt-4-9
-   (implies (and (integerp n) (>= n 0)
-                 (integerp k) (>= k 0)
-                 (integerp l) (>= l 0) (< l k)
-                 (< k n))
-            (= (fl (/ (- (1- (expt 2 n)) (expt 2 l)) (expt 2 k)))
-               (- (expt 2 (- n k)) 1)))
-   :rule-classes ()
-   :hints (("goal" :use (logand-expt-4-8
-                         logand-expt-4-6)))))
-
-(local
- (defthm logand-expt-4-10
-   (implies (and (integerp n) (>= n 0)
-                 (integerp k) (>= k 0)
-                 (integerp l) (>= l 0) (< l k)
-                 (< k n))
-            (= (logand (- (1- (expt 2 n)) (expt 2 l)) (- (expt 2 n) (expt 2 k)))
-               (* (expt 2 k) (- (expt 2 (- n k)) 1))))
-   :rule-classes ()
-   :hints (("goal" :hands-off (expt mod fl)
-            :use ((:instance logand-expt-4-5)
-                  (:instance logand-expt-4-9))))))
-
-;BOZO is this used anywhere?
-;move?
-;rename!
-(defthm logand-expt-4
-  (implies (and (integerp n) (>= n 0)
-                (integerp k) (>= k 0)
-                (integerp l) (>= l 0) (< l k)
-                (<= k n))
-           (= (logand (- (1- (expt 2 n)) (expt 2 l))
-                      (- (expt 2 n) (expt 2 k)))
-              (- (expt 2 n) (expt 2 k))))
-  :rule-classes ()
-  :hints (("goal" :hands-off (expt mod fl)
-           :use ((:instance logand-expt-4-10)
-                 (:instance expt-split (r 2) (i (- n k)) (j k))))))
-
-
 ;;;**********************************************************************
 ;;;                       LOGAND, LOGIOR, and LOGXOR
 ;;;**********************************************************************
