@@ -14,9 +14,7 @@
 
 (include-book "verify-guards")
 
-(include-book "../rel9-rtl-pkg/lib/add")
-
-(include-book "./lza")
+(include-book "./add")
 
 (include-book "./mult")
 
@@ -26,8 +24,6 @@
 
 (include-book "./gl")
 
-(include-book "./masc")
-
 (include-book "./basic")
 
 (include-book "./bits")
@@ -45,3 +41,5 @@
 (include-book "./div")
 
 (include-book "./excps")
+
+(include-book "./rac")
