@@ -35,30 +35,16 @@
 (include-book "xdoc/top" :dir :system)
 (include-book "system/f-put-global" :dir :system)
 (include-book "std/lists/list-defuns" :dir :system)
+(include-book "std/basic/bytep" :dir :system)
 (include-book "file-measure")
 (local (include-book "std/lists/append" :dir :system))
 (local (include-book "std/lists/revappend" :dir :system))
 (local (include-book "std/lists/rev" :dir :system))
 (local (include-book "std/strings/coerce" :dir :system))
 
-(defsection bytep
-
-  ;; This should probably be defined elsewhere.
-  ;;
-  ;; We leave this enabled since arithmetic theories probably shouldn't need to
-  ;; know about it.
-
-  (defun bytep (x)
-    (declare (xargs :guard t))
-    (mbe :logic (unsigned-byte-p 8 x)
-         :exec (and (natp x)
-                    (< x 256))))
-
-  (defthm bytep-compound-recognizer
-    (implies (bytep x)
-             (and (integerp x)
-                  (<= 0 x)))
-    :rule-classes :compound-recognizer))
+; We enable this since arithmetic theories probably shouldn't need to know
+; about it.
+(in-theory (enable bytep))
 
 ;; Various guard-related facts about IO functions.  BOZO maybe some of these
 ;; theorems should be local.
@@ -108,9 +94,9 @@
            (open-channels-p (add-pair k v x)))
   :hints(("Goal" :in-theory (enable open-channels-p))))
 
-(defthm open-channels-p-of-delete-assoc-equal
+(defthm open-channels-p-of-remove1-assoc-equal
   (implies (open-channels-p x)
-           (open-channels-p (delete-assoc-equal k x)))
+           (open-channels-p (remove1-assoc-equal k x)))
   :hints(("Goal" :in-theory (enable open-channels-p
                                     open-channel-listp
                                     ordered-symbol-alistp))))
@@ -705,7 +691,45 @@ foo
                      state))
      :hints(("Goal" :in-theory (e/d (read-object state-p1)))))))
 
+(defsection std/io/read-file-into-string
+  :parents (std/io read-file-into-string)
 
+  :long "<p>See @(see read-file-into-string).</p>"
+
+  (local (in-theory (disable read-char$ open-input-channel-p1)))
+
+  (defthm
+    stringp-of-read-file-into-string1
+    (implies
+     (not
+      (null
+       (mv-nth 0
+               (read-file-into-string1 channel state ans bound))))
+     (stringp
+      (mv-nth 0
+              (read-file-into-string1 channel state ans bound))))
+    :rule-classes
+    (:rewrite
+     (:type-prescription
+      :corollary
+      (or
+       (null
+        (mv-nth 0
+                (read-file-into-string1 channel state ans bound)))
+       (stringp
+        (mv-nth
+         0
+         (read-file-into-string1 channel state ans bound)))))))
+
+  (defthm
+    state-p1-of-read-file-into-string1
+    (implies
+     (and (symbolp channel)
+          (open-input-channel-p channel
+                                :character state)
+          (state-p state))
+     (state-p1 (mv-nth 1
+                       (read-file-into-string1 channel state ans bound))))))
 
 ; -----------------------------------------------------------------------------
 ;
