@@ -296,10 +296,13 @@ the other keyword arguments are unused.  For example:</p>
                               (string-listp (strip-cars strsubst))
                               (string-listp (strip-cdrs strsubst))
                               (symbol-listp exports)
+                              (symbolp pkg)
                               (not (and (equal prefix "")
                                         (equal suffix "")
                                         (not strsubst)
-                                        (not exports))))))
+                                        (not exports)
+                                        (not pkg)))
+                              )))
   (b* ((stobjp (fgetprop stobjname 'acl2::stobj nil world))
        (absstobjp (fgetprop stobjname 'acl2::absstobj-info nil world))
        (pkg (or pkg name))
