@@ -37,7 +37,7 @@
 
 (in-package "STR")
 (include-book "pretty")
-(include-book "misc/assert" :dir :system)
+(include-book "std/testing/assert" :dir :system)
 (include-book "std/osets/top" :dir :system)
 (include-book "std/util/defconsts" :dir :system)
 (include-book "centaur/misc/memory-mgmt" :dir :system)
