@@ -32,10 +32,14 @@
 ;
 ; This file is adapted from the Milawa Theorem Prover, Copyright (C) 2005-2009
 ; Kookamara LLC, which is also available under an MIT/X11 style license.
+;
+; Contribution by Alessandro Coglio (coglio@kestrel.edu):
+; Add support for :PRED option of DEFAGGREGATE.
 
 (in-package "STD")
 (include-book "support")
 (include-book "tools/rulesets" :dir :system)
+(include-book "cons")
 
 (defsection tag
   :parents (defaggregate)
@@ -97,7 +101,18 @@ fty::deftranssum).</p>"
      hons
      booleanp
      booleanp-compound-recognizer
-     tag)
+     prod-car
+     prod-cdr
+     prod-hons
+     prod-cons-with-hint
+     cons-with-hint
+     booleanp-of-prod-consp
+     prod-consp-compound-recognizer
+     prod-consp-of-prod-cons
+     car-of-prod-cons
+     cdr-of-prod-cons
+     prod-cons-of-car/cdr
+     prod-cons-when-either)
    (theory 'minimal-theory)))
 
 
@@ -129,16 +144,28 @@ fty::deftranssum).</p>"
             (da-accessor-names basename (cdr fields)))
     nil))
 
-(defun da-recognizer-name (basename)
-  (intern-in-package-of-symbol
-   (concatenate 'string (symbol-name basename) "-P")
-   basename))
+(defun da-recognizer-name (basename pred)
+  ;; PRED is the :PRED option of DEFAGGREGATE, or NIL for DEF-PRIMITIVE-AGGREGATE.
+  (or pred
+      (intern-in-package-of-symbol
+       (concatenate 'string (symbol-name basename) "-P")
+       basename)))
 
 (defun da-changer-name (basename)
   (intern-in-package-of-symbol
    (concatenate 'string "CHANGE-" (symbol-name basename))
    basename))
 
+(defun da-changer-fn-name (basename)
+  (intern-in-package-of-symbol
+   (concatenate 'string "CHANGE-" (symbol-name basename) "-FN")
+   basename))
+
+(defun da-remake-name (basename)
+  (intern-in-package-of-symbol
+   (concatenate 'string "REMAKE-" (symbol-name basename))
+   basename))
+
 (defun da-maker-name (basename)
   (intern-in-package-of-symbol
    (concatenate 'string "MAKE-" (symbol-name basename))
@@ -152,26 +179,30 @@ fty::deftranssum).</p>"
 
 ; FIELDS MAPS.
 ;
-; We can lay out the components of the structure in one of three ways:
+; Supported layouts:
 ;
-;   :legible    -- alist-based recognizer (any order permitted)
+;   :alist      -- alist-based recognizer (any order permitted)
 ;   :ordered    -- ordered alist-based recognizer (but still with names)
-;   :illegible  -- tree-based recognizer without names
-;
-; Illegible structures are most efficient, but are not very convenient when you
-; are trying to debug your code.  By default, we lay out the structure legibly.
+;   :tree       -- tree-based recognizer (using prod-cons)
+;   :fulltree   -- tree based recognizer (using ordinary cons)
 ;
 ; A "fields map" is an alist that binds each field name to an s-expression that
 ; describes how to access it.  For instance, suppose the fields are (A B C).
-; For a legible structure, the fields map will be:
+; For an alist layout structure, the fields map will be:
 ;
 ;   ((A . (cdr (assoc 'a <body>)))
 ;    (B . (cdr (assoc 'b <body>)))
 ;    (C . (cdr (assoc 'c <body>))))
 ;
 ; Where <body> is either X or (cdr X), depending on whether the structure is
-; tagless or not.  For an illegible structure, the (cdr (assoc ...)) terms just
-; get replaced with something horrible like (CAR (CDR (CAR <body>))).
+; tagless or not.
+;
+; For structures of other layouts, the (cdr (assoc ...)) terms just get
+; replaced with something else, e.g., for a :fulltree structure we might have
+; something like (CAR (CDR (CAR <body>))).  For a :tree structure instead of
+; CAR/CDR we'll have PROD-CAR/PROD-CDR.  For a :list structure, we'll have
+; something essentially like (first <body>), (second <body>), etc., except
+; that they'll be the CAR/CDR expansions of that.
 
 (defun da-body (basename tag)
   (if tag
@@ -192,54 +223,89 @@ fty::deftranssum).</p>"
              (cons (da-illegible-split-fields firsthalf)
                    (da-illegible-split-fields lasthalf)))))))
 
-(defun da-illegible-fields-map-aux (split-fields path)
+(defun da-illegible-fields-map-aux (split-fields path car cdr)
   ;; Convert the balanced tree into a map from field names to paths, e.g.,
   ;; field1 might be bound to (car (car x)), field2 to (cdr (car x)), etc.
+  ;; The variables car and cdr might be 'car and 'cdr or 'prod-car and 'prod-cdr
   (if (consp split-fields)
-      (append (da-illegible-fields-map-aux (car split-fields) `(car ,path))
-              (da-illegible-fields-map-aux (cdr split-fields) `(cdr ,path)))
+      (append (da-illegible-fields-map-aux (car split-fields) `(,car ,path) car cdr)
+              (da-illegible-fields-map-aux (cdr split-fields) `(,cdr ,path) car cdr))
     (list (cons split-fields path))))
 
-(defun da-illegible-fields-map (basename tag fields)
+(defun da-illegible-fields-map (basename tag fields car cdr)
   ;; Convert a linear list of fields into a map from field names to paths.
   (da-illegible-fields-map-aux (da-illegible-split-fields fields)
-                               (da-body basename tag)))
+                               (da-body basename tag)
+                               car cdr))
 
-(defun da-illegible-structure-checks-aux (split-fields path)
+(defun da-illegible-structure-checks-aux (split-fields path consp car cdr)
   ;; Convert the balanced tree into a list of the consp checks we'll need.
   (if (consp split-fields)
-      (cons `(consp ,path)
-            (append (da-illegible-structure-checks-aux (car split-fields) `(car ,path))
-                    (da-illegible-structure-checks-aux (cdr split-fields) `(cdr ,path))))
+      (cons `(,consp ,path)
+            (append (da-illegible-structure-checks-aux (car split-fields) `(,car ,path) consp car cdr)
+                    (da-illegible-structure-checks-aux (cdr split-fields) `(,cdr ,path) consp car cdr)))
     nil))
 
-(defun da-illegible-structure-checks (basename tag fields)
+(defun da-illegible-structure-checks (basename tag fields consp car cdr)
   ;; Convert a linear list of fields into the consp checks we'll need.
   (da-illegible-structure-checks-aux (da-illegible-split-fields fields)
-                                     (da-body basename tag)))
+                                     (da-body basename tag)
+                                     consp car cdr))
 
-(defun da-illegible-pack-aux (honsp split-fields)
+(defun da-illegible-pack-aux (cons split-fields)
   ;; Convert the tree of split fields into a cons tree for building the struct.
+  ;; Cons might be cons, hons, prod-cons, or prod-hons
   (if (consp split-fields)
-      `(,(if honsp 'hons 'cons)
-        ,(da-illegible-pack-aux honsp (car split-fields))
-        ,(da-illegible-pack-aux honsp (cdr split-fields)))
+      `(,cons
+        ,(da-illegible-pack-aux cons (car split-fields))
+        ,(da-illegible-pack-aux cons (cdr split-fields)))
     split-fields))
 
-(defun da-illegible-pack-fields (honsp tag fields)
-  ;; Convert a linear list of fields into consing code
-  (let ((body (da-illegible-pack-aux honsp (da-illegible-split-fields fields))))
+(defun da-illegible-pack-fields (layout honsp tag fields)
+  ;; Convert a linear list of fields into consing code.  This is used for
+  ;; the constructor.
+  (b* ((cons (cond ((eq layout :fulltree) (if honsp 'hons 'cons))
+                   ((eq layout :tree)     (if honsp 'prod-hons 'prod-cons))
+                   (t (er hard? 'da-illegible-pack-fields "Bad layout ~x0" layout))))
+       (body (da-illegible-pack-aux cons (da-illegible-split-fields fields))))
     (if tag
         `(,(if honsp 'hons 'cons) ,tag ,body)
       body)))
 
+(defun da-illegible-remake-aux (split-fields path cons-with-hint car cdr)
+  ;; Convert the tree of split fields into a cons-with-hint tree for changing
+  ;; structures.  Only for non-honsed structures.  Cons-with-hint is either
+  ;; 'cons-with-hint or 'prod-cons-with-hint.
+  (if (consp split-fields)
+      `(,cons-with-hint
+        ,(da-illegible-remake-aux (car split-fields) `(,car ,path) cons-with-hint car cdr)
+        ,(da-illegible-remake-aux (cdr split-fields) `(,cdr ,path) cons-with-hint car cdr)
+        ,path)
+    split-fields))
+
+(defun da-illegible-remake-fields (basename layout tag fields)
+  (b* (((mv cons-with-hint car cdr)
+        (cond ((eq layout :fulltree) (mv 'cons-with-hint 'car 'cdr))
+              ((eq layout :tree)     (mv 'prod-cons-with-hint 'prod-car 'prod-cdr))
+              (t (mv (er hard? 'da-illegible-remake-fields "Bad layout ~x0" layout)
+                     nil nil))))
+       (x            (da-x basename))
+       (body         (da-body basename tag))
+       (split-fields (da-illegible-split-fields fields))
+       (new-body     (da-illegible-remake-aux split-fields body cons-with-hint car cdr)))
+    (if tag
+        `(cons-with-hint ,tag ,new-body ,x)
+      new-body)))
+
 #||
-(da-illegible-fields-map 'taco :taco '(shell meat cheese lettuce sauce))
-(da-illegible-pack-fields nil :taco '(shell meat cheese lettuce sauce))
-
-;; (CONS :TACO (CONS (CONS SHELL MEAT)
-;;                   (CONS CHEESE (CONS LETTUCE SAUCE))))
+(da-illegible-fields-map 'taco :taco '(shell meat cheese lettuce sauce) 'car 'cdr)
+(da-illegible-pack-fields :tree nil :taco '(shell meat cheese lettuce sauce))
+(da-illegible-pack-fields :fulltree nil :taco '(shell meat cheese lettuce sauce))
+(da-illegible-pack-fields :tree t :taco '(shell meat cheese lettuce sauce))
+(da-illegible-pack-fields :fulltree t :taco '(shell meat cheese lettuce sauce))
 
+(da-illegible-remake-fields 'taco :tree :taco '(shell meat cheese lettuce sauce))
+(da-illegible-remake-fields 'taco :fulltree :taco '(shell meat cheese lettuce sauce))
 ||#
 
 (defun da-legible-fields-map (basename tag fields)
@@ -268,6 +334,8 @@ fty::deftranssum).</p>"
 
 (da-legible-fields-map 'taco :taco '(shell meat cheese lettuce sauce))
 (da-legible-pack-fields nil :taco '(shell meat cheese lettuce sauce))
+(da-legible-pack-fields t :taco '(shell meat cheese lettuce sauce))
+
 
 ;; (CONS :TACO (CONS (CONS 'SHELL SHELL)
 ;;                   (CONS (CONS 'MEAT MEAT)
@@ -308,8 +376,6 @@ fty::deftranssum).</p>"
         `(,(if honsp 'hons 'cons) ,tag ,body)
       body)))
 
-
-
 (defun da-ordered-structure-checks-aux (fields path)
   ;; Path is something like (cdddr x).  It's how far down the structure
   ;; we are, so far.
@@ -337,24 +403,29 @@ fty::deftranssum).</p>"
 (defun da-fields-map (basename tag layout fields)
   ;; Create a fields map of the appropriate type
   (case layout
-    (:legible (da-legible-fields-map basename tag fields))
-    (:ordered (da-ordered-fields-map 0 basename tag fields))
-    (:illegible (da-illegible-fields-map basename tag fields))))
+    (:alist    (da-legible-fields-map basename tag fields))
+    (:list     (da-ordered-fields-map 0 basename tag fields))
+    (:tree     (da-illegible-fields-map basename tag fields 'prod-car 'prod-cdr))
+    (:fulltree (da-illegible-fields-map basename tag fields 'car 'cdr))
+    (otherwise (er hard? 'da-fields-map "Bad layout ~x0" layout))))
 
 (defun da-pack-fields (honsp layout tag fields)
   ;; Create a fields map of the appropriate type
   (case layout
-    (:legible   (da-legible-pack-fields honsp tag fields))
-    (:ordered   (da-ordered-pack-fields honsp tag fields))
-    (:illegible (da-illegible-pack-fields honsp tag fields))))
+    (:alist            (da-legible-pack-fields honsp tag fields))
+    (:list             (da-ordered-pack-fields honsp tag fields))
+    ((:tree :fulltree) (da-illegible-pack-fields layout honsp tag fields))
+    (otherwise         (er hard? 'da-pack-fields "Bad layout ~x0" layout))))
 
 (defun da-structure-checks (basename tag layout fields)
   ;; Check that the object's cdr has the appropriate cons structure
   (case layout
-    (:legible `((alistp ,(da-body basename tag))
+    (:alist   `((alistp ,(da-body basename tag))
                 (consp ,(da-body basename tag))))
-    (:ordered   (da-ordered-structure-checks basename tag fields))
-    (:illegible (da-illegible-structure-checks basename tag fields))))
+    (:list     (da-ordered-structure-checks basename tag fields))
+    (:tree     (da-illegible-structure-checks basename tag fields 'prod-consp 'prod-car 'prod-cdr))
+    (:fulltree (da-illegible-structure-checks basename tag fields 'consp 'car 'cdr))
+    (otherwise (er hard? 'da-structure-checks "Bad layout ~x0" layout))))
 
 (defun da-fields-map-let-bindings (map)
   ;; Convert a fields map into a list of let bindings
@@ -412,13 +483,13 @@ fty::deftranssum).</p>"
             :exec ,(da-pack-fields t layout tag fields)))))
 
 
-
 ; (FOOP X) RECOGNIZER.
 
-(defun da-make-recognizer-raw (basename tag fields guard layout)
+(defun da-make-recognizer-raw (basename tag fields guard layout pred)
   ;; Previously we allowed recognizers to be inlined, but now we prefer to
   ;; only inline accessors.
-  (let* ((foo-p      (da-recognizer-name basename))
+  ;; PRED is the :PRED option of DEFAGGREGATE, or NIL for DEF-PRIMITIVE-AGGREGATE.
+  (let* ((foo-p      (da-recognizer-name basename pred))
          (x          (da-x basename))
          (fields-map (da-fields-map basename tag layout fields))
          (let-binds  (da-fields-map-let-bindings fields-map)))
@@ -455,8 +526,9 @@ fty::deftranssum).</p>"
 
 ; (FOO->BAR X) ACCESSORS.
 
-(defun da-make-accessor (basename field map)
-  (let ((foo-p    (da-recognizer-name basename))
+(defun da-make-accessor (basename field map pred)
+  ;; PRED is the :PRED option of DEFAGGREGATE, or NIL for DEF-PRIMITIVE-AGGREGATE.
+  (let ((foo-p    (da-recognizer-name basename pred))
         (foo->bar (da-accessor-name basename field))
         (x        (da-x basename))
         (body     (cdr (assoc field map))))
@@ -487,14 +559,17 @@ fty::deftranssum).</p>"
 
 ||#
 
-(defun da-make-accessors-aux (basename fields map)
+(defun da-make-accessors-aux (basename fields map pred)
+  ;; PRED is the :PRED option of DEFAGGREGATE, or NIL for DEF-PRIMITIVE-AGGREGATE.
   (if (consp fields)
-      (cons (da-make-accessor basename (car fields) map)
-            (da-make-accessors-aux basename (cdr fields) map))
+      (cons (da-make-accessor basename (car fields) map pred)
+            (da-make-accessors-aux basename (cdr fields) map pred))
     nil))
 
-(defun da-make-accessors (basename tag fields layout)
-  (da-make-accessors-aux basename fields (da-fields-map basename tag layout fields)))
+(defun da-make-accessors (basename tag fields layout pred)
+  ;; PRED is the :PRED option of DEFAGGREGATE, or NIL for DEF-PRIMITIVE-AGGREGATE.
+  (da-make-accessors-aux basename fields
+                         (da-fields-map basename tag layout fields) pred))
 
 (defun da-make-accessor-of-constructor (basename field all-fields)
   (let ((foo->bar (da-accessor-name basename field))
@@ -523,6 +598,40 @@ fty::deftranssum).</p>"
 
 ; (CHANGE-FOO ...) MACRO.
 
+(defun da-layout-supports-remake-p (honsp layout)
+  ;; If the structure is honsed there's no sense in trying to reusing the
+  ;; original structure, because we're going to re-hons it anyway and that'll
+  ;; share everything.
+  ;;
+  ;; We don't yet support remaking of lists or alists.  It might be sensible to
+  ;; add a remaker function for list layout, but for now we won't bother since
+  ;; if you care about memory usage you're probably using a tree layout.
+  (and (member layout '(:tree :fulltree))
+       (not honsp)))
+
+(defun da-maybe-remake-name (basename honsp layout)
+  (and (da-layout-supports-remake-p honsp layout)
+       (da-remake-name basename)))
+
+(defun da-make-remaker-raw (basename tag fields guard honsp layout pred)
+  ;; PRED is the :PRED option of DEFAGGREGATE, or NIL for DEF-PRIMITIVE-AGGREGATE.
+  (b* (((unless (da-layout-supports-remake-p honsp layout))
+        nil)
+       (x          (da-x basename))
+       (foo        (da-constructor-name basename))
+       (foo-p      (da-recognizer-name basename pred))
+       (remake-foo (da-remake-name basename)))
+    `((defun ,remake-foo (,x . ,fields)
+        (declare (xargs :guard (and (,foo-p ,x) ,guard)
+                        :guard-hints
+                        (("Goal"
+                          :expand ((,foo-p ,x)
+                                   (,foo . ,fields))
+                          :in-theory (union-theories '(,foo ,foo-p)
+                                                     (theory 'defaggregate-basic-theory))))))
+        (mbe :logic (,foo . ,fields)
+             :exec ,(da-illegible-remake-fields basename layout tag fields))))))
+
 (defun da-make-valid-fields-for-changer (fields)
   ;; Convert field names into keywords for use in da-changer-args-to-alist.
   (if (consp fields)
@@ -554,60 +663,125 @@ fty::deftranssum).</p>"
     (cons (cons field value)
           rest)))
 
-(defun da-changer-fill-in-fields
-  ;; Build the actual arguments to give to the structure's raw constructor
-  (obj        ; object being changed, in case we need to extract fields from it
-   acc-map    ; binds keywordified fields to their accessors, ordered per constructor
-   alist      ; binds keywordified fields to their values, if provided by the user
+;; Gross but workable strategy for constructing let bindings that work:
+;;
+;;   1. For all fields that the user has supplied a value for, bind the
+;;   ACCESSOR'S NAME, which is weird but works out well, to the provided value.
+;;   This happens before we bind anything else, with LET (not LET*) semantics,
+;;   so there is no possibility of inadvertent capture.
+;;
+;;      (foo->a 5)
+;;      (foo->b 6)
+;;      ...
+;;
+;;   2. In the same LET, bind the CHANGE MACRO NAME, which again is weird but
+;;   works out well, to the actual object being changed.  I.e., if someone
+;;   writes (change-foo (blah x y) :a 5 ...), then we will bind
+;;
+;;      (change-foo (blah x y))
+;;
+;;   This can't clash with the accessor names we're binding above, because the
+;;   change macro can't have the same name as an accessor.  Also LET semantics
+;;   ensures that X and Y are not inadvertently bound to foo->a or anything
+;;   like that.
+;;
+;;   3. After the above bindings, invoke the constructor on the "obvious"
+;;   arguments.  For any argument that has a binding, use the variable.  For
+;;   any argument without a binding, use (accessor-name change-foo).
+
+(defun da-changer-let-bindings-and-args
+  (change-name ; variable to extract unchanged fields from
+   acc-map     ; binds keywordified fields to their accessors, ordered per constructor
+   alist       ; binds keywordified fields to their values, if provided by the user
    )
+  ;; We return the bindings separately because it allows us to build a suitable
+  ;; LET structure that avoids capture issues, below.
+  "Returns (mv let-bindings constructor-args)"
   (b* (((when (atom acc-map))
-        nil)
-       (rest (da-changer-fill-in-fields obj (cdr acc-map) alist))
+        (mv nil nil))
+       ((mv rest-bindings rest-args) (da-changer-let-bindings-and-args change-name (cdr acc-map) alist))
        ((cons field1 accessor1) (car acc-map))
        (look1 (assoc field1 alist))
        ((when look1)
-        ;; User gave us a value for this field, so insert it.
-        (cons (cdr look1) rest)))
-    ;; No value for this field, so get it from the object.
-    (cons `(,accessor1 ,obj) rest)))
+        ;; User gave us a value for this field, so bind it as part of the fresh
+        ;; bindings and use the binding as its argument.
+        (mv (cons (list accessor1 (cdr look1)) rest-bindings)
+            (cons accessor1 rest-args))))
+    ;; User gave no value for this field, so keep its previous value
+    (mv rest-bindings
+        (cons `(,accessor1 ,change-name) rest-args))))
+
+#||
+
+;; For example:
+
+(da-changer-let-bindings-and-args 'change-foo
+                                  '((:a . foo->a)
+                                    (:b . foo->b)
+                                    (:c . foo->c)
+                                    (:d . foo->d))
+                                  '((:a . 5)
+                                    (:c . 4)))
+
+;;  Gives us let bindings for the user-supplied args:
+;;
+;;     ((foo->a 5)
+;;      (foo->c 4))
+;;
+;;  And gives us args for the constructor:
+;;
+;;     (foo->a (foo->b change-foo) foo->c (foo->d change-foo))
+
+||#
 
 (defun change-aggregate
+  ;; Change an arbitrary aggregate.
   (basename    ; basename for this structure, for name generation
    obj         ; object being changed, e.g., a term in the user's program.
    args        ; user-level arguments to the change macro, e.g., (:name newname :age 5)
    acc-map     ; binds fields to their accessors, e.g., ((name . student->name) ...), ordered per constructor
-   macroname   ; e.g., change-student, for error reporting
+   macroname   ; e.g., change-student, for error reporting and let binding
+   remake-name ; NIL if there is no remake-function (in which case just use the constructor) or
+               ; the name of the REMAKE function to invoke, otherwise.
    )
-  (b* ((ctor-name  (da-constructor-name basename))
-       (kwd-fields (strip-cars acc-map))
+  (b* ((kwd-fields (strip-cars acc-map))
        (alist      (da-changer-args-to-alist macroname args kwd-fields))
-       (nobind-p   (or
-                    ;; If the object being changed is already evaluated, there's no
-                    ;; need to evaluate it. (variables, constants)
-                    (atom obj)
-                    (and (consp obj)
-                         (equal (car obj) 'quote))
-                    ;; If the object being changed is never accessed, there's no
-                    ;; need to evaluate it.
-                    (subsetp kwd-fields (strip-cars alist))))
-       (newvar     (if nobind-p
-                       obj
-                     (acl2::pack (cons macroname obj))))
-       (ctor-call  (cons ctor-name
-                         (da-changer-fill-in-fields newvar acc-map alist))))
-    (if nobind-p
-        ctor-call
-      `(let ((,newvar ,obj))
-         ,ctor-call))))
+       (all-setp   (subsetp kwd-fields (strip-cars alist)))
+       (remake-name
+        ;; If the user is providing a new value for every possible field, then
+        ;; there's no reason to try to reuse parts of the original object.
+        ;; Just construct a new one.
+        (and (not all-setp) remake-name))
+       ((mv arg-bindings ctor-args)
+        (da-changer-let-bindings-and-args macroname acc-map alist))
+       (ctor-name (da-constructor-name basename)))
+    (if (not remake-name)
+        ;; Easy case, just call the constructor on its arguments.
+        (if all-setp
+            ;; Special case: no need to bind the macro name.
+            `(let ,arg-bindings (,ctor-name . ,ctor-args))
+          ;; Usual case: need to bind the macro name.
+          `(let ((,macroname ,obj) . ,arg-bindings)
+             (,ctor-name . ,ctor-args)))
+      ;; Else we want to use the fancy remake function to avoid reconsing.  We
+      ;; use the MBE here because, when you prove a theorem about the change
+      ;; macro, we want it to be a theorem about the constructor instead of a
+      ;; theorem about the remake-function.  BOZO should we be using let-mbe
+      ;; instead?  It doesn't like that the two calls don't take the same
+      ;; arguments.  Does it do anything fancy for us?
+      `(let ((,macroname ,obj) . ,arg-bindings)
+         (mbe :logic (,ctor-name . ,ctor-args)
+              :exec  (,remake-name ,macroname . ,ctor-args))))))
 
-(defun da-make-changer (basename fields)
-  (let* ((x          (da-x basename))
-         (change-foo (da-changer-name basename))
-         (acc-names  (da-accessor-names basename fields))
-         (kwd-fields (da-make-valid-fields-for-changer fields))
-         (acc-map    (pairlis$ kwd-fields acc-names)))
+
+(defun da-make-changer (basename fields remake-name)
+  (b* ((x          (da-x basename))
+       (change-foo (da-changer-name basename))
+       (acc-names  (da-accessor-names basename fields))
+       (kwd-fields (da-make-valid-fields-for-changer fields))
+       (acc-map    (pairlis$ kwd-fields acc-names)))
     `(defmacro ,change-foo (,x &rest args)
-       (change-aggregate ',basename ,x args ',acc-map ',change-foo))))
+       (change-aggregate ',basename ,x args ',acc-map ',change-foo ',remake-name))))
 
 
 ; (MAKE-FOO ...) MACRO.
@@ -685,14 +859,14 @@ fty::deftranssum).</p>"
     (da-patbind-find-used-vars (car form) varstrs
                                (da-patbind-find-used-vars (cdr form) varstrs acc))))
 
-(defun da-patbind-alist-to-bindings (vars valist target)
+(defun da-patbind-alist-to-bindings (vars valist target extra-args)
   (if (atom vars)
       nil
     (let* ((accessor (cdr (assoc-equal (symbol-name (car vars)) valist)))
-           (call     (list accessor target))     ;; (taco->shell foo)
+           (call     (list* accessor target extra-args))     ;; (taco->shell foo extra-args)
            (binding  (list (car vars) call))) ;; (x.foo (taco->shell foo))
       (cons binding
-            (da-patbind-alist-to-bindings (cdr vars) valist target)))))
+            (da-patbind-alist-to-bindings (cdr vars) valist target extra-args)))))
 
 ;; notes: fields-accs is now a mapping from field names to accessors.
 ;; Defaggregate itself just needs the field names because it always generates
@@ -700,7 +874,7 @@ fty::deftranssum).</p>"
 ;; context where the accessors are various different sorts of things.
 (defun da-patbind-fn (name fields-accs args forms rest-expr)
   (b* (((mv kwd-alist args)
-        (extract-keywords `(da-patbind-fn ',name) '(:quietp) args nil))
+        (extract-keywords `(da-patbind-fn ',name) '(:quietp :extra-args) args nil))
        ;; allow ((binder name)) abbrev for ((binder name) name)
        (forms (if (and (not forms)
                        (tuplep 1 args)
@@ -730,7 +904,8 @@ fty::deftranssum).</p>"
               (cw "Note: not introducing any ~x0 field bindings for ~x1, ~
                    since none of its fields appear to be used.~%" name var)))
 
-       (bindings (da-patbind-alist-to-bindings used-vars full-vars-alist var)))
+       (bindings (da-patbind-alist-to-bindings used-vars full-vars-alist var
+                                               (cdr (assoc :extra-args kwd-alist)))))
     (if (eq var (car forms))
         ;; No need to rebind: this actually turns out to matter for some
         ;; expansion heuristics in the svex library (3vec-fix), which is
@@ -758,15 +933,16 @@ fty::deftranssum).</p>"
 
 (defun def-primitive-aggregate-fn (basename fields tag)
   (let ((honsp nil)
-        (layout :legible)
+        (layout :alist)
         (guard t))
     `(progn
-       ,(da-make-recognizer-raw basename tag fields guard layout)
+       ,(da-make-recognizer-raw basename tag fields guard layout nil)
        ,(da-make-constructor-raw basename tag fields guard honsp layout)
-       ,@(da-make-accessors basename tag fields layout)
+       ,@(da-make-accessors basename tag fields layout nil)
        ,@(da-make-accessors-of-constructor basename fields)
+       ,@(da-make-remaker-raw basename tag fields guard honsp layout nil)
        ,(da-make-binder basename fields)
-       ,(da-make-changer basename fields)
+       ,(da-make-changer basename fields (da-maybe-remake-name basename honsp layout))
        ,(da-make-maker basename fields nil))))
 
 (defmacro def-primitive-aggregate (name fields &key tag)
