@@ -30,7 +30,7 @@
 
 (in-package "STD")
 (include-book "../defprojection")
-(include-book "misc/assert" :dir :system)
+(include-book "std/testing/assert" :dir :system)
 
 (make-event
  (prog2$
