@@ -39,7 +39,7 @@
 (include-book "std/strings/top" :dir :system)
 (include-book "std/osets/sort" :dir :system)
 (include-book "xdoc/parse-xml" :dir :system)
-(include-book "misc/assert" :dir :system)
+(include-book "std/testing/assert" :dir :system)
 (set-state-ok t)
 (program)
 
