@@ -30,7 +30,7 @@
 
 (in-package "ACL2")
 (include-book "hons-check")
-(include-book "misc/assert" :dir :system)
+(include-book "std/testing/assert" :dir :system)
 (include-book "std/osets/top" :dir :system)
 
 ; cert_param: (hons-only)
