@@ -2,6 +2,11 @@
 ; Written by David Rager (original date April, 2012)
 ; License: A 3-clause BSD license.  See the LICENSE file distributed with ACL2.
 
+; Modified 8/2016 by Matt Kaufmann, so that termination and guards are also
+; verified for remove-lambdas (and also remove-lambdas1 and
+; remove-lambdas-lst).  That work is added here because it depends on
+; properties of subcor-var that are local to this book.
+
 (in-package "ACL2")
 
 (include-book "sublis-var") ; for verification of cons-term
@@ -79,3 +84,41 @@
                             (x form))))))
 
 (verify-guards subcor-var)
+
+; The following events verify termination and guards for remove-lambdas (and
+; also for remove-lambdas1 and remove-lambdas-lst).
+
+(verify-termination remove-lambdas1) ; and remove-lambdas-lst
+(verify-termination remove-lambdas)
+
+(local (include-book "tools/flag" :dir :system))
+
+(local (make-flag flag-remove-lambdas remove-lambdas1))
+
+; Useful here: pseudo-term-listp-subcor-var-lst
+; and pseudo-term-listp-subcor-var, proved above.
+
+(local
+ (defthm len-mv-nth-1-remove-lambdas-lst
+   (equal (len (mv-nth 1 (remove-lambdas-lst x)))
+          (len x))))
+
+(local
+ (defthm-flag-remove-lambdas
+   (defthm pseudo-termp-mv-nth-1-remove-lambdas1
+     (implies (pseudo-termp term)
+              (pseudo-termp (mv-nth 1 (remove-lambdas1 term))))
+     :flag remove-lambdas1)
+   (defthm pseudo-term-listp-mv-nth-1-remove-lambdas-lst
+     (implies (pseudo-term-listp termlist)
+              (pseudo-term-listp (mv-nth 1 (remove-lambdas-lst termlist))))
+     :flag remove-lambdas-lst)))
+
+(local
+ (defthm true-listp-mv-nth-1-remove-lambdas-lst
+   (implies (force (true-listp lst))
+            (true-listp (mv-nth 1 (remove-lambdas-lst lst))))
+   :rule-classes :type-prescription))
+
+(verify-guards remove-lambdas1) ; and remove-lambdas-lst
+(verify-guards remove-lambdas)
