@@ -21,8 +21,8 @@
 
 (in-package "ACL2")
 
-(include-book "misc/eval" :dir :system) ; defines must-fail
-(include-book "misc/assert" :dir :system)
+(include-book "std/testing/eval" :dir :system) ; defines must-fail
+(include-book "std/testing/assert" :dir :system)
 
 (defmacro local-test (&key defs run check)
 
@@ -35,8 +35,11 @@
      ,@defs
      (make-event
       (er-progn (trans-eval ',run 'top state t)
-                (assert-event ,check :on-skip-proofs t)
-                (value '(value-triple '(value-triple :success))))))))
+                (mv-let (erp val state)
+                  (trans-eval ',check 'top state t)
+                  (if (and (null erp) val)
+                      (value '(value-triple '(value-triple :success)))
+                    (er soft 'top "Check failed!"))))))))
 
 ; As promised in :doc stobj-let, we begin with an example from that :doc.
 
