@@ -8,8 +8,8 @@
 
 (in-package "ACL2")
 
-(include-book "misc/assert" :dir :system)
-(include-book "misc/eval" :dir :system)
+(include-book "std/testing/assert" :dir :system)
+(include-book "std/testing/eval" :dir :system)
 
 ; The file read-file-into-string-test.txt should be kept in sync with the
 ; following constant.
