@@ -1,6 +1,6 @@
-; XDOC Constructors
+; XDOC Documentation System for ACL2
 ;
-; Copyright (C) 2019 Kestrel Institute (http://www.kestrel.edu)
+; Copyright (C) 2020 Kestrel Institute (http://www.kestrel.edu)
 ;
 ; License: A 3-clause BSD license. See the LICENSE file distributed with ACL2.
 ;
@@ -11,7 +11,7 @@
 (in-package "XDOC")
 
 ; Only the following book should be non-locally included here,
-; to minimize footprint and dependencies of this XDOC constructor library.
+; to minimize footprint and dependencies.
 (include-book "top")
 
 ; The books locally included here should be minimized, for the above reason.
@@ -47,13 +47,18 @@
       and adding XML tags and preprocessor directives
       at the roots of the trees.</p>
    <p>With these XDOC constructors, one can write</p>
-   <code>(xdoc::topstring
-           (xdoc::p \"A paragraph.\")
-           (xdoc::ul
-             (xdoc::li \"One.\")
-             (xdoc::li \"Two.\")
-             (xdoc::li \"Three.\"))
-           (xdoc::p \"Another paragraph.\"))</code>
+   @({
+   (xdoc::topstring
+      (xdoc::p \"A paragraph.\")
+      (xdoc::ul
+        (xdoc::li \"One.\")
+        (xdoc::li \"Two.\")
+        (xdoc::li \"Three.\"))
+      (xdoc::p \"Another paragraph.\")
+      (xdoc::p \"See \"
+               (xdoc::a :href \"https://www.wikipedia.org\" \"Wikipedia\")
+               \".\"))
+   })
    <p>instead of</p>
    @({
      \"<p>A paragraph.</p>
@@ -62,7 +67,8 @@
         <li>Two.</li>
         <li>Three.</li>
       </ul>
-      <p>Another paragraph.</p>\"
+      <p>Another paragraph.</p>
+      <p>See <a href=\"https://www.wikipedia.org\">Wikipedia</a>.</p>\"
    })
    <p>The main advantage is that the XML tags (and preprocessor directives)
       will be always properly matched and nested by construction.
@@ -80,7 +86,7 @@
       it may be better to use tags and directives within a string
       rather than the corresponding XDOC constructors,
       e.g.</p>
-   <code>(xdoc::p \"This is in \<i\>italics\</i\>.\")</code>
+   @({(xdoc::p \"This is in <i>italics</i>.\")})
    <p>rather than</p>
    <code>(xdoc::p \"This is in \" (xdoc::i \"italics\") \".\")</code>
    <p>In other words,
@@ -219,7 +225,7 @@
     (true-listp (mv-nth 0 (partition-macro-args args ctx)))
     :hints (("Goal" :in-theory (enable partition-macro-args))))
 
-  (defthm true-listp-of-mv-nth-1-partition-macro-args
+  (defthm alistp-of-mv-nth-1-partition-macro-args
     (alistp (mv-nth 1 (partition-macro-args args ctx)))
     :hints (("Goal" :in-theory (enable partition-macro-args)))))
 
@@ -232,7 +238,7 @@
   "<p>This complements @(tsee partition-macro-args),
       which extracts a list of regular arguments
       and an alist of keyword arguments.
-      This alist has keys that are keyword
+      This alist has keys that are keywords
       but values that, in general, are terms that need to be evaluated
       to obtain the actual values of the keyword arguments;
       the terms are the ones supplied by the caller of the macro.
@@ -623,8 +629,21 @@
       In contrast, the
       <see topic='@(url composite-constructors)'>composite
       XDOC constructors</see>
-      correspond to multiple tags, directives, and concatenations.</p>
-   <p>Since the primitive constructors have a very uniform structure,
+      correspond to multiple tags, directives, and concatenations,
+      or provide a more concise notation for common attributes.</p>
+   <p>These primitive constructors are
+      macros with a variable number of arguments.
+      Each argument must be a tree or a keyword,
+      such that each keyword is immediately followed by a tree.
+      Each keyword-tree pair forms an attribute of an XML tag,
+      with the keyword naming the attribute
+      and the immediately following tree providing the value of the attribute.
+      Keyword-tree pairs can be used only in constructors for XML tags,
+      not in constructors for preprocessor directives or tree concatenation.
+      Keyword-tree pairs may occur anywhere in the argument list.
+      See the <see topic='@(url constructors)'>top-level topic</see>
+      for example calls of primitive constructors.</p>
+   <p>Since these primitive constructors have a very uniform structure,
       we introduce them via two event-generating macros,
       one for XML tags
       and one for preprocessor directives and tree concatenation.</p>")
@@ -669,14 +688,20 @@
                          (:see 'see_)
                          (t (intern$ (symbol-name tag) "XDOC"))))
            (fn-name (acl2::add-suffix-to-fn macro-name "-FN"))
-           (thm-name (acl2::packn (list 'stringp-of- macro-name))))
+           (thm-name (acl2::packn (list 'stringp-of- macro-name)))
+           (long (concatenate
+                  'string
+                  "<p>See the <see topic='@(url primitive-constructors)'
+                   >primitive constructors topic</see>
+                   for information about the kind of arguments
+                   that must be passed to this constructor.</p>"
+                  "@(def "
+                  (string-downcase$ (symbol-name macro-name))
+                  ")")))
       `(defsection ,macro-name
          :parents (primitive-constructors)
          :short ,doc
-         :long ,(concatenate 'string
-                             "@(def "
-                             (string-downcase$ (symbol-name macro-name))
-                             ").")
+         :long ,long
          (defund ,fn-name (attributes trees)
            (declare (xargs :guard (and (keyword-tree-alistp attributes)
                                        (tree-listp trees))))
@@ -730,7 +755,7 @@
                              (string-escape
                               (string-downcase$
                                (symbol-name macro-name)))
-                             ").")
+                             ")")
          (defund ,fn-name (trees)
            (declare (xargs :guard (tree-listp trees)))
            (make-tree-dir/&& ,dir/&& trees))
@@ -775,10 +800,10 @@
   "Construct an XDOC tree for an HTML list item @('<li>...</li>').")
 
 (generate-primitive-constructor-for-tag :ul
-  "Construct an XDOC tree for an HTML unordered list @('<ul>...</ul>').")
+  "Construct an XDOC tree for an HTML unordered (bulleted) list @('<ul>...</ul>').")
 
 (generate-primitive-constructor-for-tag :ol
-  "Construct an XDOC tree for an HTML unordered list @('<ol>...</ol>').")
+  "Construct an XDOC tree for an HTML ordered (numbered) list @('<ol>...</ol>').")
 
 (generate-primitive-constructor-for-tag :dt
   "Construct an XDOC tree for an HTML term @('<dt>...</dt>').")
@@ -937,7 +962,8 @@
   (xdoc::tree-to-string
    (xdoc::p
     "These correspond to multiple
-     XML tags, preprocessor directives, and concatenations.
+     XML tags, preprocessor directives, and concatenations,
+     or provide a more concise notation for common attributes.
      In contrast,
      the <see topic='@(url primitive-constructors)'>primitive
      constructors</see> correspond to single
@@ -968,10 +994,8 @@
   (xdoc::tree-to-string
    (xdoc::&&
     (xdoc::p
-     "A @(':long') documentation string often consists of
-      a series of one or more XDOC trees
-      for paragraphs, (un)ordered lists, code blocks, etc.
-      This function can be used to wrap them into a top-level ``pseudo-tag''.")
+     "This can be used to construct XDOC strings at the ``top level'',
+      e.g. @(':short') and @(':long') documentation string.")
     (xdoc::@def "topstring")))
 
   (defmacro topstring (&rest trees)
@@ -985,9 +1009,7 @@
   :long
   (xdoc::topstring
    (xdoc::p
-    "Sometimes a @(':long') documentation string consists of a single paragraph.
-     This macro wraps the arguments (often just one string)
-     into a paragraph tree and then calls @(tsee topstring).")
+    "This combines @(tsee topstring) with @(tsee p).")
    (xdoc::@def "topstring-p"))
 
   (defmacro topstring-p (&rest trees)
@@ -1001,10 +1023,7 @@
   :long
   (xdoc::topstring
    (xdoc::p
-    "Sometimes a @(':long') documentation string
-     consists of a single definition preprocessor directive.
-     This macro wraps the arguments (often just one string)
-     into a definition directive tree and then calls @(tsee topstring).")
+    "This combines @(tsee topstring) with @(tsee @def).")
    (xdoc::@def "topstring-@def"))
 
   (defmacro topstring-@def (&rest trees)
@@ -1117,7 +1136,26 @@
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(defsection seeurl
+(defsection ahref
+  :parents (generic-composite-constructors)
+  :short "Construct an XDOC tree for a string of the form
+          @('<a href=\"...\">...</a>')."
+  :long
+  (xdoc::topstring
+   (xdoc::p
+    "This is a fairly common pattern.
+     This XDOC constructor obviates the need to type @(':href'),
+     compared to the primitive constructor @(tsee a):
+     the first argument is always the URL,
+     and the remaining arguments form the text.")
+   (xdoc::@def "ahref"))
+
+  (defmacro ahref (href &rest text)
+    `(a :href ,href ,@text)))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(defsection seetopic
   :parents (generic-composite-constructors)
   :short "Construct an XDOC tree for a string of the form
           @('<see topic=\"@(url ...)\">...</see>')."
@@ -1128,7 +1166,7 @@
      with several opportunities for mistyping it.
      This XDOC constructor takes two strings as arguments,
      one for the topic and one for the hyperlinked text.")
-   (xdoc::@def "seeurl"))
+   (xdoc::@def "seetopic"))
 
-  (defmacro seeurl (topic text)
+  (defmacro seetopic (topic text)
     `(see_ :topic (@url ,topic) ,text)))
