@@ -1,5 +1,5 @@
-; ACL2 Version 8.2 -- A Computational Logic for Applicative Common Lisp
-; Copyright (C) 2019, Regents of the University of Texas
+; ACL2 Version 8.3 -- A Computational Logic for Applicative Common Lisp
+; Copyright (C) 2020, Regents of the University of Texas
 
 ; This version of ACL2 is a descendent of ACL2 Version 1.9, Copyright
 ; (C) 1997 Computational Logic, Inc.  See the documentation topic NOTE-2-0.
@@ -56,7 +56,7 @@
 (verify-termination-boot-strap cons-term) ; and guards
 (verify-termination-boot-strap symbol-class) ; and guards
 
-; packn1 and packn
+; packn1, packn, and pack-to-string
 
 (verify-termination-boot-strap packn1) ; and guards
 
@@ -78,6 +78,7 @@
 (verify-termination-boot-strap packn-pos) ; and guards
 (verify-termination-boot-strap find-first-non-cl-symbol) ; and guards
 (verify-termination-boot-strap packn) ; and guards
+(verify-termination-boot-strap pack-to-string) ; and guards
 )
 
 (verify-termination-boot-strap read-file-into-string1) ; and guards
@@ -90,6 +91,7 @@
 (verify-termination-boot-strap pairlis-x1) ; and guards
 (verify-termination-boot-strap pairlis-x2) ; and guards
 (verify-termination-boot-strap first-keyword) ; and guards
+(verify-termination-boot-strap symbol-name-lst) ; and guards
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Attachment: too-many-ifs-post-rewrite and too-many-ifs-pre-rewrite
@@ -1072,12 +1074,14 @@
                   :guard (symbolp name)))
   (let ((wrld (w state)))
     (or (getpropc name 'theorem nil wrld)
-        (mv-let (flg prop)
-          (constraint-info name wrld)
-          (cond ((unknown-constraints-p prop)
-                 *t*)
-                (flg (ec-call (conjoin prop)))
-                (t prop))))))
+        (cond ((logicp name wrld)
+               (mv-let (flg prop)
+                 (constraint-info name wrld)
+                 (cond ((unknown-constraints-p prop)
+                        *t*)
+                       (flg (ec-call (conjoin prop)))
+                       (t prop))))
+              (t *t*)))))
 
 (verify-termination-boot-strap type-set-quote)
 (verify-guards type-set-quote)
@@ -1195,20 +1199,23 @@
 
 (defun fncall-term (fn arglist state)
   (declare (xargs :stobjs state
-                  :guard (true-listp arglist)))
-  (mv-let (erp val)
-          (magic-ev-fncall fn arglist state
-                           t   ; hard-error-returns-nilp
-                           nil ; aok
-                           )
-          (cond (erp *t*)
-                (t (fcons-term* 'equal
+                  :guard (and (symbolp fn)
+                              (true-listp arglist))))
+  (cond ((logicp fn (w state))
+         (mv-let (erp val)
+           (magic-ev-fncall fn arglist state
+                            t  ; hard-error-returns-nilp
+                            nil ; aok
+                            )
+           (cond (erp *t*)
+                 (t (fcons-term* 'equal
 
 ; As suggested by Sol Swords, we use fcons-term below in order to avoid having
 ; to reason about the application of an evaluator to (cons-term fn ...).
 
-                                (fcons-term fn (kwote-lst arglist))
-                                (kwote val))))))
+                                 (fcons-term fn (kwote-lst arglist))
+                                 (kwote val))))))
+        (t *t*)))
 
 (defun logically-equivalent-states (st1 st2)
    (declare (xargs :guard t))
