@@ -1,5 +1,5 @@
-; ACL2 Version 8.2 -- A Computational Logic for Applicative Common Lisp
-; Copyright (C) 2019, Regents of the University of Texas
+; ACL2 Version 8.3 -- A Computational Logic for Applicative Common Lisp
+; Copyright (C) 2020, Regents of the University of Texas
 
 ; This version of ACL2 is a descendent of ACL2 Version 1.9, Copyright
 ; (C) 1997 Computational Logic, Inc.  See the documentation topic NOTE-2-0.
@@ -296,7 +296,7 @@
      (PLIST-WORLDP-WITH-FORMALS ACL2-COUNT ALIST)
      (PUSH-IO-RECORD)
      (RELATIVIZE-BOOK-PATH)
-     (REMOVE-GUARD-HOLDERS)
+     (REMOVE-GUARD-HOLDERS-WEAK)
      (REMOVE-GUARD-HOLDERS1 ACL2-COUNT TERM)
      (REMOVE-GUARD-HOLDERS1-LST ACL2-COUNT LST)
      (REMOVE-LAMBDAS)
@@ -403,6 +403,8 @@
      (TERM-LIST-LISTP ACL2-COUNT L)
      (TERM-LISTP ACL2-COUNT X)
      (TERMP ACL2-COUNT X)
+     (THEREIS$ ACL2-COUNT LST)
+     (THEREIS$+ ACL2-COUNT LST)
      (UNTIL$ ACL2-COUNT LST)
      (UNTIL$+ ACL2-COUNT LST)
      (UNTIL$+-AC ACL2-COUNT LST)
@@ -676,7 +678,7 @@
            (apply$-equivalence fn1 fn2))))
 
 (system-events "system/apply/apply"
-(defequiv fn-equal)
+(defequiv fn-equal :package :legacy)
 )
 
 (system-events "system/apply/loop-scions"
@@ -741,6 +743,8 @@
  (defwarrant sum$+)
  (defwarrant always$)
  (defwarrant always$+)
+ (defwarrant thereis$)
+ (defwarrant thereis$+)
  (defwarrant collect$-ac)
  (defwarrant collect$)
  (defwarrant collect$+-ac)
@@ -763,7 +767,10 @@
 ; We skip raw Lisp functions here; see *thread-unsafe-builtin-memoizations*.
 
   (memoize 'fchecksum-obj :stats nil :forget t)
-  (memoize 'pkg-names-memoize :stats nil :forget t)
+
+; We no longer define pkg-names-memoize (other than to cause an error); see the
+; comment there.
+; (memoize 'pkg-names-memoize :stats nil :forget t)
 
 ; Comment on memoizing a worse-than function:
 
