@@ -1,5 +1,5 @@
-; ACL2 Version 8.2 -- A Computational Logic for Applicative Common Lisp
-; Copyright (C) 2019, Regents of the University of Texas
+; ACL2 Version 8.3 -- A Computational Logic for Applicative Common Lisp
+; Copyright (C) 2020, Regents of the University of Texas
 
 ; This version of ACL2 is a descendent of ACL2 Version 1.9, Copyright
 ; (C) 1997 Computational Logic, Inc.  See the documentation topic NOTE-2-0.
@@ -98,8 +98,8 @@
         ADD-MATCH-FREE-OVERRIDE ADD-NTH-ALIAS
         ADD-OVERRIDE-HINTS ADD-OVERRIDE-HINTS!
         ADD-PAIR ADD-PAIR-PRESERVES-ALL-BOUNDP
-        ADD-RAW-ARITY ADD-TIMERS ADD-TO-SET ADD-TO-SET-EQ
-        ADD-TO-SET-EQL ADD-TO-SET-EQUAL
+        ADD-RAW-ARITY ADD-SUFFIX ADD-SUFFIX-TO-FN ADD-TIMERS
+        ADD-TO-SET ADD-TO-SET-EQ ADD-TO-SET-EQL ADD-TO-SET-EQUAL
         ALISTP ALISTP-FORWARD-TO-TRUE-LISTP
         ALL-BOUNDP ALL-BOUNDP-PRESERVES-ASSOC
         ALL-VARS ALL-VARS1 ALL-VARS1-LST
@@ -166,6 +166,7 @@
         CODE-CHAR-TYPE COERCE COERCE-INVERSE-1
         COERCE-INVERSE-2 COERCE-OBJECT-TO-STATE
         COERCE-STATE-TO-OBJECT
+        COMMENT
         COMMUNITY-BOOKS
         COMMUTATIVITY-OF-*
         COMMUTATIVITY-OF-+ COMP COMPLETION-OF-*
@@ -189,7 +190,7 @@
         COMPLEX-IMPLIES1 COMPLEX-RATIONALP
         COMPLEX/COMPLEX-RATIONALP
         COMPRESS1 COMPRESS11 COMPRESS2
-        COMPRESS21 COMPRESS211 CONCATENATE
+        COMPRESS21 COMPRESS211 CONCATENATE COUNT-KEYS
         DOPPELGANGER-APPLY$-USERFN DOPPELGANGER-BADGE-USERFN
         COND COND-CLAUSESP COND-MACRO
         CONJUGATE CONS CONS-EQUAL CONS-WITH-HINT CONSP
@@ -224,7 +225,8 @@
         DEFINE-PC-ATOMIC-MACRO DEFINE-PC-HELP
         DEFINE-PC-MACRO DEFINE-PC-META
         DEFINE-TRUSTED-CLAUSE-PROCESSOR
-        DEFLABEL DEFLOCK DEFMACRO DEFMACRO-LAST DEFN DEFND DEFPKG
+        DEFLABEL DEFLOCK DEFMACRO DEFMACRO-LAST DEFMACRO-UNTOUCHABLE
+        DEFN DEFND DEFPKG
         DEFPROXY DEFREC DEFREFINEMENT DEFSTOBJ DEFSTUB
         DEFTHEORY DEFTHEORY-STATIC
         DEFTHM DEFTHMD DEFTHY DEFTTAG
@@ -238,6 +240,7 @@
         DISABLE-IMMEDIATE-FORCE-MODEP
         DISABLEDP DISASSEMBLE$ DISTRIBUTIVITY
         DMR-START DMR-STOP DOC DOC! DOCS DOUBLE-REWRITE
+        DUMB-OCCUR DUMB-OCCUR-VAR
         DUPLICATES E/D E0-ORD-< E0-ORDINALP
         EC-CALL EIGHTH ELIMINATE-DESTRUCTORS
         ELIMINATE-IRRELEVANCE
@@ -353,6 +356,7 @@
         MAKE-VAR-LST MAKE-VAR-LST1
         MAKE-WORMHOLE-STATUS MAKUNBOUND-GLOBAL
         MAX MAXIMUM-LENGTH MAY-NEED-SLASHES
+        MAYBE-FLUSH-AND-COMPRESS1
         MBE MBT MBT*
         MEMBER MEMBER-EQ MEMBER-EQUAL MEMBER-SYMBOL-NAME
         META-EXTRACT-CONTEXTUAL-FACT META-EXTRACT-FORMULA
@@ -478,7 +482,7 @@
         RESET-PREHISTORY RESET-PRINT-CONTROL
         RESIZE-LIST REST RESTORE-MEMOIZATION-SETTINGS RETRACT-WORLD
         RETRIEVE RETURN-LAST RETURN-LAST-TABLE
-        REVAPPEND REVERSE REVERT-WORLD REWRITE-STACK-LIMIT
+        REVAPPEND REVERSE REVERT-WORLD REWRITE-EQUIV REWRITE-STACK-LIMIT
         RFIX ROUND RW-CACHE SATISFIES
         SAVE-AND-CLEAR-MEMOIZATION-SETTINGS SAVE-EXEC
         SEARCH SECOND
@@ -535,7 +539,7 @@
         SET-REGISTER-INVARIANT-RISK SET-REWRITE-STACK-LIMIT
         SET-RULER-EXTENDERS
         SET-RW-CACHE-STATE SET-RW-CACHE-STATE!
-        SET-SAVED-OUTPUT SET-SERIALIZE-CHARACTER SET-SERIALIZE-CHARACTER-SYSTEM
+        SET-SERIALIZE-CHARACTER SET-SERIALIZE-CHARACTER-SYSTEM
         SET-SKIP-META-TERMP-CHECKS SET-SKIP-META-TERMP-CHECKS!
         SET-SLOW-ALIST-ACTION SET-SPLITTER-OUTPUT SET-STATE-OK
         SET-TAU-AUTO-MODE
@@ -563,7 +567,7 @@
         STANDARD-CHAR STANDARD-CHAR-LISTP
         STANDARD-CHAR-LISTP-APPEND
         STANDARD-CHAR-LISTP-FORWARD-TO-CHARACTER-LISTP
-        STANDARD-CHAR-P
+        STANDARD-CHAR-P STANDARD-CHAR-P+
         STANDARD-CHAR-P-NTH STANDARD-CO
         STANDARD-OI STANDARD-STRING-ALISTP
         STANDARD-STRING-ALISTP-FORWARD-TO-ALISTP
@@ -590,8 +594,10 @@
         STRINGP STRINGP-SYMBOL-PACKAGE-NAME
         STRIP-CARS STRIP-CDRS
         SUBLIS SUBLIS-FN SUBLIS-FN-LST-SIMPLE SUBLIS-FN-SIMPLE
-        SUBSEQ SUBSEQ-LIST SUBSETP SUBSETP-EQ SUBSETP-EQUAL
+        SUBSEQ SUBSEQ-LIST SUBSEQUENCEP
+        SUBSETP SUBSETP-EQ SUBSETP-EQUAL
         SUBST SUBSTITUTE SUBSTITUTE-AC SUITABLY-TAMEP-LISTP SUMMARY
+        SWAP-STOBJS
         SYMBOL SYMBOL-< SYMBOL-<-ASYMMETRIC
         SYMBOL-<-IRREFLEXIVE SYMBOL-<-TRANSITIVE
         SYMBOL-<-TRICHOTOMY SYMBOL-ALISTP
@@ -601,6 +607,7 @@
         SYMBOL-LISTP-FORWARD-TO-TRUE-LISTP
         SYMBOL-NAME
         SYMBOL-NAME-INTERN-IN-PACKAGE-OF-SYMBOL
+        SYMBOL-NAME-LST
         SYMBOL-PACKAGE-NAME SYMBOLP
         SYMBOLP-INTERN-IN-PACKAGE-OF-SYMBOL
         SYNP SYNTAXP SYS-CALL SYS-CALL* SYS-CALL+ SYS-CALL-STATUS
@@ -616,11 +623,15 @@
         TENTH TERM-LIST-LISTP TERM-LISTP TERM-ORDER TERMINATION-THEOREM TERMP
         THE THE-CHECK THE-FIXNUM
         THE-FIXNUM! THEORY THEORY-INVARIANT
-        THIRD THM TIME$ TIME-TRACKER TIME-TRACKER-TAU TIMER-ALISTP
+        THEREIS$ THEREIS$+
+        THIRD
+        THM TIME$ TIME-TRACKER TIME-TRACKER-TAU TIMER-ALISTP
         TIMER-ALISTP-FORWARD-TO-TRUE-LIST-LISTP-AND-SYMBOL-ALISTP
         TOGGLE-PC-MACRO
         TOP-LEVEL TRACE! TRACE$ TRANS
-        TRANS! TRANS1 TRANSLAM TRANSLATE-AND-TEST TRICHOTOMY
+        TRANS!
+        TRANS-EVAL TRANS-EVAL-DEFAULT-WARNING TRANS-EVAL-NO-WARNING
+        TRANS1 TRANSLAM TRANSLATE-AND-TEST TRICHOTOMY
         TRUE-LIST-FIX TRUE-LIST-LISTP
         TRUE-LIST-LISTP-FORWARD-TO-TRUE-LISTP
         TRUE-LIST-LISTP-FORWARD-TO-TRUE-LISTP-ASSOC-EQUAL
@@ -636,7 +647,7 @@
         UNICITY-OF-1 UNION$ UNION-EQ UNION-EQUAL
         UNION-THEORIES UNIVERSAL-THEORY
         UNMONITOR UNQUOTE UNSAVE UNSIGNED-BYTE UNSIGNED-BYTE-P
-        UNTIL$ UNTIL$+ UNTRACE$ UNTRANS-TABLE
+        UNTIL$ UNTIL$+ UNTOUCHABLE-MARKER UNTRACE$ UNTRANS-TABLE
         UNTRANSLATE UPDATE-32-BIT-INTEGER-STACK
         UPDATE-ACL2-ORACLE
         UPDATE-ACL2-ORACLE-PRESERVES-STATE-P1
